@@ -1,8 +1,8 @@
-#include "FlexArray.h"
+#include "uFlexArray.h"
 #include <iostream.h>
 
 int main() {
-    FlexArray<int> a( 1 ), b( 1 );
+    uFlexArray<int> a( 1 ), b( 1 );
     int i;
     for ( i = 0; i < 6; i += 1 ) {
 	a.add( i );
