@@ -14,87 +14,87 @@ class mary: public fred {
 
 main() {
     uSequence<fred> foo;
-    uSeqGen<fred> foogen( foo );
+    uSeqIter<fred> fooIter( foo );
     uSequence<mary> bar;
-    uSeqGen<mary> bargen( bar );
+    uSeqIter<mary> barIter( bar );
     fred *f;
     mary *m;
     int i;
 
     // fred test
 
-    for ( ; foogen >> f; ) {
+    for ( ; fooIter >> f; ) {
 	cout << f->i << " ";
     }
     cout << "\n";
     
     for ( i = 0; i < 10; i += 1 ) {
-	foo.uAdd( new fred( 2 * i ) );
+	foo.add( new fred( 2 * i ) );
     }
-    for ( foogen.uOver( foo ); foogen >> f; ) {
+    for ( fooIter.over( foo ); fooIter >> f; ) {
 	cout << f->i << " ";
     }
     cout << "\n";
 
     for ( i = 0; i < 9; i += 1 ) {
-	foo.uDropHead();
+	foo.dropHead();
     }
-    for ( foogen.uOver( foo ); foogen >> f; ) {
+    for ( fooIter.over( foo ); fooIter >> f; ) {
 	cout << f->i << " ";
     }
     cout << "\n";
     
     for ( i = 0; i < 10; i += 1 ) {
-	foo.uAddTail( new fred( 2 * i + 1 ) );
+	foo.addTail( new fred( 2 * i + 1 ) );
     }
-    for ( foogen.uOver( foo ); foogen >> f; ) {
+    for ( fooIter.over( foo ); fooIter >> f; ) {
 	cout << f->i << " ";
     }
     cout << "\n";
 
     for ( i = 0; i < 9; i += 1 ) {
-	foo.uDropTail();
+	foo.dropTail();
     }
-    for ( foogen.uOver( foo ); foogen >> f; ) {
+    for ( fooIter.over( foo ); fooIter >> f; ) {
 	cout << f->i << " ";
     }
     cout << "\n";
 
     // mary test
 
-    for ( ; bargen >> m; ) {
+    for ( ; barIter >> m; ) {
 	cout << m->i << " ";
     }
     cout << "\n";
     
     for ( i = 0; i < 10; i += 1 ) {
-	bar.uAdd( new mary( 2 * i ) );
+	bar.add( new mary( 2 * i ) );
     }
-    for ( bargen.uOver( bar ); bargen >> m; ) {
+    for ( barIter.over( bar ); barIter >> m; ) {
 	cout << m->i << " ";
     }
     cout << "\n";
     
     for ( i = 0; i < 9; i += 1 ) {
-	bar.uDropHead();
+	bar.dropHead();
     }
-    for ( bargen.uOver( bar ); bargen >> m; ) {
+    for ( barIter.over( bar ); barIter >> m; ) {
 	cout << m->i << " ";
     }
     cout << "\n";
     
     for ( i = 0; i < 10; i += 1 ) {
-	bar.uAddTail( new mary( 2 * i + 1 ) );
+	bar.addTail( new mary( 2 * i + 1 ) );
     }
-    for ( bargen.uOver( bar ); bargen >> m; ) {
+    for ( barIter.over( bar ); barIter >> m; ) {
 	cout << m->i << " ";
     }
     cout << "\n";
 
     for ( i = 0; i < 9; i += 1 ) {
-	bar.uDropTail();
+	bar.dropTail();
     }
-    for ( bargen.uOver( bar ); bargen >> m; ) {
+    for ( barIter.over( bar ); barIter >> m; ) {
 	cout << m->i << " ";
     }
     cout << "\n";
