@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1993
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1993
 // 
 // uBoundedBuffer.h -- Generic bounded buffer problem using a monitor and uAccept
 // 
 // Author           : Peter A. Buhr
 // Created On       : Sun Apr  4 10:20:32 1993
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jun 28 16:57:30 2001
-// Update Count     : 9
+// Last Modified On : Wed Nov 30 09:00:13 2005
+// Update Count     : 15
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -29,7 +29,7 @@
 #define __U_BOUNDEDBUFFER_H__
 
 
-template<class ELEMTYPE> uMonitor uBoundedBuffer {
+template<class ELEMTYPE> _Monitor uBoundedBuffer {
   protected:
     const int size;					// number of buffer elements
     int front, back;					// position of front and back of queue
@@ -45,7 +45,7 @@ template<class ELEMTYPE> uMonitor uBoundedBuffer {
         delete [] Elements;
     } // uBoundedBuffer::~uBoundedBuffer
 
-    uNoMutex int query() {
+    _Nomutex int query() {
         return count;
     } // uBoundedBuffer::query
 
@@ -55,7 +55,7 @@ template<class ELEMTYPE> uMonitor uBoundedBuffer {
 
 template<class ELEMTYPE> inline void uBoundedBuffer<ELEMTYPE>::insert( ELEMTYPE elem ) {
     if ( count == size ) {				// buffer full ?
-        uAccept( remove );				// only allow removals
+        _Accept( remove );				// only allow removals
     } // if
 
     Elements[back] = elem;
@@ -67,14 +67,14 @@ template<class ELEMTYPE> inline ELEMTYPE uBoundedBuffer<ELEMTYPE>::remove() {
     ELEMTYPE elem;
 
     if ( count == 0 ) {					// buffer empty ?
-        uAccept( insert );				// only allow insertions
+        _Accept( insert );				// only allow insertions
     } // if
 
     elem = Elements[front];
     front = ( front + 1 ) % size;
     count -= 1;
 
-    return( elem );
+    return elem;
 } // uBoundedBuffer::remove
 
 
