@@ -2,13 +2,13 @@
 // 
 // Copyright (C) Glen Ditchfield 1994
 // 
-// uCollection.h -- Classes defining collections and related generators.
+// uCollection.h -- Classes defining collections and related iterators.
 // 
 // Author           : Glen Ditchfield
 // Created On       : Sun Feb 13 14:18:43 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jan 10 17:01:51 2002
-// Update Count     : 88
+// Last Modified On : Mon Oct 10 11:41:50 2005
+// Update Count     : 100
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -36,14 +36,14 @@ class uColable {
     friend class uCFriend;
 
     uColable *next;					// Next node in the list.
-    // class invariant: (next != 0) <=> uListed().
+    // class invariant: (next != 0) <=> listed().
   public:
     inline uColable() {
 	next = 0;
-    }							// post: ! uListed().
+    }							// post: ! listed().
     // Return true iff *this is an element of any collection.
-    inline bool uListed() const {			// pre:  this != 0
-	return (next != 0);
+    inline bool listed() const {			// pre:  this != 0
+	return next != 0;
     }
     inline uColable *getnext() {
 	return next;
@@ -55,7 +55,7 @@ class uColable {
  
 class uCFriend {
   protected:
-    uColable *&uNext(uColable *cp) const {
+    uColable *&uNext( uColable *cp ) const {
 	return cp->next;
     }
 };
@@ -66,8 +66,8 @@ class uCFriend {
 // descendants of uCollection<T> specify orderings.  uCollection<T> is an
 // abstract class: instances can not be declared.
 
-// The default implementation of uHead() returns root, since it must point at
-// some collection element if the collection is not empty.  uDrop() and uAdd()
+// The default implementation of head() returns root, since it must point at
+// some collection element if the collection is not empty.  drop() and add()
 // are left to descendants, since they define the order of elements.
 // Underscores are used at the start of member, parameter, and variable names,
 // to avoid clashes with argument names during template expansion.
@@ -75,55 +75,55 @@ class uCFriend {
 template<class T> class uCollection : protected uCFriend {
   protected:
     T *root;						// Pointer to root element of list.
-    // class invariant: root == 0 & uEmpty() | *root in *this
+    // class invariant: root == 0 & empty() | *root in *this
 
-    uCollection(const uCollection &);			// no copy
-    uCollection &operator=(const uCollection &);	// no assignment
+    uCollection( const uCollection & );			// no copy
+    uCollection &operator=( const uCollection & );	// no assignment
   public:
     inline uCollection() {	
 	root = 0;
-    }							// post: uEmpty().
-    inline bool uEmpty() const {			// 0 <=> *this contains no elements.
+    }							// post: empty().
+    inline bool empty() const {				// 0 <=> *this contains no elements.
 	return root == 0;
     }
-    inline T *uHead() const {
+    inline T *head() const {
 	return root;
-    }							// post: uEmpty() & uHead() == 0 | !uEmpty() & uHead() in *this
-    inline void uAdd(T *n) {				// pre: !n->uListed();
+    }							// post: empty() & head() == 0 | !empty() & head() in *this
+    inline void add( T *n ) {				// pre: !n->listed();
 	n = 0;
-    }							// post: n->isListed() & *n in *this
-    inline T *uDrop() {
+    }							// post: n->listed() & *n in *this
+    inline T *drop() {
 	return 0;
-    }							// post: uEmpty() & uDrop() == 0 | !uEmpty() & !uDrop()->isListed()
+    }							// post: empty() & drop() == 0 | !empty() & !drop()->listed()
 };
 
 
-// A uColGen<T> a stream of the elements of a uCollection<T>.  It is used to
+// A uColIter<T> a stream of the elements of a uCollection<T>.  It is used to
 // iterate over a collection.  Every descendant of uCollection has associated
-// generators descended from uColGen.  By convention, the generator ThingGen<T>
+// iterators descended from uColIter.  By convention, the iterator ThingIter<T>
 // for collection Thing<T> has members
-//	ThingGen<T>::ThingGen<T>();
-// to create inactive generators, and
-//	ThingGen<T>::ThingGen<T>(const Thing<T> &);
-//	void ThingGen<T>::over(const Thing<T> &);
-// to create active generators.  Usage is
+//	ThingIter<T>::ThingIter<T>();
+// to create inactive iterators, and
+//	ThingIter<T>::ThingIter<T>(const Thing<T> &);
+//	void ThingIter<T>::over(const Thing<T> &);
+// to create active iterators.  Usage is
 //	Thing<Foo>	c;
-//	ThingGen<Foo>	g(c);
+//	ThingIter<Foo>	g(c);
 //	Foo		*foop;
 //	while (g >> foop) ...
 // or
 //	for (g.over(c); g >> foop;) ...;
-// If a collection with an active generator is modified, subsequent values
-// produced by the generator are not defined.
+// If a collection with an active iterator is modified, subsequent values
+// produced by the iterator are not defined.
 
-template<class T> class uColGen : protected uCFriend {
+template<class T> class uColIter : protected uCFriend {
   protected:
     T *curr;						// Element to be returned by >>.
   public:
-    inline uColGen() {
+    inline uColIter() {
 	curr = 0;
     }							// post: elts = null.
-    bool operator>>(T *&tp) {
+    bool operator>>( T *&tp ) {
 	tp = 0;
 	return 0;
     }
