@@ -7,8 +7,8 @@
 // Author           : Glen Ditchfield
 // Created On       : Sun Feb 13 19:56:07 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Jul 19 23:09:16 2004
-// Update Count     : 110
+// Last Modified On : Mon Oct 17 07:58:35 2005
+// Update Count     : 131
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -35,7 +35,7 @@
 class uSeqable : public uColable {
     friend class uSFriend;
 
-    uSeqable* back;					// Pointer to previous node in the list.
+    uSeqable *back;					// Pointer to previous node in the list.
   public:
     uSeqable() {
 	back = 0;
@@ -50,7 +50,7 @@ class uSeqable : public uColable {
  
 class uSFriend {
   protected:
-    uSeqable*& uBack(uSeqable* sp) const {
+    uSeqable *&uBack( uSeqable *sp ) const {
 	return sp->back;
     };
 };
@@ -58,7 +58,7 @@ class uSFriend {
 
 // A uSequence<T> is a uCollection<T> where the elements form a sequence.  It is
 // possible to move back and forth along the sequence, and to insert and remove
-// elements in the sequence.  uHead() returns a pointer to the first element of
+// elements in the sequence.  head() returns a pointer to the first element of
 // the sequence.  T must be a public descendant of uSeqable.
 
 // Sequences are organized as circular doubly-linked lists.  root points at
@@ -68,35 +68,35 @@ template<class T> class uSequence: public uCollection<T>, protected uSFriend {
   protected:
     using uCollection<T>::root;
 
-    uSequence(const uSequence &);			// no copy
-    uSequence &operator=(const uSequence);		// no assignment
+    uSequence( const uSequence & );			// no copy
+    uSequence &operator=( const uSequence );		// no assignment
   public:
-    using uCollection<T>::uHead;
+    using uCollection<T>::head;
     using uCollection<T>::uNext;
 
-    uSequence() : uCollection<T>() {};			// post: uEmpty().
+    uSequence() : uCollection<T>() {};			// post: empty().
     // Return a pointer to the last sequence element, without removing it.
-    T *uTail() const {
+    T *tail() const {
 	return root ? (T *)uBack(root) : 0;
-    }							// post: uEmpty() & uTail() == 0 | !uEmpty() & uTail() in *this
+    }							// post: empty() & tail() == 0 | !empty() & tail() in *this
     // Return a pointer to the element after *n, or 0 if there isn't one.
-    T *uSucc(T *n) const {				// pre: *n in *this
+    T *succ( T *n ) const {				// pre: *n in *this
 #ifdef __U_DEBUG__
-	if ( ! n->uListed() ) uAbort( "(uSequence &)0x%p.uSucc( 0x%p ) node is not on a list.", this, n );
+	if ( ! n->listed() ) uAbort( "(uSequence &)0x%p.succ( 0x%p ) : Node is not on a list.", this, n );
 #endif // __U_DEBUG__
 	return (uNext(n) == root) ? 0 : (T *)uNext(n);
-    }							// post: n == uTail() & uSucc(n) == 0 | n != uTail() & *uSucc(n) in *this
+    }							// post: n == tail() & succ(n) == 0 | n != tail() & *succ(n) in *this
     // Return a pointer to the element before *n, or 0 if there isn't one.
-    T *uPred(T *n) const {				// pre: *n in *this
+    T *pred( T *n ) const {				// pre: *n in *this
 #ifdef __U_DEBUG__
-	if ( ! n->uListed() ) uAbort( "(uSequence &)0x%p.uPred( 0x%p ) node is not on a list.", this, n );
+	if ( ! n->listed() ) uAbort( "(uSequence &)0x%p.pred( 0x%p ) : Node is not on a list.", this, n );
 #endif // __U_DEBUG__
 	return (n == root) ? 0 : (T *)uBack(n);
-    }							// post: n == uHead() & uHead(n) == 0 | n != uHead() & *uPred(n) in *this
+    }							// post: n == head() & head(n) == 0 | n != head() & *pred(n) in *this
     // Insert *n into the sequence before *bef, or at the end if bef == 0.
-    void uInsertBef(T *n, T *bef) {			// pre: !n->uListed() & *bef in *this
+    void insertBef( T *n, T *bef) {			// pre: !n->listed() & *bef in *this
 #ifdef __U_DEBUG__
-	if ( n->uListed() ) uAbort( "(uSequence &)0x%p.uInsertBef( 0x%p, 0x%p ) node is already on another list.", this, n, bef );
+	if ( n->listed() ) uAbort( "(uSequence &)0x%p.insertBef( 0x%p, 0x%p ) : Node is already on another list.", this, n, bef );
 #endif // __U_DEBUG__
 	if (bef == root) {
 	    if (root) {
@@ -117,11 +117,11 @@ template<class T> class uSequence: public uCollection<T>, protected uSFriend {
 	    uNext(uBack(n)) = n;
 	    uBack(bef) = n;
 	}
-    }							// post: n->uListed() & *n in *this & uSucc(n) == bef
+    }							// post: n->listed() & *n in *this & succ(n) == bef
     // Insert *n into the sequence after *aft, or at the beginning if aft == 0.
-    void uInsertAft(T *aft, T *n) {			// pre: !n->uListed() & *aft in *this
+    void insertAft( T *aft, T *n ) {			// pre: !n->listed() & *aft in *this
 #ifdef __U_DEBUG__
-	if ( n->uListed() ) uAbort( "(uSequence &)0x%p.uInsertAft( 0x%p, 0x%p ) node is already on another list.", this, aft, n );
+	if ( n->listed() ) uAbort( "(uSequence &)0x%p.insertAft( 0x%p, 0x%p ) : Node is already on another list.", this, aft, n );
 #endif // __U_DEBUG__
 	if (!aft) {
 	    if (root) {
@@ -142,10 +142,10 @@ template<class T> class uSequence: public uCollection<T>, protected uSFriend {
 	    uBack((T *)uNext(n)) = n;
 	    uNext(aft) = n;
 	}
-    }							// post: n->uListed() & *n in *this & uSucc(n) == bef
-    void uRemove(T *n) {				// O(1)
+    }							// post: n->listed() & *n in *this & succ(n) == bef
+    void remove( T *n ) {				// O(1)
 #ifdef __U_DEBUG__
-	if ( ! n->uListed() ) uAbort( "(uSequence &)0x%p.uRemove( 0x%p ) node is not on a list.", this, n );
+	if ( ! n->listed() ) uAbort( "(uSequence &)0x%p.remove( 0x%p ) : Node is not on a list.", this, n );
 #endif // __U_DEBUG__
 	if (n == root) {
 	    if (uNext(root) == root) root = 0;
@@ -154,98 +154,96 @@ template<class T> class uSequence: public uCollection<T>, protected uSFriend {
 	uBack((T *)uNext(n)) = uBack(n);
 	uNext(uBack(n)) = uNext(n);
 	uNext(n) = uBack(n) = 0;
-    }							// post: !n->uListed().
+    }							// post: !n->listed().
     // Add an element to the head of the sequence.
-    inline void uAddHead(T* n) {			// pre: !n->uListed(); post: n->uListed() & uHead() == n
-	uInsertAft( 0, n );
+    inline void addHead( T *n ) {			// pre: !n->listed(); post: n->listed() & head() == n
+	insertAft( 0, n );
     }
     // Add an element to the tail of the sequence.
-    inline void uAddTail(T* n) {			// pre: !n->uListed(); post: n->uListed() & uHead() == n
-	uInsertBef( n, 0 );
+    inline void addTail( T *n ) {			// pre: !n->listed(); post: n->listed() & head() == n
+	insertBef( n, 0 );
     }
     // Add an element to the tail of the sequence.
-    inline void uAdd(T* n) {				// pre: !n->uListed(); post: n->uListed() & uHead() == n
-	uAddTail( n );
+    inline void add( T *n ) {				// pre: !n->listed(); post: n->listed() & head() == n
+	addTail( n );
     }
     // Remove and return the head element in the sequence.
-    T *uDropHead() {
-	T *n = uHead();
-	return n ? uRemove( n ), n : 0;
+    T *dropHead() {
+	T *n = head();
+	return n ? remove( n ), n : 0;
     }
     // Remove and return the head element in the sequence.
-    inline T *uDrop() {
-	return uDropHead();
+    inline T *drop() {
+	return dropHead();
     }
     // Remove and return the tail element in the sequence.
-    T *uDropTail() {
-	T *n = uTail();
-	return n ? uRemove( n ), n : 0;
+    T *dropTail() {
+	T *n = tail();
+	return n ? remove( n ), n : 0;
     }
 };
 
 
-// uSeqGen<T> is used to iterate over a uSequence<T> in head-to-tail order.
+// uSeqIter<T> is used to iterate over a uSequence<T> in head-to-tail order.
 
 
-template<class T> class uSeqGen: public uColGen<T>, protected uSFriend {
+template<class T> class uSeqIter: public uColIter<T>, protected uSFriend {
   protected:
-    using uColGen<T>::curr;
+    using uColIter<T>::curr;
 
     const uSequence<T> *seq;
   public:
-    uSeqGen() : uColGen<T>() {
+    uSeqIter() : uColIter<T>() {
 	seq = 0;
     } // post: elts = null.
-    // Create a generator active in sequence s
-    uSeqGen(const uSequence<T> &s) {	
-	curr = s.uHead();
+    // Create a iterator active in sequence s
+    uSeqIter(const uSequence<T> &s) {	
 	seq = &s;
+	curr = s.head();
     }							// post: elts = {e in s}.
-    // Make the generator active in sequence s.
-    void uOver(const uSequence<T> &s) {
-	curr = s.uHead();
+    // Make the iterator active in sequence s.
+    void over(const uSequence<T> &s) {
 	seq = &s;
+	curr = s.head();
     }							// post: elts = {e in s}.
-    bool operator>>(T *&tp) {
+    bool operator>>( T *&tp ) {
 	if (curr) {
 	    tp = curr;
-	    T *n = seq->uSucc(curr);
-	    curr = (n == seq->uHead()) ? 0 : n;
-	}
-	else tp = 0;
+	    T *n = seq->succ(curr);
+	    curr = (n == seq->head()) ? 0 : n;
+	} else tp = 0;
 	return tp != 0;
     }
 };
 
 
-// A uSeqGenRev<T> is used to iterate over a uSequence<T> in tail-to-head order.
+// A uSeqIterRev<T> is used to iterate over a uSequence<T> in tail-to-head order.
 
-template<class T> class uSeqGenRev: public uColGen<T>, protected uSFriend {
+template<class T> class uSeqIterRev: public uColIter<T>, protected uSFriend {
   protected:
-    using uColGen<T>::curr;
+    using uColIter<T>::curr;
 
     const uSequence<T> *seq;
   public:
-    uSeqGenRev() : uColGen<T>() {
+    uSeqIterRev() : uColIter<T>() {
 	seq = 0;
     }							// post: elts = null.
-    // Create a generator active in sequence s.
-    uSeqGenRev(const uSequence<T> &s) {
+    // Create a iterator active in sequence s.
+    uSeqIterRev(const uSequence<T> &s) {
 	seq = &s;
-	curr = s.uTail();
+	curr = s.tail();
     }							// post: elts = {e in s}.
-    // Make the generator active in sequence s.
-    void uOver(const uSequence<T> &s) {
+    // Make the iterator active in sequence s.
+    void over(const uSequence<T> &s) {
 	seq = &s;
-	curr = s.uTail();
+	curr = s.tail();
     }							// post: elts = {e in s}.
-    bool operator>>(T *&tp) {
+    bool operator>>( T *&tp ) {
 	if (curr) {
 	    tp = curr;
-	    T *n = seq->uPred(curr);
-	    curr = (n == seq->uTail()) ? 0 : n;
-	}
-	else tp = 0;
+	    T *n = seq->pred(curr);
+	    curr = (n == seq->tail()) ? 0 : n;
+	} else tp = 0;
 	return tp != 0;
     }
 };
