@@ -16,7 +16,9 @@ namespace _static_assert_ {
     template<int x> struct static_assert_test {};    
 } // _static_assert_
 
-#define _CPP_CONCAT_( X, Y ) X##Y
+#define _CPP_CONCAT_( X, Y ) _CPP_DO_CONCAT_( X, Y )
+#define _CPP_DO_CONCAT_( X, Y ) X##Y
+
 #define _STATIC_ASSERT_( B ) typedef ::_static_assert_::static_assert_test< sizeof(::_static_assert_::STATIC_ASSERTION_FAILURE< (bool)( B ) >) > \
 	_CPP_CONCAT_( _static_assert_typedef_, __LINE__ )
 
