@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Martin Karsten 1995
+// uC++ Version 5.3.0, Copyright (C) Martin Karsten 1995
 // 
 // uLocalDebugger.cc -- 
 // 
 // Author           : Martin Karsten
 // Created On       : Thu Apr 20 21:34:48 1995
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Aug 12 08:32:21 2004
-// Update Count     : 674
+// Last Modified On : Mon Oct 10 11:21:52 2005
+// Update Count     : 684
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -80,7 +80,7 @@ void uLocalDebugger::readPDU( uSocketClient &sockClient, uDebuggerProtocolUnit &
 	if ( sockClient.read( (char *)&request_type, sizeof(uDebuggerProtocolUnit::RequestType) ) != sizeof(uDebuggerProtocolUnit::RequestType) ) {
 		uLocalDebugger::uGlobalDebuggerActive = false;
 		uExit( -1 );									// TEMPORARY
-		uAbort( "uLocalDebugger/readPDU: global debugger is gone" );
+		uAbort( "uLocalDebugger/readPDU : global debugger is gone" );
 	} // if
 
 	pdu.re_init( request_type );
@@ -91,7 +91,7 @@ void uLocalDebugger::readPDU( uSocketClient &sockClient, uDebuggerProtocolUnit &
 		if ( sockClient.read( (char *)pdu.data_buffer(), pdu.data_size() ) != pdu.data_size() ) {
 			uLocalDebugger::uGlobalDebuggerActive = false;
 			uExit( -1 );								// TEMPORARY
-			uAbort( "uLocalDebugger/readPDU: global debugger is gone" );
+			uAbort( "uLocalDebugger/readPDU : global debugger is gone" );
 		} // if
 	} // if
 
@@ -108,7 +108,7 @@ void uLocalDebugger::readPDU( uSocketClient &sockClient, uDebuggerProtocolUnit &
 // arrival of data, it's delivered to the appropriate member of the local
 // debugger task.
 
-uTask uLocalDebuggerReader {
+_Task uLocalDebuggerReader {
     uLocalDebugger &debugger;
     uSocketClient &sockClient;
     uDebuggerProtocolUnit &pdu;
@@ -190,7 +190,7 @@ void uLocalDebuggerReader::main() {
 				break;
 			}
 		  default:
-			uAbort( "(uLocalDebuggerReader &)0x%p.main: global debugger sent invalid request %d", this, pdu.getType() );
+			uAbort( "(uLocalDebuggerReader &)0x%p.main : global debugger sent invalid request %d", this, pdu.getType() );
 		} // switch
 	} // for
 } // uLocalDebuggerReader::main
@@ -220,7 +220,7 @@ void uLocalDebugger::main() {
 			fullpath[0] = 0;
 		} else {
 			if ( ! getcwd( fullpath, FILENAME_MAX - (strlen(name) + 1) ) ) {
-				uAbort( "(uLocalDebugger &)0x%p.main: unable to obtain full pathname", this );
+				uAbort( "(uLocalDebugger &)0x%p.main : unable to obtain full pathname", this );
 			} // if
 			strcat( fullpath, "/" );
 		} // if
@@ -249,35 +249,35 @@ void uLocalDebugger::main() {
 #ifdef __U_DEBUG_H__
 		uDebugPrt( "%d (uLocalDebugger &)0x%p.main, loop\n", __LINE__, this );
 #endif // __U_DEBUG_H__
-		uAccept( ~uLocalDebugger ) {
+		_Accept( ~uLocalDebugger ) {
 			break;
-		} uOr uAccept( breakpointHandler ) {
-		} uOr uAccept( unblockTask ) {
-		} uOr uAccept( checkPointMX ) {
-		} uOr uAccept( performAtomicOperation ) {
-		} uOr uAccept( attachULThread ) {
+		} else _Accept( breakpointHandler ) {
+		} else _Accept( unblockTask ) {
+		} else _Accept( checkPointMX ) {
+		} else _Accept( performAtomicOperation ) {
+		} else _Accept( attachULThread ) {
 			send( pdu );
-		} uOr uAccept( createULThreadMX ) {
+		} else _Accept( createULThreadMX ) {
 			send( pdu );
-		} uOr uAccept( destroyULThreadMX ) {
+		} else _Accept( destroyULThreadMX ) {
 			send( pdu );
-		} uOr uAccept( createCluster ) {
+		} else _Accept( createCluster ) {
 			send( pdu );
-		} uOr uAccept( destroyCluster ) {
+		} else _Accept( destroyCluster ) {
 			send( pdu );
-		} uOr uAccept( createKernelThread ) {
+		} else _Accept( createKernelThread ) {
 			send( pdu );
-		} uOr uAccept( destroyKernelThread ) {
+		} else _Accept( destroyKernelThread ) {
 			send( pdu );
-		} uOr uAccept( migrateKernelThread ) {
+		} else _Accept( migrateKernelThread ) {
 			send( pdu );
-		} uOr uAccept( migrateULThreadMX ) {
+		} else _Accept( migrateULThreadMX ) {
 			send( pdu );
-		} uOr uAccept( abortApplication ) {
-		} uOr uAccept( finish ) {
+		} else _Accept( abortApplication ) {
+		} else _Accept( finish ) {
 			send( pdu );
 			uLocalDebuggerActive = false;
-		} // uAccept
+		} // _Accept
 	} // for
 
 	deregister();										// finish local debugger
@@ -384,19 +384,19 @@ void uLocalDebugger::uCreateLocalDebugger( int port, char *machine, char *name )
 	dispatcher = new uLocalDebuggerReader( *this, *sockClient );
 
 	// register clusters
-	uSeqGen<uClusterDL> ci;
+	uSeqIter<uClusterDL> ci;
 	uClusterDL *cr;
-	for ( ci.uOver( *uKernelModule::uGlobalClusters ); ci >> cr; ) {
+	for ( ci.over( *uKernelModule::uGlobalClusters ); ci >> cr; ) {
 		uCluster &cluster = cr->uGet();
 #ifdef __U_DEBUG_H__
-		uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, cluster is %s (0x%p)\n", __LINE__, this, cluster.uGetName(), &cluster );
+		uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, cluster is %s (0x%p)\n", __LINE__, this, cluster.getName(), &cluster );
 #endif // __U_DEBUG_H__
 		createCluster( cluster );
 		send( pdu );
 
 		// register processors associated with this cluster
 		uProcessorDL *pr;
-		for ( uSeqGen<uProcessorDL> gen( cluster.uProcessorsOnCluster ); gen >> pr; ) {
+		for ( uSeqIter<uProcessorDL> iter( cluster.uProcessorsOnCluster ); iter >> pr; ) {
 			uProcessor &processor = pr->uGet();
 #ifdef __U_DEBUG_H__
 			uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, processor is 0x%p\n", __LINE__, this, &processor );
@@ -408,10 +408,10 @@ void uLocalDebugger::uCreateLocalDebugger( int port, char *machine, char *name )
 
 		// register tasks on the cluster
 		uBaseTaskDL *bt;
-		for ( uSeqGen<uBaseTaskDL> tgen( cluster.uTasksOnCluster ); tgen >> bt; ) {
+		for ( uSeqIter<uBaseTaskDL> iter( cluster.uTasksOnCluster ); iter >> bt; ) {
 			uBaseTask &task = bt->uGet();
 #ifdef __U_DEBUG_H__
-			uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, task %s (0x%p)\n", __LINE__, this, task.uGetName(), &task );
+			uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, task %s (0x%p)\n", __LINE__, this, task.getName(), &task );
 #endif // __U_DEBUG_H__
 			// ignore  boot, system, local debugger, dispatcher and processor tasks
 
@@ -424,10 +424,10 @@ void uLocalDebugger::uCreateLocalDebugger( int port, char *machine, char *name )
 				regs.fp = registers[0];
 				regs.sp = registers[1];
 #ifdef __U_MULTI__
-				pdu.createNattachULThread( &task, U_THIS_TASK, &cluster, regs, task.uGetName() );
+				pdu.createNattachULThread( &task, U_THIS_TASK, &cluster, regs, task.getName() );
 #else
 				// in uni-processor, pretend that every task exist on the system cluster
-				pdu.createNattachULThread( &task, U_THIS_TASK, uKernelModule::uSystemCluster, regs, task.uGetName() );
+				pdu.createNattachULThread( &task, U_THIS_TASK, uKernelModule::uSystemCluster, regs, task.getName() );
 #endif
 				send( pdu );
 				receive();
@@ -501,12 +501,12 @@ void uLocalDebugger::send( uDebuggerProtocolUnit &pdu ) {
 
 void uLocalDebugger::receive() {						// only called by the local debugger
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "%d (uLocalDebugger &)0x%p.receive, task %s (0x%p) goes to sleep\n", __LINE__, this, (U_THIS_TASK)->uGetName(), U_THIS_TASK );
+    uDebugPrt( "%d (uLocalDebugger &)0x%p.receive, task %s (0x%p) goes to sleep\n", __LINE__, this, (U_THIS_TASK)->getName(), U_THIS_TASK );
 #endif // __U_DEBUG_H__
 
     uAssert( uLocalDebuggerActive );
     debugger_blocked_tasks += 1;
-	uAccept( unblockTask );
+	_Accept( unblockTask );
 	debugger_blocked_tasks -= 1;
 
 #ifdef __U_DEBUG_H__
@@ -517,15 +517,15 @@ void uLocalDebugger::receive() {						// only called by the local debugger
 
 bool uLocalDebugger::receive( uDebuggerProtocolUnit &pdu ) {
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "%d (uLocalDebugger &)0x%p.receive, task %s (0x%p) goes to sleep / pdu is 0x%p\n", __LINE__, this, (U_THIS_TASK)->uGetName(), U_THIS_TASK, &pdu );
+    uDebugPrt( "%d (uLocalDebugger &)0x%p.receive, task %s (0x%p) goes to sleep / pdu is 0x%p\n", __LINE__, this, (U_THIS_TASK)->getName(), U_THIS_TASK, &pdu );
 #endif // __U_DEBUG_H__
 
     uAssert( uLocalDebuggerActive );
     debugger_blocked_tasks += 1;
     blockedNode node( U_THIS_TASK, pdu );
-	blockedTasks.uAdd( &node );
-	uWait node.wait;
-	blockedTasks.uRemove( &node );
+	blockedTasks.add( &node );
+	node.wait.wait();
+	blockedTasks.remove( &node );
 	debugger_blocked_tasks -= 1;
 
 #ifdef __U_DEBUG_H__
@@ -545,14 +545,14 @@ void uLocalDebugger::unblockTask( uBaseTask *ul_thread, uDebuggerProtocolUnit &p
 #endif // __U_DEBUG_H__
 
 	blockedNode *p;
-	for ( uSeqGen<blockedNode> gen(blockedTasks); gen >> p; ) {	// search for thread
+	for ( uSeqIter<blockedNode> iter(blockedTasks); iter >> p; ) {	// search for thread
 	  if ( p->key == ul_thread ) break;
 	} // for
 
 	if ( p != NULL ) {									// found
 		p->pdu = pdu;									// copy result
 		pdu = pdu;										// copy result
-		uSignal p->wait;								// wake thread
+		p->wait.signal();								// wake thread
 	} // if
 
 #ifdef __U_DEBUG_H__
@@ -650,9 +650,9 @@ void uLocalDebugger::performAtomicOperation() {
 #endif // __U_DEBUG_H__
 
 #ifndef __U_MULTI__
-		uSeqGen<uClusterDL> ci;
+		uSeqIter<uClusterDL> ci;
 		uClusterDL *cr;
-		for ( ci.uOver( *uKernelModule::uGlobalClusters ); ci >> cr; ) {
+		for ( ci.over( *uKernelModule::uGlobalClusters ); ci >> cr; ) {
 			cluster = &cr->uGet();
 #endif // __U_MULTI__
 
@@ -660,13 +660,13 @@ void uLocalDebugger::performAtomicOperation() {
 			uDebugPrt( "%d (uLocalDebugger &)0x%p.performAtomicOperation, checking cluster 0x%p\n", __LINE__, this, cluster );
 #endif // __U_DEBUG_H__
 
-			uSeqGen<uBaseTaskDL> ci;
+			uSeqIter<uBaseTaskDL> ci;
 			uBaseTaskDL *cr;
-			for ( ci.uOver( cluster->uTasksOnCluster ); ci >> cr; ) {
+			for ( ci.over( cluster->uTasksOnCluster ); ci >> cr; ) {
 
 #ifdef __U_DEBUG_H__
 				uDebugPrt( "%d (uLocalDebugger &)0x%p.performAtomicOperation, task %s (0x%p) at 0x%p\n",
-						   __LINE__, this, cr->uGet().uGetName(), &cr->uGet(), cr->uGet().DebugPCandSRR );
+						   __LINE__, this, cr->uGet().getName(), &cr->uGet(), cr->uGet().DebugPCandSRR );
 #endif // __U_DEBUG_H__
 
 				if ( ( (long *)cr->uGet().DebugPCandSRR >= low1 && (long *)cr->uGet().DebugPCandSRR < high1 )
@@ -716,7 +716,7 @@ void uLocalDebugger::performAtomicOperation() {
 
 void uLocalDebugger::attachULThread( uBaseTask *this_task, uCluster *this_cluster ) {
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "%d (uLocalDebugger &)0x%p.attachULThread, task %s (0x%p) / cluster 0x%p\n", __LINE__, this, this_task->uGetName(), this_task, this_cluster );
+	uDebugPrt( "%d (uLocalDebugger &)0x%p.attachULThread, task %s (0x%p) / cluster 0x%p\n", __LINE__, this, this_task->getName(), this_task, this_cluster );
 #endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
@@ -728,11 +728,11 @@ void uLocalDebugger::attachULThread( uBaseTask *this_task, uCluster *this_cluste
 	regs.fp = registers[0];
 	regs.sp = registers[1];
 #ifdef __U_MULTI__
-	pdu.createNattachULThread( this_task, U_THIS_TASK, this_cluster, regs, this_task->uGetName() );
+	pdu.createNattachULThread( this_task, U_THIS_TASK, this_cluster, regs, this_task->getName() );
 #else
 	// in uni-processor, pretend that every task exist on the system cluster
 	// WHY IS THIS DONE LIKE THIS?
-	pdu.createNattachULThread( this_task, U_THIS_TASK, uKernelModule::uSystemCluster, regs, this_task->uGetName() );
+	pdu.createNattachULThread( this_task, U_THIS_TASK, uKernelModule::uSystemCluster, regs, this_task->getName() );
 #endif
 
 	if ( receive( pdu ) ) {
@@ -750,7 +750,7 @@ void uLocalDebugger::attachULThread( uBaseTask *this_task, uCluster *this_cluste
 
 void uLocalDebugger::checkPoint() {
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "%d (uLocalDebugger &)0x%p.checkPoint, task %s (0x%p) / cluster 0x%p\n", __LINE__, this, U_THIS_TASK->uGetName(), U_THIS_TASK, U_THIS_CLUSTER );
+	uDebugPrt( "%d (uLocalDebugger &)0x%p.checkPoint, task %s (0x%p) / cluster 0x%p\n", __LINE__, this, U_THIS_TASK->getName(), U_THIS_TASK, U_THIS_CLUSTER );
 #endif // __U_DEBUG_H__
 
   if ( U_THIS_TASK == uLocalDebuggerInstance || U_THIS_TASK == dispatcher || &U_THIS_TASK->uBound != NULL ) return;
@@ -760,7 +760,7 @@ void uLocalDebugger::checkPoint() {
 
 void uLocalDebugger::checkPointMX() {
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "%d (uLocalDebugger &)0x%p.checkPointMX, task %s (0x%p) / cluster 0x%p\n", __LINE__, this, U_THIS_TASK->uGetName(), U_THIS_TASK, U_THIS_CLUSTER );
+	uDebugPrt( "%d (uLocalDebugger &)0x%p.checkPointMX, task %s (0x%p) / cluster 0x%p\n", __LINE__, this, U_THIS_TASK->getName(), U_THIS_TASK, U_THIS_CLUSTER );
 #endif // __U_DEBUG_H__
 } // uLocalDebugger::checkPointMX
 
@@ -768,7 +768,7 @@ void uLocalDebugger::checkPointMX() {
 void uLocalDebugger::createULThread() {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.createULThread, task 0x%p (%s) / cluster 0x%p (%s)\n",
-			   __LINE__, this, U_THIS_TASK, U_THIS_TASK->uGetName(), U_THIS_CLUSTER, U_THIS_CLUSTER->uGetName() );
+			   __LINE__, this, U_THIS_TASK, U_THIS_TASK->getName(), U_THIS_CLUSTER, U_THIS_CLUSTER->getName() );
 #endif // __U_DEBUG_H__
 	MinimalRegisterSet regs;
 	CREATE_MINIMAL_REGISTER_SET( regs );				// save caller information
@@ -789,17 +789,17 @@ void uLocalDebugger::createULThreadMX( MinimalRegisterSet &regs ) {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.createULThreadMX, task 0x%p (%s) / cluster 0x%p (%s)\n",
 
-			   __LINE__, this, U_THIS_TASK, U_THIS_TASK->uGetName(), U_THIS_CLUSTER, U_THIS_CLUSTER->uGetName() );
+			   __LINE__, this, U_THIS_TASK, U_THIS_TASK->getName(), U_THIS_CLUSTER, U_THIS_CLUSTER->getName() );
 #endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
 
 #ifdef __U_MULTI__
-	pdu.createNcreateULThread( U_THIS_TASK, U_THIS_CLUSTER, regs, U_THIS_TASK->uGetName() );
+	pdu.createNcreateULThread( U_THIS_TASK, U_THIS_CLUSTER, regs, U_THIS_TASK->getName() );
 #else
 	// in uni-processor, pretend that every task exist on the system cluster
 	// WHY IS THIS DONE LIKE THIS?
-	pdu.createNcreateULThread( U_THIS_TASK, uKernelModule::uSystemCluster, regs, U_THIS_TASK->uGetName() );
+	pdu.createNcreateULThread( U_THIS_TASK, uKernelModule::uSystemCluster, regs, U_THIS_TASK->getName() );
 #endif
 	if ( receive( pdu ) ) {
 		int dummy;
@@ -815,7 +815,7 @@ void uLocalDebugger::createULThreadMX( MinimalRegisterSet &regs ) {
 void uLocalDebugger::destroyULThread() {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.destroyULThread, task 0x%p (%s) / cluster 0x%p (%s)\n",
-			   __LINE__, this, U_THIS_TASK, U_THIS_TASK->uGetName(), U_THIS_CLUSTER, U_THIS_CLUSTER->uGetName() );
+			   __LINE__, this, U_THIS_TASK, U_THIS_TASK->getName(), U_THIS_CLUSTER, U_THIS_CLUSTER->getName() );
 #endif // __U_DEBUG_H__
 
   if ( U_THIS_TASK == uLocalDebuggerInstance || U_THIS_TASK == dispatcher || U_THIS_TASK == uThisProcessor().uProcTask ) return;
@@ -827,7 +827,7 @@ void uLocalDebugger::destroyULThread() {
 void uLocalDebugger::destroyULThreadMX() {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.destroyULThreadMX, task 0x%p (%s) / cluster 0x%p (%s)\n",
-			   __LINE__, this, U_THIS_TASK, U_THIS_TASK->uGetName(), U_THIS_CLUSTER, U_THIS_CLUSTER->uGetName() );
+			   __LINE__, this, U_THIS_TASK, U_THIS_TASK->getName(), U_THIS_CLUSTER, U_THIS_CLUSTER->getName() );
 #endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
@@ -848,7 +848,7 @@ void uLocalDebugger::createCluster( uCluster &cluster ) {
 
   if ( ! uLocalDebuggerActive ) return;
 
-	pdu.createNcreateCluster( &cluster, cluster.uGetName(), cluster.uDebugIgnore );
+	pdu.createNcreateCluster( &cluster, cluster.getName(), cluster.uDebugIgnore );
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.createCluster, type %d, done\n", __LINE__, this, pdu.getType() );
@@ -874,7 +874,7 @@ void uLocalDebugger::destroyCluster( uCluster &cluster ) {
 void uLocalDebugger::createKernelThread( uProcessor &process, uCluster &cluster ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.createKernelThread, creating task: %s (0x%p), creating cluster:0x%p, process 0x%p / cluster 0x%p / pid %d\n",
-			   __LINE__, this, (U_THIS_TASK)->uGetName(), U_THIS_TASK, U_THIS_CLUSTER, &process, &cluster, process.uPid );
+			   __LINE__, this, (U_THIS_TASK)->getName(), U_THIS_TASK, U_THIS_CLUSTER, &process, &cluster, process.uPid );
 #endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
@@ -924,7 +924,7 @@ void uLocalDebugger::migrateKernelThread( uProcessor &process, uCluster &to_clus
 void uLocalDebugger::migrateULThread( uCluster &to_cluster ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.migrateULThread, task %s (0x%p) / to_cluster 0x%p\n",
-			   __LINE__, this, (U_THIS_TASK)->uGetName(), U_THIS_TASK, &to_cluster );
+			   __LINE__, this, (U_THIS_TASK)->getName(), U_THIS_TASK, &to_cluster );
 #endif // __U_DEBUG_H__
 
   if ( U_THIS_CLUSTER->uDebugIgnore || to_cluster.uDebugIgnore ) return;
@@ -936,7 +936,7 @@ void uLocalDebugger::migrateULThread( uCluster &to_cluster ) {
 void uLocalDebugger::migrateULThreadMX( uCluster &to_cluster ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.migrateULThreadMX, task %s (0x%p) / to_cluster 0x%p\n",
-			   __LINE__, this, (U_THIS_TASK)->uGetName(), U_THIS_TASK, &to_cluster );
+			   __LINE__, this, (U_THIS_TASK)->getName(), U_THIS_TASK, &to_cluster );
 #endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
@@ -976,7 +976,7 @@ void uLocalDebugger::abortApplication() {
   if ( U_THIS_TASK == uLocalDebuggerInstance ) return;	// prevent recursion
 
 	uSigHandlerModule::uSSignal( SIGCONT, cont_handler ); // install SIGCONT handler
-	pdu.createNabortApplication( uThisProcessor().uGetPid() );
+	pdu.createNabortApplication( uThisProcessor().getPid() );
 	send( pdu );
 	while ( ! abort_confirmed ) {						// busy wait for a response
 		sigpause( 0 );
