@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Martin Karsten 1995
+// uC++ Version 5.3.0, Copyright (C) Martin Karsten 1995
 // 
 // uLocalDebugger.h -- 
 // 
 // Author           : Martin Karsten
 // Created On       : Thu Apr 20 21:32:37 1995
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Jul 17 12:46:58 2004
-// Update Count     : 210
+// Last Modified On : Mon Jun 13 15:37:13 2005
+// Update Count     : 216
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -31,7 +31,7 @@
 							   ( defined( __sparc__ ) && defined( __svr4__ ) ) ||	\
 							   ( defined( __i386__ )  && defined( __linux__ ) )	\
 							   )
-#define __U_LOCALDEBUGGER_H__ 1
+#define __U_LOCALDEBUGGER_H__ 0							// TURN OFF FOR NOW
 #else
 #define __U_LOCALDEBUGGER_H__ 0
 #endif
@@ -40,7 +40,7 @@
 // Don't include uC++.h. Either this file is included in uC++.h or uC++.h is
 // included, before this file is included
 
-uTask uLocalDebuggerReader;								// forward declaration
+_Task uLocalDebuggerReader;							// forward declaration
 class uDebuggerProtocolUnit;							// forward declaration
 class uSocketClient;									// forward declaration
 class uBaseTask;										// forward declaration
@@ -52,20 +52,20 @@ struct MinimalRegisterSet;								// forward declaration
 //######################### uLocalDebugger #########################
 
 
-uTask uLocalDebugger {
+_Task uLocalDebugger {
 	friend class uSystemTask;							// access: uLocalDebuggerInstance, uLocalDebugger
 	friend class uBaseTask;								// access: uLocalDebuggerInstance, uLocalDebuggerActive, checkPoint, migrateULThread
-	friend uCoroutine uProcessorKernel;					// access: uLocalDebuggerInstance, dispatcher, debugger_blocked_tasks
-	friend uTask uProcessorTask;						// access: uLocalDebuggerInstance, uLocalDebuggerActive, checkPoint, createKernelThread, destroyKernelThread, migrateKernelThread
+	friend _Coroutine uProcessorKernel;				// access: uLocalDebuggerInstance, dispatcher, debugger_blocked_tasks
+	friend _Task uProcessorTask;						// access: uLocalDebuggerInstance, uLocalDebuggerActive, checkPoint, createKernelThread, destroyKernelThread, migrateKernelThread
     friend class uTaskConstructor;						// access: uLocalDebuggerInstance, uLocalDebuggerActive, checkPoint
     friend class uTaskDestructor;						// access: uLocalDebuggerInstance, uLocalDebuggerActive, checkPoint
 	friend class uTaskMain;								// uLocalDebuggerInstance, uLocalDebuggerActive, createULThread, destroyULThread
 	friend class uCluster;								// access: uLocalDebuggerInstance, uLocalDebuggerActive, checkPoint, createCluster, destroyCluster
 	friend class uLocalDebuggerBoot;					// access: uLocalDebuggerInstance
 	friend class uLocalDebuggerHandler;					// access: uLocalDebuggerInstance, breakpointHandler
-	friend uTask uLocalDebuggerReader;					// access: finish, performAtomicOperation, setConditionMask, resetConditionMask
+	friend _Task uLocalDebuggerReader;					// access: finish, performAtomicOperation, setConditionMask, resetConditionMask
 	friend void uAbort( const char *fmt, ... );			// access: uLocalDebuggerInstance, uLocalDebuggerActive, abortApplication
-	friend uTask uProfiler;								// access: dispatcher
+	friend _Task uProfiler;							// access: dispatcher
 	friend class uMachContext;							// uLocalDebuggerInstance, uLocalDebuggerActive, createULThread, destroyULThread
 
 	static bool uGlobalDebuggerActive;					// true => active, false => inactive (global debugger gone)
@@ -119,25 +119,25 @@ uTask uLocalDebugger {
     void receive();										// receive data from the global debugger / task is put to sleep
     bool receive( uDebuggerProtocolUnit& pdu );			// receive data from the global debugger / task is put to sleep
 
-	uMutex void unblockTask( uBaseTask *ul_thread, uDebuggerProtocolUnit &pdu );
-    uMutex int breakpointHandler( int no );
+	_Mutex void unblockTask( uBaseTask *ul_thread, uDebuggerProtocolUnit &pdu );
+    _Mutex int breakpointHandler( int no );
     void checkPoint();									// called before modifying kernel lists
-    uMutex void checkPointMX();
-    uMutex void performAtomicOperation();				// executing in a certain code range (called by uLocalDebuggerReader)
-    uMutex void attachULThread( uBaseTask* this_task, uCluster* this_cluster );
+    _Mutex void checkPointMX();
+    _Mutex void performAtomicOperation();				// executing in a certain code range (called by uLocalDebuggerReader)
+    _Mutex void attachULThread( uBaseTask* this_task, uCluster* this_cluster );
     void createULThread();
-    uMutex void createULThreadMX( MinimalRegisterSet &regs );
+    _Mutex void createULThreadMX( MinimalRegisterSet &regs );
     void destroyULThread();
-    uMutex void destroyULThreadMX();
-    uMutex void createCluster( uCluster &cluster_address );
-    uMutex void destroyCluster( uCluster &cluster_address );
-    uMutex void createKernelThread( uProcessor &process_address, uCluster &cluster_address );
-    uMutex void destroyKernelThread( uProcessor &process_address );
-    uMutex void migrateKernelThread( uProcessor &process_address, uCluster &to_address );
+    _Mutex void destroyULThreadMX();
+    _Mutex void createCluster( uCluster &cluster_address );
+    _Mutex void destroyCluster( uCluster &cluster_address );
+    _Mutex void createKernelThread( uProcessor &process_address, uCluster &cluster_address );
+    _Mutex void destroyKernelThread( uProcessor &process_address );
+    _Mutex void migrateKernelThread( uProcessor &process_address, uCluster &to_address );
     void migrateULThread( uCluster &to_address );
-    uMutex void migrateULThreadMX( uCluster &to_address );
-    uMutex void finish();
-    uMutex void abortApplication();
+    _Mutex void migrateULThreadMX( uCluster &to_address );
+    _Mutex void finish();
+    _Mutex void abortApplication();
 }; // uLocalDebugger
 
 
@@ -145,7 +145,6 @@ uTask uLocalDebugger {
 
 
 class uLocalDebuggerBoot {
-	friend class uEventList;							// TEMPORARY access: uCount
     static int uCount;
   public:
     uLocalDebuggerBoot();
