@@ -1,23 +1,25 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr and Richard Bilson 2003
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr and Richard Bilson 2003
 // 
 // AbortExit.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Fri Dec 19 10:33:58 2003
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Dec 22 14:02:37 2003
-// Update Count     : 4
+// Last Modified On : Sun Jul 31 12:51:37 2005
+// Update Count     : 7
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
 #include <uSemaphore.h>
+#include <iostream>
+using std::cerr;
+using std::endl;
 
 enum Mode { SPIN, EXIT, ABORT, EXPLODE } mode;
 
-uTask worker {
+_Task worker {
     void main() {
         switch( mode ) {
           case SPIN:
@@ -36,7 +38,7 @@ uTask worker {
 
 void uMain::main() {
     if ( argc <= 1 ) {
-        uCerr << "usage: " << argv[0] << " [0-3]" << endl;
+        cerr << "usage: " << argv[0] << " [0-3]" << endl;
     } // if
     mode = (Mode)atoi( argv[1] );
 
