@@ -1,18 +1,21 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // AlarmClock.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Wed Oct 23 16:10:01 1991
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Jan 28 23:28:14 2004
-// Update Count     : 82
+// Last Modified On : Wed Nov 30 08:40:41 2005
+// Update Count     : 97
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
+#include <iostream>
+using std::cout;
+using std::osacquire;
+using std::endl;
 
 class Node : public uSeqable {
 	Node( Node & );										// no copy
@@ -30,28 +33,28 @@ class OrderedList : public uSequence<Node> {
 	OrderedList() {}
 	void insert( Node *np ) {
 		Node *lp;
-		for ( lp = uHead();								// insert in ascending order by time
+		for ( lp = head();								// insert in ascending order by time
 			 lp != 0 && lp->ticks < np->ticks;
-			 lp = uSucc( lp ) );
-		uSequence<Node>::uInsertBef( np, lp );
+			 lp = succ( lp ) );
+		uSequence<Node>::insertBef( np, lp );
 	} // OrderedList::insert
 }; // OrderedList
 
-uTask Clock;											// forward declaration
+_Task Clock;											// forward declaration
 
-uMonitor Alarm {
-	friend uTask Clock;									// so Clock can call private Mutex member
+_Monitor Alarm {
+	friend _Task Clock;								// so Clock can call private Mutex member
 	int ticks;											// current time
 	OrderedList TimeReq;								// ordered list of time requests
 
-	uMutex void tick() {
+	_Mutex void tick() {
 		Node *client;
 
 		ticks += 1;
-		for ( uSeqGen<Node> gen(TimeReq); gen >> client && client->ticks <= ticks; ) {
-			uCout << uAcquire << "ticks = " << ticks << ", signalling!" << endl << uRelease;
-			TimeReq.uRemove( client );
-			uSignal client->block;
+		for ( uSeqIter<Node> iter(TimeReq); iter >> client && client->ticks <= ticks; ) {
+			osacquire( cout ) << "ticks = " << ticks << ", signalling!" << endl;
+			TimeReq.remove( client );
+			client->block.signal();
 		} // for
 	}; // Alarm::tick
   public:
@@ -59,7 +62,7 @@ uMonitor Alarm {
 		ticks = 0;
 	} // Alarm::Alarm
 
-	uNoMutex int time() {
+	_Nomutex int time() {
 		return ticks;
 	} // Alarm::time
 
@@ -67,28 +70,28 @@ uMonitor Alarm {
 		Node time( t );
 
 		TimeReq.insert( &time );
-		uWait time.block;
+		time.block.wait();
 	} // Alarm::sleep_until
 
 	void sleep_for( int n ) {
 		Node time( ticks + n );
 
 		TimeReq.insert( &time );
-		uWait time.block;
+		time.block.wait();
 	} // Alarm::sleep_for
 }; // Alarm
 
-uTask Clock {
+_Task Clock {
 	Alarm &alarm;
 
 	void main() {
 		for ( ;; ) {
-			uAccept( ~Clock ) {							// destructor called ?
+			_Accept( ~Clock ) {						// destructor called ?
 				break;
-			} uElse {									// don't block
-				uYield( 100 );							// should be a fixed period of time
+			} else {									// don't block
+				yield( 100 );							// should be a fixed period of time
 				alarm.tick();							// advance the clock
-			} // uAccept
+			} // _Accept
 		} // for
 	} // Clock::main
   public:
@@ -96,22 +99,22 @@ uTask Clock {
 	} // Clock::Clock
 }; // Clock
 
-uTask SampleUser {
+_Task SampleUser {
 	Alarm &alarm;
 
 	void main() {
 		int ticks;
 		
 		ticks = rand() % 17;      
-		uCout << uAcquire << "Task " << this << " : Current Time = " << alarm.time() << ", Going to sleep for " << ticks << " ticks" << endl << uRelease;
+		osacquire( cout ) << "Task " << this << " : Current Time = " << alarm.time() << ", Going to sleep for " << ticks << " ticks" << endl;
 		alarm.sleep_for( ticks );
-		uCout << uAcquire << "Task " << this << " : Now awake!  Current Time = " << alarm.time() << endl << uRelease;
+		osacquire( cout ) << "Task " << this << " : Now awake!  Current Time = " << alarm.time() << endl;
 		
 		ticks = rand() % 13 + alarm.time();      
-		uCout << uAcquire << "Task " << this << " : Current Time = " << alarm.time() << ", Going to sleep until time " << ticks << endl << uRelease;
+		osacquire( cout ) << "Task " << this << " : Current Time = " << alarm.time() << ", Going to sleep until time " << ticks << endl;
 		alarm.sleep_until( ticks );
-		uCout << uAcquire << "Task " << this << " : Now awake!  Current Time = " << alarm.time() << endl << uRelease;
-		uCout << uAcquire << "Task " << this << " : All done, now dying" << endl << uRelease;
+		osacquire( cout ) << "Task " << this << " : Now awake!  Current Time = " << alarm.time() << endl;
+		osacquire( cout ) << "Task " << this << " : All done, now dying" << endl;
 	}; // SampleUser::main
   public:
 	SampleUser( Alarm &alarm ) : alarm( alarm ) {
@@ -126,7 +129,7 @@ void uMain::main() {
 	SampleUser *sample_users = new SampleUser[NoOfUsers]( alarm );
 	delete [] sample_users;
 
-	uCout << uAcquire << "successful completion" << endl << uRelease;
+	osacquire( cout ) << "successful completion" << endl;
 } // uMain::main
 
 // Local Variables: //
