@@ -1,23 +1,26 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // Bench.cc -- Timing benchmarks for the basic features in uC++
 // 
 // Author           : Peter A. Buhr
 // Created On       : Thu Feb 15 22:03:16 1990
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Aug 27 07:57:43 2004
-// Update Count     : 349
+// Last Modified On : Fri Dec  2 13:02:19 2005
+// Update Count     : 362
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
+#include <iostream>
+using std::cerr;
+using std::osacquire;
+using std::endl;
 
 unsigned int uDefaultPreemption() {
     return 10;
 } // uDefaultPreemption
- 
+
 #include "Time.h"
 
 //=======================================
@@ -39,7 +42,7 @@ void BlockClassCreateDelete( int N ) {
 	ClassDummy dummy __attribute__(( unused ));
     } // for
     EndTime = Time();
-    uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+    osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
 } // BlockClassCreateDelete
 
 void DynamicClassCreateDelete( int N ) {
@@ -51,7 +54,7 @@ void DynamicClassCreateDelete( int N ) {
 	delete dummy;
     } // for
     EndTime = Time();
-    uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+    osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
 } // DynamicClassCreateDelete
 
 void ClassBidirectional( int N ) {
@@ -64,14 +67,14 @@ void ClassBidirectional( int N ) {
 	rv = dummy.bidirectional( 1, 2, 3, 4 ); 
     } // for
     EndTime = Time();
-    uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+    osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
 } // ClassBidirectional
 
 //=======================================
 // time coroutine
 //=======================================
 
-uCoroutine CoroutineDummy {
+_Coroutine CoroutineDummy {
     void main() {
     } // CoroutineDummy::main
   public:
@@ -88,7 +91,7 @@ void BlockCoroutineCreateDelete( int N ) {
 	CoroutineDummy dummy;
     } // for
     EndTime = Time();
-    uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+    osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
 } // BlockCoroutineCreateDelete
 
 void DynamicCoroutineCreateDelete( int N ) {
@@ -100,7 +103,7 @@ void DynamicCoroutineCreateDelete( int N ) {
 	delete dummy;
     } // for
     EndTime = Time();
-    uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+    osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
 } // DynamicCoroutineCreateDelete
 
 void CoroutineBidirectional( int N ) {
@@ -113,15 +116,15 @@ void CoroutineBidirectional( int N ) {
 	rv = dummy.bidirectional( 1, 2, 3, 4 ); 
     } // for
     EndTime = Time();
-    uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+    osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
 } // CoroutineBidirectional
 
-uCoroutine CoroutineResume {
+_Coroutine CoroutineResume {
     int N;
 
     void main() {
 	for ( int i = 1; i <= N; i += 1 ) {
-	    uSuspend;
+	    suspend();
 	} // for
     } // CoroutineResume::main
   public:
@@ -134,10 +137,10 @@ uCoroutine CoroutineResume {
 
 	StartTime = Time();
 	for ( int i = 1; i <= N; i += 1 ) {
-	    uResume;
+	    resume();
 	} // for
 	EndTime = Time();
-	uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+	osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
     } // CoroutineResume::resumer
 }; // CoroutineResume
 
@@ -145,7 +148,7 @@ uCoroutine CoroutineResume {
 // time monitor
 //=======================================
 
-uMutex class MonitorDummy {
+_Mutex class MonitorDummy {
   public:
     int bidirectional( int a, int, int, int ) {
 	return a;
@@ -160,7 +163,7 @@ void BlockMonitorCreateDelete( int N ) {
 	MonitorDummy dummy;
     } // for
     EndTime = Time();
-    uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+    osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
 } // BlockMonitorCreateDelete
 
 void DynamicMonitorCreateDelete( int N ) {
@@ -172,7 +175,7 @@ void DynamicMonitorCreateDelete( int N ) {
 	delete dummy;
     } // for
     EndTime = Time();
-    uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+    osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
 } // DynamicMonitorCreateDelete
 
 void MonitorBidirectional( int N ) {
@@ -185,10 +188,10 @@ void MonitorBidirectional( int N ) {
 	rv = dummy.bidirectional( 1, 2, 3, 4 ); 
     } // for
     EndTime = Time();
-    uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+    osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
 } // MonitorBidirectional
 
-uMonitor Monitor {
+_Monitor Monitor {
     uCondition condA, condB;
   public:
     volatile int here;
@@ -208,10 +211,10 @@ uMonitor Monitor {
 
 	StartTime = Time();
 	for ( int i = 1; i <= N; i += 1 ) {
-	    uAccept( caller );
+	    _Accept( caller );
 	} // for
 	EndTime = Time();
-	uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+	osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
     } // Monitor::acceptor
 
     void sigwaiterA( int N ) {
@@ -219,24 +222,24 @@ uMonitor Monitor {
 
 	StartTime = Time();
 	for ( int i = 1;; i += 1 ) {
-	    uSignal condA;
+	    condA.signal();
 	  if ( i > N ) break;
-	    uWait condB;
+	    condB.wait();
 	} // for
 	EndTime = Time();
-	uCerr << uAcquire << "\t " << ( ( EndTime - StartTime ) / N ) / 2 << uRelease;
+	osacquire( cerr ) << "\t " << ( ( EndTime - StartTime ) / N ) / 2;
     } // Monitor::sigwaiterA
 
     void sigwaiterB( int N ) {
 	for ( int i = 1;; i += 1 ) {
-	    uSignal condB;
+	    condB.signal();
 	  if ( i > N ) break;
-	    uWait condA;
+	    condA.wait();
 	} // for
     } // Monitor::sigwaiterB
 }; // Monitor
 
-uTask MonitorAcceptorPartner {
+_Task MonitorAcceptorPartner {
     int N;
     Monitor &m;
 
@@ -249,7 +252,7 @@ uTask MonitorAcceptorPartner {
     } // MonitorAcceptorPartner
 }; // MonitorAcceptorPartner
 
-uTask MonitorAcceptor {
+_Task MonitorAcceptor {
     int N;
 
     void main() {
@@ -257,7 +260,7 @@ uTask MonitorAcceptor {
 	MonitorAcceptorPartner partner( N, m );
 	int i, rv;
 
-	while ( m.here == 0 ) uYield();			// wait until acceptor is in monitor
+	while ( m.here == 0 ) yield();			// wait until acceptor is in monitor
 
 	for ( i = 1; i <= N; i += 1 ) {
 	    rv = m.caller( 1 );
@@ -269,7 +272,7 @@ uTask MonitorAcceptor {
     } // MonitorAcceptor
 }; // MonitorAcceptor
 
-uTask MonitorSignallerPartner {
+_Task MonitorSignallerPartner {
     int N;
     Monitor &m;
 
@@ -282,7 +285,7 @@ uTask MonitorSignallerPartner {
     } // MonitorSignallerPartner
 }; // MonitorSignallerPartner
 
-uTask MonitorSignaller {
+_Task MonitorSignaller {
     int N;
 
     void main() {
@@ -301,7 +304,7 @@ uTask MonitorSignaller {
 // time coroutine-monitor
 //=======================================
 
-uMutex uCoroutine CoroutineMonitorDummy {
+_Mutex _Coroutine CoroutineMonitorDummy {
     void main() {}
   public:
     int bidirectional( int a, int, int, int ) {
@@ -317,7 +320,7 @@ void BlockCoroutineMonitorCreateDelete( int N ) {
 	CoroutineMonitorDummy dummy;
     } // for
     EndTime = Time();
-    uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+    osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
 } // BlockCoroutineMonitorCreateDelete
 
 void DynamicCoroutineMonitorCreateDelete( int N ) {
@@ -329,7 +332,7 @@ void DynamicCoroutineMonitorCreateDelete( int N ) {
 	delete dummy;
     } // for
     EndTime = Time();
-    uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+    osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
 } // DynamicCoroutineMonitorCreateDelete
 
 void CoroutineMonitorBidirectional( int N ) {
@@ -342,10 +345,10 @@ void CoroutineMonitorBidirectional( int N ) {
 	rv = dummy.bidirectional( 1, 2, 3, 4 );
     } // for
     EndTime = Time();
-    uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+    osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
 } // CoroutineMonitorBidirectional
 
-uMutex uCoroutine CoroutineMonitorA {
+_Mutex _Coroutine CoroutineMonitorA {
     int N;
   public:
     volatile int here;
@@ -360,7 +363,7 @@ uMutex uCoroutine CoroutineMonitorA {
 
     void acceptor( int N ) {
 	CoroutineMonitorA::N = N;
-	uResume;
+	resume();
     } // CoroutineMonitorA::acceptor
   private:
     void main() {
@@ -370,14 +373,14 @@ uMutex uCoroutine CoroutineMonitorA {
 
 	StartTime = Time();
 	for ( int i = 1; i <= N; i += 1 ) {
-	    uAccept( caller );
+	    _Accept( caller );
 	} // for
 	EndTime = Time();
-	uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+	osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
     }; // CoroutineMonitorA::main
 }; // CoroutineMonitorA
 
-uTask CoroutineMonitorAcceptorPartner {
+_Task CoroutineMonitorAcceptorPartner {
     int N;
     CoroutineMonitorA &cm;
 
@@ -390,7 +393,7 @@ uTask CoroutineMonitorAcceptorPartner {
     } // CoroutineMonitorAcceptorPartner
 }; // CoroutineMonitorAcceptorPartner
 
-uTask CoroutineMonitorAcceptor {
+_Task CoroutineMonitorAcceptor {
     int N;
     void main();
   public:
@@ -404,19 +407,19 @@ void CoroutineMonitorAcceptor::main() {
     CoroutineMonitorAcceptorPartner partner( N, cm );
     int i, rv;
 
-    while ( cm.here == 0 ) uYield();
+    while ( cm.here == 0 ) yield();
     
     for ( i = 1; i <= N; i += 1 ) {
 	rv = cm.caller( 1 );
     } // for
 } // CoroutineMonitorAcceptor::main
 
-uMutex uCoroutine CoroutineMonitorResume {
+_Mutex _Coroutine CoroutineMonitorResume {
     int N;
 
     void main() {
 	for ( int i = 1; i <= N; i += 1 ) {
-	    uSuspend;
+	    suspend();
 	} // for
     }; // CoroutineMonitorResume::main
   public:
@@ -429,14 +432,14 @@ uMutex uCoroutine CoroutineMonitorResume {
 
 	StartTime = Time();
 	for ( int i = 1; i <= N; i += 1 ) {
-	    uResume;
+	    resume();
 	} // for
 	EndTime = Time();
-	uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+	osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
     }; // CoroutineMonitorResume::resumer
 }; // CoroutineMonitorResume
 
-uMutex uCoroutine CoroutineMonitorB {
+_Mutex _Coroutine CoroutineMonitorB {
     int N;
     uCondition condA, condB;
 
@@ -445,29 +448,29 @@ uMutex uCoroutine CoroutineMonitorB {
 
 	StartTime = Time();
 	for ( int i = 1;; i += 1 ) {
-	    uSignal condA;
+	    condA.signal();
 	  if ( i > N ) break;
-	    uWait condB;
+	    condB.wait();
 	} // for
 	EndTime = Time();
-	uCerr << uAcquire << "\t " << ( ( EndTime - StartTime ) / N ) / 2 << uRelease;
+	osacquire( cerr ) << "\t " << ( ( EndTime - StartTime ) / N ) / 2;
     }; // CoroutineMonitorB::main
   public:
     void sigwaiterA( int N ) {
 	CoroutineMonitorB::N = N;
-	uResume;
+	resume();
     } // CoroutineMonitorB::sigwaiterA
 
     void sigwaiterB( int N ) {
 	for ( int i = 1;; i += 1 ) {
-	    uSignal condB;
+	    condB.signal();
 	  if ( i > N ) break;
-	    uWait condA;
+	    condA.wait();
 	} // for
     } // CoroutineMonitorB::sigwaiterB
 }; // CoroutineMonitorB
 
-uTask CoroutineMonitorSignallerPartner {
+_Task CoroutineMonitorSignallerPartner {
     int N;
     CoroutineMonitorB &cm;
 
@@ -480,7 +483,7 @@ uTask CoroutineMonitorSignallerPartner {
     } // CoroutineMonitorSignallerPartner
 }; // CoroutineMonitorSignallerPartner
 
-uTask CoroutineMonitorSignaller {
+_Task CoroutineMonitorSignaller {
     int N;
 
     void main() {
@@ -500,7 +503,7 @@ uTask CoroutineMonitorSignaller {
 // time task
 //=======================================
 
-uTask TaskDummy {
+_Task TaskDummy {
     void main() {
     } // TaskDummy::main
   public:
@@ -517,7 +520,7 @@ void BlockTaskCreateDelete( int N ) {
 	TaskDummy dummy;
     } // for
     EndTime = Time();
-    uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+    osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
 } // BlockTaskCreateDelete
 
 void DynamicTaskCreateDelete( int N ) {
@@ -529,10 +532,10 @@ void DynamicTaskCreateDelete( int N ) {
 	delete dummy;
     } // for
     EndTime = Time();
-    uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+    osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
 } // DynamicTaskCreateDelete
 
-uTask TaskAcceptorPartner {
+_Task TaskAcceptorPartner {
     int N;
   public:
     int caller( int a ) {
@@ -548,14 +551,14 @@ uTask TaskAcceptorPartner {
     
 	StartTime = Time();
 	for ( int i = 1; i <= N; i += 1 ) {
-	    uAccept( caller );
+	    _Accept( caller );
 	} // for
 	EndTime = Time();
-	uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+	osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
     } // TaskAcceptorPartner::main
 }; // TaskAcceptorPartner
 
-uTask TaskAcceptor {
+_Task TaskAcceptor {
     int N;
 
     void main() {
@@ -572,15 +575,15 @@ uTask TaskAcceptor {
     } // TaskAcceptor
 }; // TaskAcceptor
 
-uTask TaskSignallerPartner {
+_Task TaskSignallerPartner {
     int N;
     uCondition condA, condB;
   public:
     void sigwaiter( int N ) {
 	for ( int i = 1;; i += 1 ) {
-	    uSignal condB;
+	    condB.signal();
 	  if ( i > N ) break;
-	    uWait condA;
+	    condA.wait();
 	} // for
     } // TaskSignallerPartner::sigwaiter
 
@@ -591,20 +594,20 @@ uTask TaskSignallerPartner {
     void main() {
 	int StartTime, EndTime;
 
-	uAccept( sigwaiter );
+	_Accept( sigwaiter );
 
 	StartTime = Time();
 	for ( int i = 1;; i += 1 ) {
-	    uSignal condA;
+	    condA.signal();
 	  if ( i > N ) break;
-	    uWait condB;
+	    condB.wait();
 	} // for
 	EndTime = Time();
-	uCerr << uAcquire << "\t " << ( ( EndTime - StartTime ) / N ) / 2 << uRelease;
+	osacquire( cerr ) << "\t " << ( ( EndTime - StartTime ) / N ) / 2;
     } // TaskSignallerPartner::main
 }; // TaskSignallerPartner
 
-uTask TaskSignaller {
+_Task TaskSignaller {
     int N;
 
     void main() {
@@ -622,7 +625,7 @@ uTask TaskSignaller {
 // time context switch
 //=======================================
 
-uTask ContextSwitch {
+_Task ContextSwitch {
     int N;
 
     void main() {    
@@ -632,7 +635,7 @@ uTask ContextSwitch {
 	    uYieldNoPoll();
 	} // for
 	EndTime = Time();
-	uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
+	osacquire( cerr ) << "\t " << ( EndTime - StartTime ) / N;
     } // ContextSwitch::main
   public:
     ContextSwitch( int N ) {
@@ -647,43 +650,43 @@ uTask ContextSwitch {
 void uMain::main() {
     const int NoOfTimes = 10000;
 
-    uCerr << "\t\tcreate\tcreate\t16i/4o\t16i/4o\tresume/\tsignal/" << endl;
-    uCerr << "\t\tdelete/\tdelete/\tbytes\tbytes\tsuspend\twait" << endl;
-    uCerr << "\t\tblock\tdynamic\tdirect\taccept\tcycle\tcycle" << endl;
+    osacquire( cerr ) << "\t\tcreate\tcreate\t16i/4o\t16i/4o\tresume/\tsignal/" << endl;
+    osacquire( cerr ) << "\t\tdelete/\tdelete/\tbytes\tbytes\tsuspend\twait" << endl;
+    osacquire( cerr ) << "\t\tblock\tdynamic\tdirect\taccept\tcycle\tcycle" << endl;
 
-    uCerr << "class\t";
+    osacquire( cerr ) << "class\t";
     BlockClassCreateDelete( NoOfTimes );
     DynamicClassCreateDelete( NoOfTimes );
     ClassBidirectional( NoOfTimes );
-    uCerr << "\t N/A\t N/A\t N/A";
-    uCerr << "\t" << endl;
+    osacquire( cerr ) << "\t N/A\t N/A\t N/A";
+    osacquire( cerr ) << "\t" << endl;
 
-    uCerr << "coroutine";
+    osacquire( cerr ) << "coroutine";
     BlockCoroutineCreateDelete( NoOfTimes );
     DynamicCoroutineCreateDelete( NoOfTimes );
     CoroutineBidirectional( NoOfTimes );
-    uCerr << "\t N/A";
+    osacquire( cerr ) << "\t N/A";
     {
 	CoroutineResume resumer( NoOfTimes );
 	resumer.resumer();
     }
-    uCerr << "\t N/A";
-    uCerr << "\t" << endl;
+    osacquire( cerr ) << "\t N/A";
+    osacquire( cerr ) << "\t" << endl;
 
-    uCerr << "monitor\t";
+    osacquire( cerr ) << "monitor\t";
     BlockMonitorCreateDelete( NoOfTimes );
     DynamicMonitorCreateDelete( NoOfTimes );
     MonitorBidirectional( NoOfTimes );
     {
 	MonitorAcceptor m( NoOfTimes );
     }
-    uCerr << "\t N/A";
+    osacquire( cerr ) << "\t N/A";
     {
 	MonitorSignaller m( NoOfTimes );
     }
-    uCerr << "\t" << endl;
+    osacquire( cerr ) << "\t" << endl;
 
-    uCerr << "cormonitor";
+    osacquire( cerr ) << "cormonitor";
     BlockCoroutineMonitorCreateDelete( NoOfTimes );
     DynamicCoroutineMonitorCreateDelete( NoOfTimes );
     CoroutineMonitorBidirectional( NoOfTimes );
@@ -697,27 +700,26 @@ void uMain::main() {
     {
 	CoroutineMonitorSignaller cm( NoOfTimes );
     }
-    uCerr << "\t" << endl;
+    osacquire( cerr ) << "\t" << endl;
 
-    uCerr << "task\t";
+    osacquire( cerr ) << "task\t";
     BlockTaskCreateDelete( NoOfTimes );
     DynamicTaskCreateDelete( NoOfTimes );
-    uCerr << "\t N/A";
+    osacquire( cerr ) << "\t N/A";
     {
 	TaskAcceptor t( NoOfTimes );
     }
-    uCerr << "\t N/A";
+    osacquire( cerr ) << "\t N/A";
     {
 	TaskSignaller t( NoOfTimes );
     }
-    uCerr << "\t" << endl;
+    osacquire( cerr ) << "\t" << endl;
 
-    uCerr << "cxt sw\t";
+    osacquire( cerr ) << "cxt sw\t";
     {
 	ContextSwitch dummy( NoOfTimes );		// context switch
     }
-    uCerr << "\t" << endl;
-
+    osacquire( cerr ) << "\t" << endl;
 } // uMain::main
 
 // Local Variables: //
