@@ -1,69 +1,69 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 2004
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 2004
 // 
 // EHM10.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Mar 22 21:17:24 2004
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Aug 19 16:41:27 2004
-// Update Count     : 4
+// Last Modified On : Mon Nov 21 15:25:53 2005
+// Update Count     : 11
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
+#include <iostream>
+using std::cout;
+using std::endl;
 
-uRaiseEvent R1 {
+_ResumeEvent R1 {
   public:
 	int &i;
 	R1( int &i ) : i(i) {}
 };
-uInitEvent( R1 );
 
-uRaiseEvent R2 {
+_ResumeEvent R2 {
   public:
 	int &i;
 	R2( int &i ) : i(i) {}
 };
-uInitEvent( R2 );
 
 void f( int &i );
 void g( int &i );
 
 void h1( R1 &r ) {
 	r.i -= 1;
-	uCout << "h1, i:" << r.i << endl;
+	cout << "h1, i:" << r.i << endl;
 	f( r.i );
 }
 void h2( R2 &r ) {
 	r.i -= 1;
-	uCout << "h2, i:" << r.i << endl;
+	cout << "h2, i:" << r.i << endl;
 	g( r.i );
 }
 void h3( R2 &r ) {
 	r.i -= 1;
-	uCout << "h3, i:" << r.i << endl;
+	cout << "h3, i:" << r.i << endl;
 }
 
 void f( int &i ) {
 	i -= 1;
-	uCout << "f, i:" << i << endl;
+	cout << "f, i:" << i << endl;
 	if ( i > 5 ) {
 		try <R1,h1> {
-			if ( i < 10 ) uRaise R2(i);
+			if ( i < 10 ) _Resume R2(i);
 			try <R2,h2> {
 				g( i );
 			}
 		}
 	} else {
-		if ( i > -5 ) uRaise R2(i);
+		if ( i > -5 ) _Resume R2(i);
 	} // if
 }
 
 void g( int &i ) {
 	i -= 1;
-	uCout << "g, i:" << i << endl;
+	cout << "g, i:" << i << endl;
 	if ( i > 10 ) {
 		try <R2,h2> {
 			f( i );
@@ -71,7 +71,7 @@ void g( int &i ) {
 		try <R2,h3> {
 			f( i );
 		}
-		uRaise R1(i);
+		_Resume R1(i);
 	}
 }
 void uMain::main() {
