@@ -1,40 +1,35 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1998
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1998
 // 
 // EHM2.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Tue Oct 27 21:24:48 1998
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Aug  4 10:01:21 2004
-// Update Count     : 17
+// Last Modified On : Fri Aug  5 14:46:10 2005
+// Update Count     : 28
 // 
 
 #include <uC++.h>
-#include <uOStream.h>
 
-extern "C" void uDebugPrt( const char fmt[], ... );
-
-uThrowEvent xxx {
+_ThrowEvent xxx {
   public:
     uBaseTask *tid;
     xxx( uBaseTask *tid ) : tid(tid) {}
 };
-uInitEvent(xxx);
 
-uThrowEvent yyy {
+_ThrowEvent yyy {
   public:
     uBaseTask *tid;
     yyy( uBaseTask *tid ) : tid(tid) {}
 };
-uInitEvent(yyy);
 
 
-uTask fred {
+_Task fred {
     void r( int i ) {
 	if ( i == 0 ) {
-	    uThrow xxx( &uThisTask() );
+	    _Throw xxx( &uThisTask() );
 	} else {
 	    r( i - 1 );
 	} // if
@@ -46,7 +41,7 @@ uTask fred {
 		r( 5 );
 	    } catch( xxx e ) {
 		uAssert( e.tid == &uThisTask() );
-		uThrow;
+		_Throw;
 	    }
 	} else {
 	    s( i - 1 );
@@ -59,7 +54,7 @@ uTask fred {
 		s( 5 );
 	    } catch( xxx e ) {
 		uAssert( e.tid == &uThisTask() );
-		uThrow yyy( &uThisTask() );
+		_Throw yyy( &uThisTask() );
 	    }
 	} else {
 	    t( i - 1 );
@@ -69,7 +64,6 @@ uTask fred {
     void main() {
 //	for ( int i = 0; i < 5000; i += 1 ) {
 	for ( int i = 0; i < 5; i += 1 ) {
-	    uDebugPrt( "fred::main this:0x%p i:%d\n", this, i );
 	    try {
 		t( 5 );
 	    } catch( yyy e ) {
@@ -81,5 +75,5 @@ uTask fred {
 
 void uMain::main() {
     uProcessor p[3];
-    fred f[4] __attribute__ (( unused ));
+    fred f[4] __attribute__(( unused ));
 } // uMain::main
