@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // Fib.cc --   Produce the fibonacci numbers in sequence on each call.
 //
@@ -12,14 +12,16 @@
 // Author           : Peter A. Buhr
 // Created On       : Thu Aug  2 11:55:37 1990
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jun 10 11:15:39 2004
-// Update Count     : 34
+// Last Modified On : Mon Oct 10 11:40:34 2005
+// Update Count     : 39
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
+#include <iostream>
+using std::cout;
+using std::endl;
 
-uCoroutine fibonacci {
+_Coroutine fibonacci {
     int fn;
 
     void main() {
@@ -27,21 +29,21 @@ uCoroutine fibonacci {
 
 	fn = 1;						// special case f0
 	fn1 = fn;
-	uSuspend;
+	suspend();
 	fn = 1;						// special case f1
 	fn2 = fn1;
 	fn1 = fn;
-	uSuspend;
+	suspend();
 	for ( ;; ) {					// general case fn
 	    fn = fn1 + fn2;
-	    uSuspend;
+	    suspend();
 	    fn2 = fn1;
 	    fn1 = fn;
 	} // for
     } // fibonacci::main
   public:
     int next() {
-	uResume;
+	resume();
 	return fn;
     }; // next
 }; // fibonacci
@@ -51,11 +53,11 @@ void uMain::main() {
     fibonacci f1, f2;					// create two fibonacci generators
     int i;
 
-    uCout << "Fibonacci Numbers" << endl;
+    cout << "Fibonacci Numbers" << endl;
     for ( i = 1; i <= NoOfFibs; i += 1 ) {
-	uCout << f1.next() << " " << f2.next() << endl;
+	cout << f1.next() << " " << f2.next() << endl;
     } // for
-    uCout << "successful completion" << endl;
+    cout << "successful completion" << endl;
 } // uMain::main
 
 // Local Variables: //
