@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // ClientINET.cc -- Client for INET/stream socket test. Client reads from
 // standard input, writes the data to the server, reads the data from the
@@ -9,13 +9,18 @@
 // Author           : Peter A. Buhr
 // Created On       : Tue Jan  7 08:42:32 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jul 22 08:41:38 2003
-// Update Count     : 136
+// Last Modified On : Wed Nov 30 13:20:45 2005
+// Update Count     : 142
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
 #include <uSocket.h>
+#include <iostream>
+using std::cin;
+using std::cout;
+using std::cerr;
+using std::osacquire;
+using std::endl;
 
 #define EOD '\377'
 // minimum buffer size is 2, 1 character and string terminator, '\0'
@@ -23,7 +28,7 @@
 
 int rcnt = 0, wcnt = 0;
 
-uTask reader {
+_Task reader {
 	uSocketClient &client;
 
 	void main() {
@@ -32,32 +37,32 @@ uTask reader {
 
 		for ( ;; ) {
 			len = client.read( buf, sizeof(buf) );
-			// uCerr << uAcquire << "Client::reader read len:" << len << endl << uRelease;
-		  if ( buf[0] == EOD ) break;
+			// osacquire( cerr ) << "Client::reader read len:" << len << endl;
+		  if ( len == 0 ) uAbort( "(uSocketClient &)0x%p : EOF ecountered without EOD", &client );
 			// The EOD character can be piggy-backed onto the end of the message.
-		  if ( buf[len - 1] == EOD ) { rcnt += len - 1; uCout.write( buf, len - 1 ); break; }
+		  if ( buf[len - 1] == EOD ) {
+			  rcnt += len - 1;
+			  cout.write( buf, len - 1 );				// do not write the EOD
+			  break; }
 			rcnt += len;
-			uCout.write( buf, len );
+			cout.write( buf, len );
 		} // for
-		// connection not closed until after this data received
-		buf[0] = '\0';
-		client.write( buf, sizeof(char) );
 	} // reader::main
   public:
 	reader( uSocketClient &client ) : client ( client ) {
 	} // reader::reader
 }; // reader
 
-uTask writer {
+_Task writer {
 	uSocketClient &client;
 
 	void main() {
 		char buf[BufferSize];
 
 		for ( ;; ) {
-			uCin.get( buf, sizeof(buf), '\0' );	// leave room for string terminator
+			cin.get( buf, sizeof(buf), '\0' );			// leave room for string terminator
 			int len = strlen( buf );
-			// uCerr << uAcquire << "Client::writer read len:" << len << endl << uRelease;
+			// osacquire( cerr ) << "Client::writer read len:" << len << endl;
 		  if ( buf[0] == '\0' ) break;
 			wcnt += len;
 			client.write( buf, len );
@@ -75,11 +80,11 @@ void uMain::main() {
 	  case 2:
 		break;
 	  default:
-		uCerr << "Usage: " << argv[0] << " port-number" << endl;
+		cerr << "Usage: " << argv[0] << " port-number" << endl;
 		uExit( -1 );
 	} // switch
 
-	uSocketClient client( atoi( argv[1] ) );			// connection to local server
+	uSocketClient client( atoi( argv[1] ) );			// connection to server
 	{
 		reader rd( client );							// emit worker to read from server and write to output
 		writer wr( client );							// emit worker to read from input and write to server
