@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1999
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1999
 // 
 // ClientINET2.cc -- Client for INET/datagram socket test. Client reads from
 // standard input, writes the data to the server, reads the data from the
@@ -9,14 +9,19 @@
 // Author           : Peter A. Buhr
 // Created On       : Thu Apr 29 16:04:50 1999
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Nov 21 13:29:21 2003
-// Update Count     : 44
+// Last Modified On : Wed Nov 30 13:20:52 2005
+// Update Count     : 50
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
-#include <uSocket.h>
 #include <uSemaphore.h>
+#include <uSocket.h>
+#include <iostream>
+using std::cin;
+using std::cout;
+using std::cerr;
+using std::osacquire;
+using std::endl;
 
 #define EOD '\377'
 // minimum buffer size is 2, 1 character and string terminator, '\0'
@@ -33,7 +38,7 @@ int rcnt = 0, wcnt = 0;
 const int MaxWriteBeforeRead = 5;
 uSemaphore readSync(MaxWriteBeforeRead);
 
-uTask reader {
+_Task reader {
 	uSocketClient &client;
 
 	void main() {
@@ -43,12 +48,15 @@ uTask reader {
 		for ( ;; ) {
 			len = client.recvfrom( buf, sizeof(buf) );
 			readSync.V();
-			// uCerr << uAcquire << "Client::reader read len:" << len << endl << uRelease;
-		  if ( buf[0] == EOD ) break;
+			// osacquire( cerr ) << "Client::reader read len:" << len << endl;
+		  if ( len == 0 ) uAbort( "(uSocketClient &)0x%p : EOF ecountered without EOD", &client );
 			// The EOD character can be piggy-backed onto the end of the message.
-		  if ( buf[len - 1] == EOD ) { rcnt += len - 1; uCout.write( buf, len - 1 ); break; }
+		  if ( buf[len - 1] == EOD ) {
+			  rcnt += len - 1;
+			  cout.write( buf, len - 1 );				// do not write the EOD
+			  break; }
 			rcnt += len;
-			uCout.write( buf, len );
+			cout.write( buf, len );
 		} // for
 	} // reader::main
   public:
@@ -56,16 +64,16 @@ uTask reader {
 	} // reader::reader
 }; // reader
 
-uTask writer {
+_Task writer {
 	uSocketClient &client;
 
 	void main() {
 		char buf[BufferSize];
 
 		for ( ;; ) {
-			uCin.get( buf, sizeof(buf), '\0' );	// leave room for string terminator
+			cin.get( buf, sizeof(buf), '\0' );			// leave room for string terminator
 			int len = strlen( buf );
-			// uCerr << uAcquire << "Client::writer read len:" << len << endl << uRelease;
+			// osacquire( cerr ) << "Client::writer read len:" << len << endl;
 		  if ( buf[0] == '\0' ) break;
 			wcnt += len;
 			readSync.P();
@@ -85,7 +93,7 @@ void uMain::main() {
 	  case 2:
 		break;
 	  default:
-		uCerr << "Usage: " << argv[0] << " port-number" << endl;
+		cerr << "Usage: " << argv[0] << " port-number" << endl;
 		uExit( -1 );
 	} // switch
 
