@@ -1,21 +1,24 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // File.cc -- Print multiple copies of the same file to standard output
 // 
 // Author           : Peter A. Buhr
 // Created On       : Tue Jan  7 08:44:56 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jul 22 08:41:44 2003
-// Update Count     : 34
+// Last Modified On : Sun Jul 31 18:57:48 2005
+// Update Count     : 41
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
 #include <uFile.h>
+#include <iostream>
+using std::cout;
+using std::cerr;
+using std::endl;
 
-uTask Copier {
+_Task Copier {
 	uFile &input;
 
 	void main() {
@@ -26,8 +29,8 @@ uTask Copier {
 		for ( int i = 0;; i += 1 ) {					// copy in-file to out-file
 			count = in.read( buf, sizeof( buf ) );
 		  if ( count == 0 ) break;						// eof ?
-			uCout << buf[0];
-			if ( i % 20 == 0 ) uYield();
+			cout << buf[0];
+			if ( i % 20 == 0 ) yield();
 		} // for
 	} // Copier::main
   public:
@@ -40,7 +43,7 @@ void uMain::main() {
 	  case 2:
 		break;
 	  default:
-		uCerr << "Usage: " << argv[0] << " input-file" << endl;
+		cerr << "Usage: " << argv[0] << " input-file" << std::endl;
 		uExit( -1 );
 	} // switch
 
