@@ -1,44 +1,45 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // NBFile.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Tue Apr 27 20:39:18 1993
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jul 22 08:41:21 2003
-// Update Count     : 17
+// Last Modified On : Sun Jul 31 19:00:02 2005
+// Update Count     : 21
 // 
 
 #include <uC++.h>
 #include <uFile.h>
-#include <uIStream.h>
+#include <iostream>
+using std::cin;
 
 char ch = 'a';						// shared by reader and writer
 
-uTask Reader {
+_Task Reader {
     void main() {
 	char tch;
 
 	for ( ;; ) {
-	    uCin >> tch;				// read number from stdin
+	    cin >> tch;					// read number from stdin
 	    if ( tch != '\n' ) ch = tch;
-	  if ( uCin.eof() ) break;
+	  if ( cin.eof() ) break;
 	} // for
     } // Reader::main
 }; // Reader
 
-uTask Writer {
+_Task Writer {
     void main() {
 	uFile out( "xxx" );
 	uFileAccess output( out, O_WRONLY | O_CREAT | O_TRUNC, 0666 );
 	int i;
 
 	for ( i = 0;; i += 1 ) {
-	  if ( uCin.eof() ) break;
+	  if ( cin.eof() ) break;
 	    output.write( &ch, 1 );			// write number to stdout
-	    uYield( 1 );
+	    yield( 1 );
 	} // for
     } // Writer::main
 }; // Writer
