@@ -1,38 +1,40 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // NBStream.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Wed Apr 28 13:23:14 1993
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jul 22 08:41:30 2003
-// Update Count     : 17
+// Last Modified On : Sun Jul 31 19:00:44 2005
+// Update Count     : 21
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
+#include <iostream>
+using std::cin;
+using std::cerr;
 
 int d = 1;						// shared by reader and writer
 
-uTask Reader {
+_Task Reader {
     void main() {
 	for ( ;; ) {
-	    uCin >> d;					// read number from stdin
-	  if ( uCin.eof() ) break;
+	    cin >> d;					// read number from stdin
+	  if ( cin.eof() ) break;
 	} // for
     } // Reader::main
 }; // Reader
 
-uTask Writer {
+_Task Writer {
     void main() {
 	for ( int i = 0;; i += 1 ) {
-	  if ( uCin.eof() ) break;
+	  if ( cin.eof() ) break;
 	    if ( i % 100 == 0 ) {			// don't print too much
-		uCerr << d;				// write number to stderr (no buffering)
-	    } // if					// if uCout is used, it must be flushed with endl
-	    uYield( 1 );
+		cerr << d;				// write number to stderr (no buffering)
+	    } // if					// if cout is used, it must be flushed with endl
+	    yield( 1 );
 	} // for
     } // Writer::main
 }; // Writer
