@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // ServerUNIX.cc -- Server for UNIX/stream socket test. Server accepts multiple
 // connections from clients. Each client then communicates with an acceptor.
@@ -9,30 +9,33 @@
 // Author           : Peter A. Buhr
 // Created On       : Tue Jan  7 08:40:22 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Aug 13 00:09:09 2004
-// Update Count     : 129
+// Last Modified On : Sat Aug  6 18:11:34 2005
+// Update Count     : 137
 // 
 
 #include <uC++.h>
 #include <uSocket.h>
-#include <uIOStream.h>
+#include <iostream>
+using std::cerr;
+using std::osacquire;
+using std::endl;
 
 #define EOD '\377'
 #define BufferSize (8 * 1024)
 
-uTask server;											// forward declaration
+_Task server;											// forward declaration
 
-uTask acceptor {
+_Task acceptor {
 	uSocketServer &sockserver;
 	server &s;
 
 	void main();
   public:
-	acceptor( uSocketServer &socks, server &s ) : sockserver( socks ), s( s ) {
+	acceptor( uSocketServer &socks, server &s ) : uBaseTask( 64000 ), sockserver( socks ), s( s ) {
 	} // acceptor::acceptor
 }; // acceptor
 
-uTask server {
+_Task server {
 	uSocketServer &sockserver;
 	acceptor *terminate;
 	int acceptorCnt;
@@ -52,10 +55,10 @@ uTask server {
 	void main() {
 		new acceptor( sockserver, *this );				// create initial acceptor
 		for ( ;; ) {
-			uAccept( connection ) {
+			_Accept( connection ) {
 				new acceptor( sockserver, *this );		// create new acceptor after a connection
 				acceptorCnt += 1;
-			} uOr uAccept( complete ) {					// acceptor has completed with client
+			} else _Accept( complete ) {				// acceptor has completed with client
 				delete terminate;						// delete must appear here or deadlock
 				acceptorCnt -= 1;
 		  if ( acceptorCnt == 0 ) break;				// if no outstanding connections, stop
@@ -63,7 +66,7 @@ uTask server {
 					new acceptor( sockserver, *this );	// create new acceptor after a timeout
 					acceptorCnt += 1;
 				} // if
-			}; // uAccept
+			}; // _Accept
 		} // for
 	} // server::main
 }; // server
@@ -78,14 +81,14 @@ void acceptor::main() {
 		s.connection();									// tell server about client connection
 		for ( ;; ) {
 			len = acceptor.read( buf, sizeof(buf) );	// read byte from client
-			// uCerr << uAcquire << "Server::acceptor read len:" << len << endl << uRelease;
+			// osacquire( cerr ) << "Server::acceptor read len:" << len << endl;
+		  if ( len == 0 ) uAbort( "(uSocketAccept &)0x%p : EOF ecountered without EOD", &acceptor );
 			acceptor.write( buf, len );					// write byte back to client
 			// The EOD character can be piggy-backed onto the end of the message.
-		  if ( buf[0] == EOD || buf[len - 1] == EOD ) break; // end of data ?
+		  if ( buf[len - 1] == EOD ) break;				// end of data ?
 		} // for
-		acceptor.read( buf, sizeof(char) );				// end of transmission
 		s.complete( this, false );						// terminate
-	} catch( uSocketAccept::uOpenTimeout ) {
+	} catch( uSocketAccept::OpenTimeout ) {
 		s.complete( this, true );						// terminate
 	} // try
 } // acceptor::main
@@ -95,7 +98,7 @@ void uMain::main() {
 	  case 2:
 		break;
 	  default:
-		uCerr << "Usage: " << argv[0] << " socket-name" << endl;
+		cerr << "Usage: " << argv[0] << " socket-name" << endl;
 		uExit( -1 );
 	} // switch
 
