@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // Inheritance.cc -- test inheritance of tasks
 // 
 // Author           : Peter A. Buhr
 // Created On       : Thu Mar 22 20:20:04 1990
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jul 22 08:39:16 2003
-// Update Count     : 52
+// Last Modified On : Sat Aug  6 17:50:43 2005
+// Update Count     : 57
 // 
 
 /*
@@ -29,9 +29,12 @@
    */
 
 #include <uC++.h>
-#include <uIOStream.h>
+#include <iostream>
+using std::cout;
+using std::osacquire;
+using std::endl;
 
-uTask super {
+_Task super {
     void main();
   public:
     virtual ~super();
@@ -40,32 +43,32 @@ uTask super {
 }; // super
 
 void super::main() {
-    uCout << uAcquire << "super::main" << endl << uRelease;
+    osacquire( cout ) << "super::main" << endl;
     for ( ;; ) {
-	uAccept ( ~super ) {
+	_Accept( ~super ) {
 	    break;
-	} uOr uAccept ( fred ) {
-	} uOr uAccept ( mary ) {
+	} else _Accept( fred ) {
+	} else _Accept( mary ) {
 	} // accept
     } // for
-    uCout << uAcquire << "super::main terminating" << endl << uRelease;
+    osacquire( cout ) << "super::main terminating" << endl;
 } // super::main
 
 super::~super() {
-    uCout << uAcquire << "super::~super" << endl << uRelease;
+    osacquire( cout ) << "super::~super" << endl;
 } // super::~super
 
 int super::fred( int n ) {
-    uCout << uAcquire << "super::fred: " << n << endl << uRelease;
+    osacquire( cout ) << "super::fred: " << n << endl;
     return n;
 } // super::fred
 
 float super::mary( float f ) {
-    uCout << uAcquire << "super::mary: " << f << endl << uRelease;
+    osacquire( cout ) << "super::mary: " << f << endl;
     return f;
 } // super::mary
 
-uTask sub : public super {
+_Task sub : public super {
     void main();
   public:
     virtual ~sub();
@@ -75,34 +78,34 @@ uTask sub : public super {
 }; // sub
 
 void sub::main() {
-    uCout << uAcquire << "sub::main" << endl << uRelease;
+    osacquire( cout ) << "sub::main" << endl;
     for ( ;; ) {
-	uAccept ( ~sub ) {
+	_Accept( ~sub ) {
 	    break;
-	} uOr uAccept ( fred ) {
-	} uOr uAccept ( mary ) {
-	} uOr uAccept ( jane ) {
+	} else _Accept( fred ) {
+	} else _Accept( mary ) {
+	} else _Accept( jane ) {
 	} // accept
     } // for
-    uCout << uAcquire << "sub::main terminating" << endl << uRelease;
+    osacquire( cout ) << "sub::main terminating" << endl;
 } // sub::main
 
 sub::~sub() {
-    uCout << uAcquire << "sub::~sub" << endl << uRelease;
+    osacquire( cout ) << "sub::~sub" << endl;
 } // sub::~sub
 
 int sub::fred( int n ) {
-    uCout << uAcquire << "sub::fred: " << n << endl << uRelease;
+    osacquire( cout ) << "sub::fred: " << n << endl;
     return n;
 } // sub::fred
 
 float sub::mary( float f ) {
-    uCout << uAcquire << "sub::mary: " << f << endl << uRelease;
+    osacquire( cout ) << "sub::mary: " << f << endl;
     return f;
 } // sub::mary
 
 char sub::jane( char c ) {
-    uCout << uAcquire << "sub::jane: " << c << endl << uRelease;
+    osacquire( cout ) << "sub::jane: " << c << endl;
     return c;
 } // sub::jane
 
