@@ -1,34 +1,35 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // Migrate.cc -- Test migrating of tasks among clusters.
 // 
 // Author           : Peter Buhr
 // Created On       : Tue Jun 28 10:23:11 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jul 22 08:36:39 2003
-// Update Count     : 30
+// Last Modified On : Sun Jul 31 17:24:16 2005
+// Update Count     : 34
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
-
+#include <iostream>
+using std::cout;
+using std::endl;
 
 unsigned int uDefaultPreemption() {
     return 1;
 } // uDefaultPreemption
 
-uTask dummy {
+_Task dummy {
     uCluster &c1, &c2, &c3;
 
     void main() {
 	const int NoOfTimes = 10000;
 
         for ( int i = 0; i < NoOfTimes; i += 1 ) {
-	    uMigrate( c3 );
-	    uMigrate( c2 );
-	    uMigrate( c1 );
+	    migrate( c3 );
+	    migrate( c2 );
+	    migrate( c1 );
         } // for
     } // dummy::main
   public:
@@ -46,7 +47,7 @@ void uMain::main() {
     {
 	dummy d1( uThisCluster(), c1, c2 ), d2( c2, uThisCluster(), c1 ), d3( c1, c2, uThisCluster() );
     }
-    uCout << "successful completion" << endl;
+    cout << "successful completion" << endl;
 } // uMain::main
 
 // Local Variables: //
