@@ -1,66 +1,69 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1996
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1996
 // 
 // MutexOwner.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Tue Feb  6 13:51:59 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Jun 21 10:30:49 2004
-// Update Count     : 17
+// Last Modified On : Wed Nov 30 08:42:05 2005
+// Update Count     : 24
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
+#include <iostream>
+using std::cout;
+using std::osacquire;
+using std::endl;
 
-uCorMonitor tom {
+_Cormonitor tom {
   public:
     tom() {
 	reset();
     }
     void reset() {
-	uCout << uAcquire << "(" << &uThisTask() << ") tom::reset" << endl << uRelease;
+	osacquire( cout ) << "(" << &uThisTask() << ") tom::reset" << endl;
     }
 };    
 
-uCorMonitor fred : public tom {
+_Cormonitor fred : public tom {
     void main() {
 	for ( int i = 0; i < 3; i += 1 ) {
 	    mem();
 	} // for
-	uResume;
+	resume();
     }
   public:
     fred() {
 	reset();
     }
     void reset() {
-	uCout << uAcquire << "(" << &uThisTask() << ") fred::reset" << endl << uRelease;
+	osacquire( cout ) << "(" << &uThisTask() << ") fred::reset" << endl;
     }
     void mem() {
-	uResume;
+	resume();
     }
 };
 
-uMonitor mary {
+_Monitor mary {
     uCondition delay;
   public:
     void mem( int i ) {
 	if ( i >= 0 ) {
 	    mem( i - 1 );
-	    uCout << uAcquire << "(" << &uThisTask() << ") mary::mem, i:" << i << endl << uRelease;
+	    osacquire( cout ) << "(" << &uThisTask() << ") mary::mem, i:" << i << endl;
 	} else {
 	    if ( delay.empty() ) {
-		uWait delay;
+		delay.wait();
 	    } else {
-		uSignal delay;
+		delay.signal();
 	    } // if
 	} // if
     } // mary::mem
 }; // mary
 
-uTask jane {
+_Task jane {
     mary &m;
   public:
     jane( mary &m ) : m( m ) {}
@@ -72,7 +75,7 @@ uTask jane {
   protected:
     void main() {
 	for ( int i = 0; i < 3; i += 1 ) {
-	    uCout << uAcquire << "(" << &uThisTask() << ") jane::main, i:" << i << endl << uRelease;
+	    osacquire( cout ) << "(" << &uThisTask() << ") jane::main, i:" << i << endl;
 	    mem( i );
 	} // for
     } // jane::main
