@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Philipp E. Lim and Ashif S. Harji 1996
+// uC++ Version 5.3.0, Copyright (C) Philipp E. Lim and Ashif S. Harji 1996
 // 
 // PeriodicTaskTest.cc -- 
 // 
 // Author           : Philipp E. Lim and Ashif S. Harji
 // Created On       : Tue Jul 23 14:48:37 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Aug 13 08:49:18 2004
-// Update Count     : 120
+// Last Modified On : Sat Dec  3 09:42:39 2005
+// Update Count     : 126
 // 
 
 // When run multiprocessor, migration to the system cluster to perform I/O
@@ -19,9 +19,12 @@
 #include <uC++.h>
 #include <uRealTime.h>
 #include <uDeadlineMonotonic.h>
-#include <uIOStream.h>
-#include <uIOManip.h>
-
+#include <iostream>
+using std::cout;
+using std::osacquire;
+using std::endl;
+#include <iomanip>
+using std::setw;
 
 const int Delay = 100000;
 uTime Start;						// global start time for all tasks
@@ -33,13 +36,13 @@ class AcrossCxtSw : public uContext {
     AcrossCxtSw( uTime &clock ) : clock( clock ) {
     } // AcrossCxtSw::AcrossCxtSw
 
-    void uSave(){
-	beginCxtSw = uThisProcessor().uGetClock().uGetTime();
-    } // AcrossCxtSw::uSave
+    void save(){
+	beginCxtSw = uThisProcessor().getClock().getTime();
+    } // AcrossCxtSw::save
 
-    void uRestore(){
-	clock += uThisProcessor().uGetClock().uGetTime() - beginCxtSw;
-    } // AcrossCxtSw::uRestore
+    void restore(){
+	clock += uThisProcessor().getClock().getTime() - beginCxtSw;
+    } // AcrossCxtSw::restore
 }; // AcrossCxtSw
 
 
@@ -53,15 +56,15 @@ class AcrossCxtSw : public uContext {
 // context switch, an accurate simulation of the computation time, C, is
 // possible.
 
-uPeriodicTask TestTask {
+_PeriodicTask TestTask {
     uDuration C;
     int id;
 
     void main() {
 	uTime starttime, delay, currtime, endtime;
 
-	starttime = uThisProcessor().uGetClock().uGetTime();
-	uCout << uAcquire << setw(3) << starttime - ::Start << "\t" << id << " Beginning." << endl << uRelease;
+	starttime = uThisProcessor().getClock().getTime();
+	osacquire( cout ) << setw(3) << starttime - ::Start << "\t" << id << " Beginning." << endl;
 
 	// The loop below must deal with asynchronous advancing of variable
 	// "delay" during context switches. A problem occurs when "delay" is
@@ -74,21 +77,21 @@ uPeriodicTask TestTask {
 	// or new (i.e., becomes larger) value, the comparision does not cause
 	// a premature exit.
 
-	delay = uThisProcessor().uGetClock().uGetTime() + C;
+	delay = uThisProcessor().getClock().getTime() + C;
 	{
 	    AcrossCxtSw acrossCxtSw( delay );		// cause delay to advance across a context switch interval
 	    do {
 		for ( int i = 0; i < Delay; i += 1 );	// don't spend too much time in non-interruptible clock routine
-		currtime = uThisProcessor().uGetClock().uGetTime();
+		currtime = uThisProcessor().getClock().getTime();
 	    } while ( delay > currtime );
 	}
-	endtime = uThisProcessor().uGetClock().uGetTime();
-	uCout << uAcquire << setw(3) << endtime - ::Start << "\t" << id << " Ending " <<
-	    setw(3) << endtime - starttime << " seconds later" << endl << uRelease;
+	endtime = uThisProcessor().getClock().getTime();
+	osacquire( cout ) << setw(3) << endtime - ::Start << "\t" << id << " Ending " <<
+	    setw(3) << endtime - starttime << " seconds later" << endl;
     } // TestTask::main
   public:
     TestTask( int id, uDuration period, uDuration deadline, uCluster &clust ) :
-	    uPeriodicBaseTask( period, uTime(0), uThisProcessor().uGetClock().uGetTime()+90, deadline, clust ),
+	    uPeriodicBaseTask( period, uTime(0), uThisProcessor().getClock().getTime()+90, deadline, clust ),
 	    C( deadline ), id( id ) {
     } // TestTask::TestTask
 }; // TestTask
@@ -102,11 +105,11 @@ void uMain::main() {
 	TestTask t2( 2, 30, 9, RTClust );
 	TestTask t3( 3, 60, 19, RTClust );
 
-	uCout << uAcquire << "Time  \t\tTaskID" << endl << uRelease;
+	osacquire( cout ) << "Time  \t\tTaskID" << endl;
 
-	::Start = uThisProcessor().uGetClock().uGetTime();
+	::Start = uThisProcessor().getClock().getTime();
 	p = new uProcessor( RTClust );			// now create the processor to do the work
     } // wait for t1, t2, t3 to finish
     delete p;
-    uCout << "successful completion" << endl;
+    cout << "successful completion" << endl;
 } // uMain::main
