@@ -1,12 +1,14 @@
 #include <uC++.h>
-#include <uIOStream.h>
+#include <iostream>
+using std::cout;
+using std::endl;
 
 volatile bool stop = false;
 
-uTask T {
+_Task T {
     void main() {
 	while ( ! stop ) {
-	    uYield();
+	    yield();
 	}
     }
 };
@@ -19,7 +21,7 @@ void uMain::main() {
 	uProcessor *p1 = new uProcessor();
 
 	while ( &uThisProcessor() != p1 ) {
-	    uYield();
+	    yield();
 	} // while
 
 	p2 = new uProcessor();
@@ -29,7 +31,7 @@ void uMain::main() {
 
 	stop = true;
     }
-    uCerr << "here" << endl;
+    cout << "here" << endl;
     delete p2;
 } // uMain::main
 
