@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Philipp E. Lim and Ashif S. Harji 1996
+// uC++ Version 5.3.0, Copyright (C) Philipp E. Lim and Ashif S. Harji 1996
 // 
 // RealTimePhilosophers.cc -- 
 // 
 // Author           : Philipp E. Lim and Ashif S. Harji
 // Created On       : Tue Jul 23 14:58:56 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Aug 13 08:24:30 2004
-// Update Count     : 71
+// Last Modified On : Sat Dec  3 09:44:48 2005
+// Update Count     : 81
 // 
 
 // When run multiprocessor, migration to the system cluster to perform I/O
@@ -17,10 +17,13 @@
 
 
 #include <uC++.h>
-#include <uIOStream.h>
-#include <uIOManip.h>
 #include <uDeadlineMonotonic.h>
-
+#include <iostream>
+using std::cout;
+using std::osacquire;
+using std::endl;
+#include <iomanip>
+using std::setw;
 
 const int Delay = 100000;
 uTime Start;						// global start time for all tasks
@@ -32,13 +35,13 @@ class AcrossCxtSw : public uContext {
     AcrossCxtSw( uTime &clock ) : clock( clock ) {
     } // AcrossCxtSw::AcrossCxtSw
 
-    void uSave(){
-	beginCxtSw = uThisProcessor().uGetClock().uGetTime();
-    } // AcrossCxtSw::uSave
+    void save(){
+	beginCxtSw = uThisProcessor().getClock().getTime();
+    } // AcrossCxtSw::save
 
-    void uRestore(){
-	clock += uThisProcessor().uGetClock().uGetTime() - beginCxtSw;
-    } // AcrossCxtSw::uRestore
+    void restore(){
+	clock += uThisProcessor().getClock().getTime() - beginCxtSw;
+    } // AcrossCxtSw::restore
 }; // AcrossCxtSw
 
 
@@ -47,9 +50,9 @@ uRealTimeMonitor RestRoom {
     void Toilet( int id, uDuration C1 ) {
 	uTime starttime, delay, currtime, endtime;
 
-	starttime = uThisProcessor().uGetClock().uGetTime();
-	uCout << uAcquire << setw(3) << starttime - ::Start << "\t" << id << " goes to TOILET (priority " <<
-	    uThisTask().uGetActivePriority() << ")" << endl << uRelease;
+	starttime = uThisProcessor().getClock().getTime();
+	osacquire( cout ) << setw(3) << starttime - ::Start << "\t" << id << " goes to TOILET (priority " <<
+	    uThisTask().getActivePriority() << ")" << endl;
 
 	// The loop below must deal with asynchronous advancing of variable
 	// "delay" during context switches. A problem occurs when "delay" is
@@ -62,26 +65,26 @@ uRealTimeMonitor RestRoom {
 	// or new (i.e., becomes larger) value, the comparision does not cause
 	// a premature exit.
 
-	delay = uThisProcessor().uGetClock().uGetTime() + C1;
+	delay = uThisProcessor().getClock().getTime() + C1;
 	{
 	    AcrossCxtSw acrossCxtSw( delay );
 	    do {
 		for ( int i = 0; i < Delay; i += 1 );	// don't spend too much time in non-interruptible clock routine
-		currtime = uThisProcessor().uGetClock().uGetTime();
+		currtime = uThisProcessor().getClock().getTime();
 	    } while ( delay > currtime );
 	}
 
-	endtime = uThisProcessor().uGetClock().uGetTime();
-	uCout << uAcquire << setw(3) << endtime - ::Start << "\t" << id << " leaves TOILET " <<
-	    setw(3) << endtime - starttime << " seconds later (priority " << uThisTask().uGetActivePriority() << ")" << endl << uRelease;
+	endtime = uThisProcessor().getClock().getTime();
+	osacquire( cout ) << setw(3) << endtime - ::Start << "\t" << id << " leaves TOILET " <<
+	    setw(3) << endtime - starttime << " seconds later (priority " << uThisTask().getActivePriority() << ")" << endl;
     } // Toilet::Toilet
 
-    uNoMutex void Wash( int id, uDuration C2 ) {
+    _Nomutex void Wash( int id, uDuration C2 ) {
 	uTime starttime, delay, currtime, endtime;
 
-	starttime = uThisProcessor().uGetClock().uGetTime();
-	uCout << uAcquire << setw(3) << starttime - ::Start << "\t" << id << " goes to WASH (priority " <<
-	    uThisTask().uGetActivePriority() << ")" << endl << uRelease;
+	starttime = uThisProcessor().getClock().getTime();
+	osacquire( cout ) << setw(3) << starttime - ::Start << "\t" << id << " goes to WASH (priority " <<
+	    uThisTask().getActivePriority() << ")" << endl;
 
 	// The loop below must deal with asynchronous advancing of variable
 	// "delay" during context switches. A problem occurs when "delay" is
@@ -94,24 +97,24 @@ uRealTimeMonitor RestRoom {
 	// or new (i.e., becomes larger) value, the comparision does not cause
 	// a premature exit.
 
-	delay = uThisProcessor().uGetClock().uGetTime() + C2;
+	delay = uThisProcessor().getClock().getTime() + C2;
 	{
 	    AcrossCxtSw acrossCxtSw( delay );
 	    do {
 		for ( int i = 0; i < Delay; i += 1 );	// don't spend too much time in non-interruptible clock routine
-		currtime = uThisProcessor().uGetClock().uGetTime();
+		currtime = uThisProcessor().getClock().getTime();
 	    } while ( delay > currtime );
 	}
 
-	endtime = uThisProcessor().uGetClock().uGetTime();
-	uCout << uAcquire << setw(3) << endtime - ::Start << "\t" << id << " finished with WASH " <<
-	    setw(3) << endtime - starttime << " seconds later (priority " << uThisTask().uGetActivePriority() << ")" << endl << uRelease;
+	endtime = uThisProcessor().getClock().getTime();
+	osacquire( cout ) << setw(3) << endtime - ::Start << "\t" << id << " finished with WASH " <<
+	    setw(3) << endtime - starttime << " seconds later (priority " << uThisTask().getActivePriority() << ")" << endl;
     } // Toilet::Wash
 }; // RestRoom
 
 RestRoom restroom;
 
-uPeriodicTask Philosopher {
+_PeriodicTask Philosopher {
     uDuration C1, C2;
     int id;
 
@@ -121,8 +124,8 @@ uPeriodicTask Philosopher {
     } // Philosopher::main
   public:
     Philosopher( int id, uDuration period, uDuration toilet, uDuration wash, uCluster &clust ) :
-	    uPeriodicBaseTask( period, uTime(0,0), uThisProcessor().uGetClock().uGetTime()+90, period, clust ),
-//	    uPeriodicBaseTask( period, uTime(0,0), uTime(0,0), period, clust),
+	    uPeriodicBaseTask( period, uTime(0,0), uThisProcessor().getClock().getTime()+90, period, clust ),
+//	    uPeriodicBaseTask( period, uTime(0,0), uTime(0,0), period, clust ),
 	    C1( toilet ), C2( wash ), id( id ) {
     } // Philosopher::Philosopher
 }; // Philosopher
@@ -137,11 +140,11 @@ void uMain::main() {
 	Philosopher t3( 3, 40, 6, 4, RTClust );
 	Philosopher t4( 4, 50, 8, 5, RTClust );
 
-	uCout << uAcquire << "Time  \t\tPhilosopher" << endl << uRelease;
+	osacquire( cout ) << "Time  \t\tPhilosopher" << endl;
 
-	::Start = uThisProcessor().uGetClock().uGetTime();
+	::Start = uThisProcessor().getClock().getTime();
 	p = new uProcessor( RTClust );			// now create the processor to do the work
     }
     delete p;
-    uCout << uAcquire << "successful completion" << endl << uRelease;
+    osacquire( cout ) << "successful completion" << endl;
 } // uMain::main
