@@ -1,18 +1,17 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // SemaphoreBB.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Thu Aug 15 16:42:42 1991
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Nov 21 08:53:08 2003
-// Update Count     : 53
+// Last Modified On : Sun Jul 31 18:48:08 2005
+// Update Count     : 54
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
 #include <uSemaphore.h>
 
 template<typename ELEMTYPE> class BoundedBuffer {
