@@ -1,49 +1,52 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Philipp E. Lim 1996
+// uC++ Version 5.3.0, Copyright (C) Philipp E. Lim 1996
 // 
 // Sleep.cc -- 
 // 
 // Author           : Philipp E. Lim
 // Created On       : Wed Jan 10 17:02:39 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jan 29 08:35:57 2004
-// Update Count     : 16
+// Last Modified On : Sat Dec  3 09:41:53 2005
+// Update Count     : 22
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
+#include <iostream>
+using std::cout;
+using std::osacquire;
+using std::endl;
 
 uClock Clock;
 volatile int x = 0, y = 1;
 
-uTask fred {
+_Task fred {
     void main() {
 	uTime start, end;
 	for ( ;; ) {
 	  if ( x == 20 ) break;
 	    if ( x < y ) x += 1;
-	    start = Clock.uGetTime();
-	    uTimeout( uDuration( 1 ) );
-	    end = Clock.uGetTime();
-	    uCout << uAcquire << "fred slept for " << end - start << " seconds" << endl << uRelease;
+	    start = Clock.getTime();
+	    _Timeout( uDuration( 1 ) );
+	    end = Clock.getTime();
+	    osacquire( cout ) << "fred slept for " << end - start << " seconds" << endl;
 	} // for
-	uCout << uAcquire << "fred finished" << endl << uRelease;
+	osacquire( cout ) << "fred finished" << endl;
     } // fred::main
 }; // fred
 
-uTask mary {
+_Task mary {
     void main() {
 	uTime start, end;
 	for ( ;; ) {
 	  if ( y == 20 ) break;
 	    if ( y == x ) y += 1;
-	    start = Clock.uGetTime();
-	    uTimeout( uDuration( 2 ) );
-	    end = Clock.uGetTime();
-	    uCout << uAcquire << "mary slept for " << end - start << " seconds" << endl << uRelease;
+	    start = Clock.getTime();
+	    _Timeout( uDuration( 2 ) );
+	    end = Clock.getTime();
+	    osacquire( cout ) << "mary slept for " << end - start << " seconds" << endl;
 	} // for
-	uCout << uAcquire << "mary finished" << endl << uRelease;
+	osacquire( cout ) << "mary finished" << endl;
     } // mary::main
 }; // mary
 
