@@ -1,18 +1,17 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // SpinLock.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Feb 13 15:47:48 1995
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jan 29 08:37:29 2004
-// Update Count     : 12
+// Last Modified On : Sun Jul 31 18:49:52 2005
+// Update Count     : 15
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
 
 unsigned int uDefaultPreemption() {
     return 1;
@@ -32,12 +31,12 @@ void CriticalSection() {
 
 uSpinLock Lock;
 
-uTask Tester {
+_Task Tester {
     void main() {
 	for ( int i = 1; i <= 10000; i += 1 ) {
-	    ::Lock.uAcquire();
+	    ::Lock.acquire();
 	    CriticalSection();				// critical section
-	    ::Lock.uRelease();
+	    ::Lock.release();
 	} // for
     } // main
   public:
