@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // TimeSlice.cc -- test time slice
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Apr 26 11:04:37 1993
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jan 29 08:41:53 2004
-// Update Count     : 30
+// Last Modified On : Mon Jun 13 15:30:31 2005
+// Update Count     : 32
 // 
 
 #include <uC++.h>
@@ -19,7 +19,7 @@ unsigned int uDefaultPreemption() {
 
 volatile int x = 0, y = 1;
 
-uTask T1 {
+_Task T1 {
     void main() {
 	for ( ;; ) {
 	  if ( x == 100 ) break;
@@ -28,7 +28,7 @@ uTask T1 {
     } // T1::main
 }; // T1
 
-uTask T2 {
+_Task T2 {
     void main() {
 	for ( ;; ) {
 	  if ( y == 100 ) break;
