@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uCalibrate.cc -- Calibrate the number of iterations of a set piece of code
 //    to produce a 100 microsecond delay.
@@ -8,19 +8,21 @@
 // Author           : Peter A. Buhr
 // Created On       : Fri Aug 16 14:12:08 1991
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Jun 23 19:52:34 2004
-// Update Count     : 19
+// Last Modified On : Sun Jul 31 18:53:16 2005
+// Update Count     : 21
 // 
 
 #include <uC++.h>
-#include <uIOStream.h>
+#include <iostream>
+using std::cout;
+using std::endl;
 
 #include "Time.h"
 
 #define TIMES 10000000					// cannot be larger or overflow occurs
 
 void uMain::main() {
-    int i;
+    volatile int i;
     int StartTime, EndTime;
     
     StartTime = Time();
@@ -28,7 +30,7 @@ void uMain::main() {
     } // for
     EndTime = Time();
 
-    uCout << "#define ITERATIONS_FOR_100USECS " << ( 100 * TIMES ) / ( EndTime - StartTime ) << endl;
+    cout << "#define ITERATIONS_FOR_100USECS " << ( 100 * TIMES ) / ( EndTime - StartTime ) << endl;
 } // uMain::main
 
 // Local Variables: //
