@@ -1,31 +1,31 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uContext.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Thu Jul  7 13:08:01 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sun Aug  8 08:53:23 2004
-// Update Count     : 11
+// Last Modified On : Sun Jul 31 18:53:41 2005
+// Update Count     : 14
 // 
 
 #include <uC++.h>
 #include <cstdio>
 
-// WARNING: Do not use uCout or uCerr in uSave or uRestore as they cause a
+// WARNING: Do not use cout or cerr in save or restore as they cause a
 // recursive context switch (BAD!).
 
 class uCoProcessorCxt1 : public uContext {
     static int uUniqueKey;
   public:
     uCoProcessorCxt1() : uContext( &uUniqueKey ) {};
-    void uSave() {
-	printf( "uCoProcessorCxt1::uSave\n" );
+    void save() {
+	printf( "uCoProcessorCxt1::save\n" );
     }
-    void uRestore() {
-	printf( "uCoProcessorCxt1::uRestore\n" );
+    void restore() {
+	printf( "uCoProcessorCxt1::restore\n" );
     }
 }; // uCoProcessorCxt1
 
@@ -33,11 +33,11 @@ int uCoProcessorCxt1::uUniqueKey = 0;
 
 class uCoProcessorCxt2 : public uContext {
   public:
-    void uSave() {
-	printf( "uCoProcessorCxt2::uSave\n" );
+    void save() {
+	printf( "uCoProcessorCxt2::save\n" );
     }
-    void uRestore() {
-	printf( "uCoProcessorCxt2::uRestore\n" );
+    void restore() {
+	printf( "uCoProcessorCxt2::restore\n" );
     }
 }; // uCoProcessorCxt2
 
@@ -46,7 +46,7 @@ void uMain::main() {
     uCoProcessorCxt2 cpCxt21, cpCxt22;
 
     for ( int i = 0; i < 5; i += 1 ) {
-	uYield();
+	yield();
     } // for
 } // uMain::main
     
