@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1995
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1995
 // 
 // uAssert.h -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Sun Jun 11 15:48:38 1995
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Jul 19 10:17:10 2004
-// Update Count     : 26
+// Last Modified On : Wed Jan  4 12:03:03 2006
+// Update Count     : 27
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -29,12 +29,12 @@
 
 #undef uAssert
 
-#ifdef NDEBUG
+#if defined( NDEBUG ) || ! defined( __U_DEBUG__ )
 #define	uAssert(expr) ((void)0)
 #else
 void uAbort( const char *fmt, ... );
 #define uAssert(expr) if ( ! (expr) ) { uAbort( "Assertion (" #expr ") failed at line %d in file \"" __FILE__ "\".", __LINE__ ); }
-#endif // NDEBUG
+#endif
 
 
 // Local Variables: //
