@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uBootTask.h -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Thu Apr 28 11:54:04 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Sep  1 21:03:11 2003
-// Update Count     : 24
+// Last Modified On : Mon Jun 13 14:29:17 2005
+// Update Count     : 26
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -29,7 +29,7 @@
 #define __U_BOOTTASK_H__
 
 
-uTask uBootTask {
+_Task uBootTask {
     friend class uKernelBoot;				// access: new
 
     void main();
