@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Philipp E. Lim 1995
+// uC++ Version 5.3.0, Copyright (C) Philipp E. Lim 1995
 // 
 // uCalendar.h -- 
 // 
 // Author           : Philipp E. Lim
 // Created On       : Tue Dec 19 11:58:22 1995
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Aug 10 13:21:33 2004
-// Update Count     : 231
+// Last Modified On : Sat Dec  3 10:26:45 2005
+// Update Count     : 237
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -37,6 +37,7 @@
 
 #include <ctime>
 #include <sys/time.h>
+#include <iosfwd>
 
 
 #define CLOCKGRAN 15000000L				// ALWAYS in nanoseconds, MUST BE less than 1 second
@@ -60,7 +61,6 @@
 class uDuration;					// forward declaration
 class uTime;						// forward declaration
 class uClock;						// forward declaration
-class uOStream;						// forward declaration
 
 
 //######################### uDuration #########################
@@ -80,7 +80,7 @@ bool operator>( uDuration op1, uDuration op2 );		// forward declaration
 bool operator<( uDuration op1, uDuration op2 );		// forward declaration
 bool operator>=( uDuration op1, uDuration op2 );	// forward declaration
 bool operator<=( uDuration op1, uDuration op2 );	// forward declaration
-uOStream &operator<<( uOStream &os, const uDuration op ); // forward declaration
+std::ostream &operator<<( std::ostream &os, const uDuration op ); // forward declaration
 
 
 //######################### uTime #########################
@@ -96,7 +96,7 @@ bool operator>( uTime op1, uTime op2 );			// forward declaration
 bool operator<( uTime op1, uTime op2 );			// forward declaration
 bool operator>=( uTime op1, uTime op2 );		// forward declaration
 bool operator<=( uTime op1, uTime op2 );		// forward declaration
-uOStream &operator<<( uOStream &os, const uTime op );	// forward declaration
+std::ostream &operator<<( std::ostream &os, const uTime op ); // forward declaration
 
 
 //######################### uDuration (cont) #########################
@@ -120,7 +120,7 @@ class uDuration {
     friend bool operator>=( uDuration op1, uDuration op2 ); 
     friend bool operator<=( uDuration op1, uDuration op2 );
     friend uDuration abs( uDuration op );
-    friend uOStream &operator<<( uOStream &os, const uDuration op );
+    friend std::ostream &operator<<( std::ostream &os, const uDuration op );
 
     friend uDuration operator-( uTime op1, uTime op2 );
     friend uTime operator-( uTime op1, uDuration op2 );
@@ -154,12 +154,12 @@ class uDuration {
 	return *this;
     } // uDuration::operator*=
 
-    uDuration &uDuration::operator/=( long long int op ) {
+    uDuration &operator/=( long long int op ) {
 	*this = *this / op;
 	return *this;
     } // uDuration::operator/=
 
-    long long int uDuration::nanoseconds() const {
+    long long int nanoseconds() const {
 	return tv;
     } // uDuration::nanoseconds
 
@@ -261,7 +261,7 @@ class uTime {
     friend bool operator<( uTime op1, uTime op2 );
     friend bool operator>=( uTime op1, uTime op2 ); 
     friend bool operator<=( uTime op1, uTime op2 );
-    friend uOStream &operator<<( uOStream &os, const uTime op );
+    friend std::ostream &operator<<( std::ostream &os, const uTime op );
 
 #ifdef __U_DEBUG__
     static const char *uCreateFmt;
@@ -279,7 +279,7 @@ class uTime {
     // recursion problems because uTime values are created from the sigalrm
     // handler in composing the next context switch event.
 
-    uTime::uTime( long int sec ) {
+    uTime( long int sec ) {
 	tv = (long long int)sec * TIMEGRAN;
 #ifdef __U_DEBUG__
 	if ( tv < 0 || tv > 2147483647LL * TIMEGRAN ) {	// between 00:00:00 UTC, January 1, 1970 and 03:14:07 UTC, January 19, 2038.
@@ -288,7 +288,7 @@ class uTime {
 #endif // __U_DEBUG__
     } // uTime::uTime
 
-    uTime::uTime( long int sec, long int nsec ) {
+    uTime( long int sec, long int nsec ) {
 	tv = (long long int)sec * TIMEGRAN + nsec;
 #ifdef __U_DEBUG__
 	if ( tv < 0 || tv > 2147483647LL * TIMEGRAN ) {	// between 00:00:00 UTC, January 1, 1970 and 03:14:07 UTC, January 19, 2038.
@@ -394,18 +394,19 @@ class uClock {
     } // uClock::uClock
 
     uClock( uTime adj ) {
-	uResetClock( adj );
+	resetClock( adj );
     } // uClock::uClock
 
-    uTime uGetTime();
-    void uGetTime( int &year, int &month, int &day, int &hour, int &minutes, int &seconds, long int &nsec );
-    static void uConvertTime( uTime time, int &year, int &month, int &day, int &hour, int &minutes, int &seconds, long int &nsec );
-
-    void uClock::uResetClock() {
+    void resetClock() {
 	clocktype = CLOCK_REALTIME;
-    } // uClock::uResetClock
+    } // uClock::resetClock
 
-    void uResetClock( uTime adj );
+    void resetClock( uTime adj );
+
+    uTime getTime();
+    void getTime( int &year, int &month, int &day, int &hour, int &minutes, int &seconds, long int &nsec );
+
+    static void convertTime( uTime time, int &year, int &month, int &day, int &hour, int &minutes, int &seconds, long int &nsec );
 }; // uClock
 
 
