@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uCluster.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Mon Mar 14 17:34:24 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Sep  7 11:57:21 2004
-// Update Count     : 372
+// Last Modified On : Sat Dec 17 11:12:08 2005
+// Update Count     : 403
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -29,23 +29,13 @@
 
 
 #include <uC++.h>
+#include <uProfiler.h>
 #include <uAssert.h>
 //#include <uDebug.h>
 
-#if defined( __solaris__ )
+#if defined( __solaris__ ) && ! defined( __U_PTHREAD__ )
 #include <sys/lwp.h>					// needed for _lwp_kill
-#endif
-
-extern uCluster &uThisCluster() {
-    return *THREAD_GETMEM( uActiveCluster );
-} // uThisCluster
-
-
-//######################### uClusterDL #########################
-
-
-uClusterDL::uClusterDL( uCluster &w ) : uWho( w ) {}
-uCluster &uClusterDL::uGet() const { return uWho; }
+#endif // __solaris__ && ! __U_PTHREAD__
 
 
 //######################### uCluster #########################
@@ -60,15 +50,17 @@ void *uCluster::operator new( size_t size ) {
 } // uCluster::operator new
 
 
-void uCluster::uWakeProcessor( int uPid ) {
+void uCluster::uWakeProcessor( uPid_t uPid ) {
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uCluster &)0x%p.uWakeProcessor: waking processor %d\n", this, uPid );
+    uDebugPrt( "uCluster::uWakeProcessor: waking processor %lu\n", (unsigned long)uPid );
 #endif // __U_DEBUG_H__
 
-#if defined( __solaris__ )
-    _lwp_kill( uPid, SIGALRM );
+#if defined( __U_PTHREAD__ )
+    uRealPthread::pthread_kill( uPid, SIGUSR1 );
+#elif defined( __solaris__ )
+    _lwp_kill( uPid, SIGUSR1 );
 #else
-    kill( uPid, SIGALRM );				// wake it up, as it is probably sleeping
+    kill( uPid, SIGUSR1 );				// wake it up, as it is probably sleeping
 #endif
 } // uCluster::uWakeProcessor
 
@@ -80,7 +72,7 @@ void uCluster::uProcessorPause() {
     // queue since the processor last checked.
 
     uReadyIdleTaskLock.acquire();
-    if ( uReadyTasksEmpty() && uThisProcessor().uExternal.uEmpty() ) {
+    if ( uReadyTasksEmpty() && uThisProcessor().uExternal.empty() ) {
 	// stop generating SIGALRM signals on this processor until woken up
 
 	uThisProcessor().uSetContextSwitchEvent( 0 );	// turn off context-switching
@@ -89,18 +81,19 @@ void uCluster::uProcessorPause() {
 	sigset_t new_mask, mask;
 	sigemptyset( &new_mask );
 	sigaddset( &new_mask, SIGALRM );
+	sigaddset( &new_mask, SIGUSR1 );
 	if ( sigprocmask( SIG_BLOCK, &new_mask, &mask ) == -1 ) {
 	    uAbort( "internal error, sigprocmask" );
 	} // if
 
-	if ( THREAD_GETMEM( uInKernelRF ) ) { // in kernel roll-forward flag on ?
+	if ( THREAD_GETMEM( InKernelRF ) ) {		// in kernel roll-forward flag on ?
 	        uReadyIdleTaskLock.release();
 		if ( sigprocmask( SIG_SETMASK, &mask, NULL ) == -1 ) {
 		    uAbort( "internal error, sigprocmask" );
 		} // if
-		THREAD_GETMEM( uSelf )->uRollForward( true ); // make sure to do chores
+		THREAD_GETMEM( uSelf )->rollForward( true ); // make sure to do chores
 	} else {
-	    uIdleProcessors.uAddTail( &(uThisProcessor().uIdleRef) );
+	    uIdleProcessors.addTail( &(uThisProcessor().uIdleRef) );
 	    uReadyIdleTaskLock.release();
 
 	    // Install the old signal mask and wait for a signal to arrive.
@@ -123,7 +116,7 @@ void uCluster::uProcessorPause() {
 	    if ( uThisProcessor().uIdle() ) {
 		uReadyIdleTaskLock.acquire();
 		if ( uThisProcessor().uIdle() ) {
-		    uIdleProcessors.uRemove( &(uThisProcessor().uIdleRef) );
+		    uIdleProcessors.remove( &(uThisProcessor().uIdleRef) );
 		} // if
 		uReadyIdleTaskLock.release();
 	    } // if
@@ -134,15 +127,15 @@ void uCluster::uProcessorPause() {
 	    // Therefore, do a roll-forward to ensure that any necessary events
 	    // are popped from the event list.
 
-	    THREAD_GETMEM( uSelf )->uRollForward( true );
+	    THREAD_GETMEM( uSelf )->rollForward( true );
 	} // if
 
 	// Reset the context-switch
 
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uCluster &)0x%p.uProcessorPause, reset timeslice:%d\n", this, uThisProcessor().uGetPreemption() );
+	uDebugPrt( "(uCluster &)0x%p.uProcessorPause, reset timeslice:%d\n", this, uThisProcessor().getPreemption() );
 #endif // __U_DEBUG_H__
-	uThisProcessor().uSetContextSwitchEvent( uThisProcessor().uGetPreemption() );
+	uThisProcessor().uSetContextSwitchEvent( uThisProcessor().getPreemption() );
     } else {
 	uReadyIdleTaskLock.release();
     } // if
@@ -153,24 +146,30 @@ void uCluster::uProcessorPause() {
 
 void uCluster::uMakeProcessorIdle( uProcessor &p ) {
     uReadyIdleTaskLock.acquire();
-    uIdleProcessors.uAddTail( &(p.uIdleRef) );
+    uIdleProcessors.addTail( &(p.uIdleRef) );
     uReadyIdleTaskLock.release();
 } // uCluster::uMakeProcessorIdle
 
 
 void uCluster::uMakeProcessorActive( uProcessor &p ) {
+#ifdef __U_DEBUG_H__
+    uDebugPrt( "(uCluster &)0x%p.uMakeProcessorActive(1)\n", this );
+#endif // __U_DEBUG_H__
     uReadyIdleTaskLock.acquire();
     if ( p.uIdle() ) {					// processor on idle queue ?
-	uIdleProcessors.uRemove( &(p.uIdleRef) );
+	uIdleProcessors.remove( &(p.uIdleRef) );
     } // if
     uReadyIdleTaskLock.release();
 } // uCluster::uMakeProcessorActive
 
 
 void uCluster::uMakeProcessorActive() {
+#ifdef __U_DEBUG_H__
+    uDebugPrt( "(uCluster &)0x%p.uMakeProcessorActive(2)\n", this );
+#endif // __U_DEBUG_H__
     uReadyIdleTaskLock.acquire();
-    if ( ! uReadyTasks->uEmpty() && ! uIdleProcessors.uEmpty() ) {
-	int uPid = uIdleProcessors.uDropHead()->uGet().uPid;
+    if ( ! uReadyTasks->empty() && ! uIdleProcessors.empty() ) {
+	uPid_t uPid = uIdleProcessors.dropHead()->uGet().uPid;
 	uReadyIdleTaskLock.release();			// don't hold lock while sending SIGALRM
 	uWakeProcessor( uPid );
     } else {
@@ -180,7 +179,7 @@ void uCluster::uMakeProcessorActive() {
 
 
 bool uCluster::uReadyTasksEmpty() {
-    return uReadyTasks->uEmpty();
+    return uReadyTasks->empty();
 } // uCluster::uReadyTasksEmpty
 
 
@@ -189,14 +188,14 @@ void uCluster::uMakeTaskReady( uBaseTask &uReadyTask ) {
     if ( &uReadyTask.uBound != NULL ) {			// task bound to a specific processor ?
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "(uCluster &)0x%p.uMakeTaskReady(1): task %.256s (0x%p) makes task %.256s (0x%p) ready\n",
-		  this, uThisTask().uGetName(), &uThisTask(), uReadyTask.uGetName(), &uReadyTask );
+		  this, uThisTask().getName(), &uThisTask(), uReadyTask.getName(), &uReadyTask );
 #endif // __U_DEBUG_H__
 	uProcessor *p = &uReadyTask.uBound;		// optimization
-	p->uExternal.uAddTail( &(uReadyTask.uReadyRef) ); // add task to end of special ready queue
+	p->uExternal.addTail( &(uReadyTask.uReadyRef) ); // add task to end of special ready queue
 #ifdef __U_MULTI__
 	if ( p->uIdle() ) {				// processor on idle queue ?
-	    uIdleProcessors.uRemove( &(p->uIdleRef) );
-	    int uPid = p->uPid;
+	    uIdleProcessors.remove( &(p->uIdleRef) );
+	    uPid_t uPid = p->uPid;
 	    uReadyIdleTaskLock.release();		// don't hold lock while sending SIGALRM
 	    uWakeProcessor( uPid );
 	} else {
@@ -208,7 +207,7 @@ void uCluster::uMakeTaskReady( uBaseTask &uReadyTask ) {
     } else {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "(uCluster &)0x%p.uMakeTaskReady(2): task %.256s (0x%p) makes task %.256s (0x%p) ready\n",
-		   this, uThisTask().uGetName(), &uThisTask(), uReadyTask.uGetName(), &uReadyTask );
+		   this, uThisTask().getName(), &uThisTask(), uReadyTask.getName(), &uReadyTask );
 #endif // __U_DEBUG_H__
 #ifdef __U_MULTI__
 	// Wake up an idle processor if the ready task is migrating to another
@@ -217,17 +216,17 @@ void uCluster::uMakeTaskReady( uBaseTask &uReadyTask ) {
 	// prevents a single task on a cluster, which does a yield, from
 	// unnecessarily waking up a processor that has no work to do.
 
-	if ( ! uIdleProcessors.uEmpty() && ( &uThisCluster() != this || ! uReadyTasks->uEmpty() ) ) {
-	    uReadyTasks->uAdd( &(uReadyTask.uReadyRef) ); // add task to end of cluster ready queue
-	    int uPid = uIdleProcessors.uDropHead()->uGet().uPid;
+	if ( ! uIdleProcessors.empty() && ( &uThisCluster() != this || ! uReadyTasks->empty() ) ) {
+	    uReadyTasks->add( &(uReadyTask.uReadyRef) ); // add task to end of cluster ready queue
+	    uPid_t uPid = uIdleProcessors.dropHead()->uGet().uPid;
 	    uReadyIdleTaskLock.release();		// don't hold lock while sending SIGALRM
 	    uWakeProcessor( uPid );
 	} else {
-	    uReadyTasks->uAdd( &(uReadyTask.uReadyRef) ); // add task to end of cluster ready queue
+	    uReadyTasks->add( &(uReadyTask.uReadyRef) ); // add task to end of cluster ready queue
 	    uReadyIdleTaskLock.release();
 	} // if
 #else
-	uReadyTasks->uAdd( &(uReadyTask.uReadyRef) );	// add task to end of cluster ready queue
+	uReadyTasks->add( &(uReadyTask.uReadyRef) );	// add task to end of cluster ready queue
 	uReadyIdleTaskLock.release();
 #endif // __U_MULTI__
     } // if
@@ -242,7 +241,7 @@ uBaseTask &uCluster::uReadyTaskTryRemove() {
 
     uReadyIdleTaskLock.acquire();
     if ( ! uReadyTasksEmpty() ) {
-	t = &(uReadyTasks->uDrop()->uGet());
+	t = &(uReadyTasks->drop()->uGet());
     } else {
 	t = NULL;
     } // if
@@ -253,16 +252,16 @@ uBaseTask &uCluster::uReadyTaskTryRemove() {
 
 void uCluster::uTaskAdd( uBaseTask &t ) {
     uReadyIdleTaskLock.acquire();
-    uTasksOnCluster.uAddTail( &(t.uClusterRef) );
-    if ( &t.uBound == NULL ) uReadyTasks->uAddInitialize( uTasksOnCluster ); // processor task is not part of normal initialization
+    uTasksOnCluster.addTail( &(t.uClusterRef) );
+    if ( &t.uBound == NULL ) uReadyTasks->addInitialize( uTasksOnCluster ); // processor task is not part of normal initialization
     uReadyIdleTaskLock.release();
 } // uCluster::uTaskAdd
 
 
 void uCluster::uTaskRemove( uBaseTask &t ) {
     uReadyIdleTaskLock.acquire();
-    uTasksOnCluster.uRemove( &(t.uClusterRef) );
-    if ( &t.uBound == NULL ) uReadyTasks->uRemoveInitialize( uTasksOnCluster ); // processor task is not part of normal initialization
+    uTasksOnCluster.remove( &(t.uClusterRef) );
+    if ( &t.uBound == NULL ) uReadyTasks->removeInitialize( uTasksOnCluster ); // processor task is not part of normal initialization
     uReadyIdleTaskLock.release();
 } // uCluster::uTaskRemove
 
@@ -279,7 +278,7 @@ void uCluster::uTaskResetPriority( uBaseTask &owner, uBaseTask &calling ) { // T
     uDebugPrt( "(uCluster &)0x%p.uTaskResetPriority, owner:0x%p, calling:0x%p, owner's cluster:0x%p\n", this, &owner, &calling, owner.uCurrCluster );
 #endif // __U_DEBUG_H__
     uReadyIdleTaskLock.acquire();
-    if ( &uThisCluster() == owner.uCurrCluster ) {
+    if ( &uThisCluster() == owner.currCluster ) {
 	if ( uReadyTasks->uCheckPriority( owner.uReadyRef, calling.uReadyRef ) ) {
 	    uReadyTasks->uResetPriority( owner.uReadyRef, calling.uReadyRef );
 	} // if
@@ -300,14 +299,14 @@ void uCluster::uTaskSetPriority( uBaseTask &owner, uBaseTask &calling ) {
 
 void uCluster::uProcessorAdd( uProcessor &p ) {
     uProcessorsOnClusterLock.acquire();
-    uProcessorsOnCluster.uAddTail( &(p.uProcessorRef) );
+    uProcessorsOnCluster.addTail( &(p.uProcessorRef) );
     uProcessorsOnClusterLock.release();
 } // uCluster::uProcessorAdd
 
 
 void uCluster::uProcessorRemove( uProcessor &p ) {
     uProcessorsOnClusterLock.acquire();
-    uProcessorsOnCluster.uRemove( &(p.uProcessorRef) );
+    uProcessorsOnCluster.remove( &(p.uProcessorRef) );
     uProcessorsOnClusterLock.release();
 } // uCluster::uProcessorRemove
 
@@ -325,15 +324,15 @@ void uCluster::uCreateCluster( unsigned int stacksize, const char *name ) {
 #endif // __U_MULTI__
 #endif // __U_DEBUG__
 
-    uSetName( name );
-    uSetStackSize( stacksize );
+    setName( name );
+    setStackSize( stacksize );
 
 #if __U_LOCALDEBUGGER_H__
     if ( uLocalDebugger::uLocalDebuggerActive ) uLocalDebugger::uLocalDebuggerInstance->checkPoint();
 #endif // __U_LOCALDEBUGGER_H__
 
     uKernelModule::uGlobalClusterLock->acquire();
-    uKernelModule::uGlobalClusters->uAddTail( &uGlobalRef );
+    uKernelModule::uGlobalClusters->addTail( &uGlobalRef );
     uKernelModule::uGlobalClusterLock->release();
 
 #if __U_LOCALDEBUGGER_H__
@@ -350,6 +349,10 @@ void uCluster::uCreateCluster( unsigned int stacksize, const char *name ) {
 #ifdef __U_MULTI__
     NBIO = new uNBIO;
 #endif // __U_MULTI__
+
+    if ( uProfiler::uProfiler_RegisterCluster ) {
+	(*uProfiler::uProfiler_RegisterCluster)( uProfiler::uProfilerInstance, *this );
+    } // if
 } // uCluster::uCreateCluster
 
 
@@ -398,6 +401,10 @@ uCluster::~uCluster() {
     uDebugPrt( "(uCluster &)0x%p.~uCluster\n", this );
 #endif // __U_DEBUG_H__
 
+    if ( uProfiler::uProfiler_DeregisterCluster ) {
+	(*uProfiler::uProfiler_DeregisterCluster)( uProfiler::uProfilerInstance, *this );
+    } // if
+
 #ifdef __U_MULTI__
     delete NBIO;
 #endif // __U_MULTI__
@@ -407,19 +414,19 @@ uCluster::~uCluster() {
     // processor task, and hence, there is always a task on the cluster.
     uProcessorDL *pr;
     uProcessorsOnClusterLock.acquire();
-    for ( uSeqGen<uProcessorDL> gen2(uProcessorsOnCluster); gen2 >> pr; ) {
-	uAbort( ": attempt to delete cluster %.256s (0x%p) with processor 0x%p still on it.\n"
+    for ( uSeqIter<uProcessorDL> iter(uProcessorsOnCluster); iter >> pr; ) {
+	uAbort( "Attempt to delete cluster %.256s (0x%p) with processor 0x%p still on it.\n"
 		"Possible cause is the processor has not been deleted.",
-		uGetName(), this, &(pr->uGet()) );
+		getName(), this, &(pr->uGet()) );
     } // for
     uProcessorsOnClusterLock.release();
 
     uBaseTaskDL *tr;
     uReadyIdleTaskLock.acquire();
-    for ( uSeqGen<uBaseTaskDL> gen1(uTasksOnCluster); gen1 >> tr; ) {
-	uAbort( ": attempt to delete cluster %.256s (0x%p) with task %.256s (0x%p) still on it.\n"
+    for ( uSeqIter<uBaseTaskDL> iter(uTasksOnCluster); iter >> tr; ) {
+	uAbort( "Attempt to delete cluster %.256s (0x%p) with task %.256s (0x%p) still on it.\n"
 		"Possible cause is the task has not been deleted.",
-		uGetName(), this, tr->uGet().uGetName(), &(tr->uGet()) );
+		getName(), this, tr->uGet().getName(), &(tr->uGet()) );
     } // for
     uReadyIdleTaskLock.release();
 #endif // __U_DEBUG__
@@ -433,33 +440,33 @@ uCluster::~uCluster() {
 #endif // __U_LOCALDEBUGGER_H__
 
     uKernelModule::uGlobalClusterLock->acquire();
-    uKernelModule::uGlobalClusters->uRemove( &uGlobalRef );
+    uKernelModule::uGlobalClusters->remove( &uGlobalRef );
     uKernelModule::uGlobalClusterLock->release();
 } // uCluster::~uCluster
 
-const char *uCluster::uSetName( const char *name ) {
+const char *uCluster::setName( const char *name ) {
     const char *prev = uName;
     uName = name;
     return prev;
-} // uCluster::uSetName
+} // uCluster::setName
 
-const char *uCluster::uGetName() const {
+const char *uCluster::getName() const {
     return
 #ifdef __U_DEBUG__
 	( uName == NULL || uName == (const char *)-1 ) ? "*unknown*" : // storage might be scrubbed
 #endif // __U_DEBUG__
 	uName;
-} // uCluster::uGetName
+} // uCluster::getName
 
-unsigned int uCluster::uSetStackSize( unsigned int stacksize ) {
+unsigned int uCluster::setStackSize( unsigned int stacksize ) {
     unsigned int prev = uStackSize;
     uStackSize = stacksize;
     return prev;
-} // uCluster::uSetStackSize
+} // uCluster::setStackSize
 
-unsigned int uCluster::uGetStackSize() const {
+unsigned int uCluster::getStackSize() const {
     return uStackSize;
-} // uCluster::uGetStackSize
+} // uCluster::getStackSize
 
 void uCluster::uCloseFD( int fd ) {
     NBIO->uCloseFD(fd);
