@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1997
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1997
 // 
 // uDefault.h -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Thu Mar 20 18:12:31 1997
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Sep  1 23:27:23 2003
-// Update Count     : 11
+// Last Modified On : Fri Apr 22 18:48:17 2005
+// Update Count     : 13
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -55,7 +55,12 @@
 // Define the default stack size in bytes.  Change the implicit default stack
 // size for a task or coroutine created on a particular cluster.
 
+#if defined( __ia64__ )
+// needed by IA64 unwind library
+#define __U_DEFAULT_STACK_SIZE__ 60000
+#else
 #define __U_DEFAULT_STACK_SIZE__ 30000
+#endif // __ia64__
 
 
 extern unsigned int uDefaultHeapExpansion();		// default heap expansion size (bytes)
