@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Russell Mok 1997
+// uC++ Version 5.3.0, Copyright (C) Russell Mok 1997
 // 
 // uEHM.cc -- 
 // 
 // Author           : Russell Mok
 // Created On       : Sun Jun 29 00:15:09 1997
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Aug 31 22:37:28 2004
-// Update Count     : 364
+// Last Modified On : Mon Dec 12 09:00:21 2005
+// Update Count     : 478
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -29,12 +29,15 @@
 #include <uC++.h>
 //#include <uDebug.h>
 
+#include <cxxabi.h>
+#include "unwind-cxx.h"					// include file copied from gcc 3.4, needed for reraise from a catch-any
 #include <cstring>					// strlen, strncpy, strcpy
 
-#if __GNUC__ == 3 && __GNUC_MINOR__ < 4			// TEMPORARY: bug in uncaught_exception, correction copied from gcc 3.4
-#include "unwind-cxx.h"					// TEMPORARY: include file copied from gcc 3.4 (remove)
+#if __GNUC__ == 3 && __GNUC_MINOR__ < 4 && !defined( __INTEL_COMPILER ) // TEMPORARY: bug in uncaught_exception, correction copied from gcc 3.4
 // Copyright (C) 2001 Free Software Foundation, Inc.
 namespace __cxxabiv1 {
+    // Returns the type_info for the currently handled exception [15.3/8], or
+    // null if there is none.
     extern "C" void *
     __cxa_begin_catch (void *exc_obj_in) throw()
     {
@@ -81,14 +84,33 @@ namespace __cxxabiv1 {
 	return header->adjustedPtr;
     }
 } // namespace __cxxabiv1
-#endif // __GNUC__ == 3 && __GNUC_MINOR__ < 4
+#endif // __GNUC__ == 3 && __GNUC_MINOR__ < 4 && ! __INTEL_COMPILER
 
 
 //######################### std::{C++ exception routines} ########################
 
 
 void uEHM::uTerminate() {
-    uAbort( "Unhandled exception for task %.256s (0x%p)", uThisTask().uGetName(), &uThisTask() );
+    char ExName[uEHMMaxName + sizeof("...")];		// room for "...\0"
+    char ResName[uEHMMaxName + sizeof("...")];
+
+    getCurrentEventName( uThrowF, ExName, uEHMMaxName );
+    getCurrentEventName( uResumeF, ResName, uEHMMaxName );
+
+    bool exception = ExName[0] != '\0';			// optimization
+    bool resumption = ResName[0] != '\0';
+    
+    if ( ! exception && ! resumption ) {
+	uAbort( "Attempt to rethrow/reraise but no active exception.\n"
+		"Possible cause is a rethrow/reraise not directly or indirectly performed from a catch clause." );
+    } // if
+    
+    uAbort( "Propagation failed to find a matching handler.\n"
+	    "Possible cause is a missing try block with appropriate catch clause for specified or derived exception type\n"
+	    "or throwing an exception from within a destructor while propagating an exception.\n"
+	    "%s%s%s%s%s",
+	    (exception  ? "Type of last active exception: "  : ""), (exception  ? ExName  : ""), (exception && resumption ? "\n" : ""),
+	    (resumption ? "Type of last active resumption: " : ""), (resumption ? ResName : "") ); // uAbort puts a "\n"
 } // uEHM::uTerminate
 
 void uEHM::uTerminateHandler() {
@@ -127,16 +149,8 @@ std::unexpected_handler std::set_unexpected( std::unexpected_handler func ) thro
 //######################### uEHM::uAsyncAEMsg ########################
 
 
-uEHM::uAsyncAEMsg::uAsyncAEMsg( const uDualClass &ae_obj, const uFlagT f ) : flag( f ), uHidden( false ) {
-    ae = ae_obj.uDuplicate();
-} // uEHM::uAsyncAEMsg::uAsyncAEMsg
-
-uEHM::uAsyncAEMsg::uAsyncAEMsg( const uThrowClass &ae_obj ) : flag( uThrowF ), uHidden( false ) {
-    ae = ae_obj.uDuplicate();
-} // uEHM::uAsyncAEMsg::uAsyncAEMsg
-
-uEHM::uAsyncAEMsg::uAsyncAEMsg( const uRaiseClass &ae_obj ) : flag( uRaiseF ), uHidden( false ) {
-    ae = ae_obj.uDuplicate();
+uEHM::uAsyncAEMsg::uAsyncAEMsg( const uDualClass &ex, const uFlagT f ) : flag( f ), uHidden( false ) {
+    ae = ex.duplicate();
 } // uEHM::uAsyncAEMsg::uAsyncAEMsg
 
 uEHM::uAsyncAEMsg::~uAsyncAEMsg() {
@@ -154,30 +168,30 @@ uEHM::uAsyncAEMsgBuffer::uAsyncAEMsgBuffer() {
 
 uEHM::uAsyncAEMsgBuffer::~uAsyncAEMsgBuffer() {
     uCSpinLock dummy( lock );
-    for ( uAsyncAEMsg *tmp = uDrop(); tmp; tmp = uDrop() ) {
+    for ( uAsyncAEMsg *tmp = drop(); tmp; tmp = drop() ) {
 	delete tmp;
     } // for
 } // uEHM::uAsyncAEMsgBuffer::~uAsyncAEMsgBuffer
 
 void uEHM::uAsyncAEMsgBuffer::uAddMsg( uAsyncAEMsg *msg ) {
     uCSpinLock dummy( lock );
-    uAdd( msg );
+    add( msg );
 } // uEHM::uAsyncAEMsgBuffer::uAddMsg
 
 uEHM::uAsyncAEMsg *uEHM::uAsyncAEMsgBuffer::uRmMsg() {
     uCSpinLock dummy( lock );
-    return uDrop();
+    return drop();
 } // uEHM::uAsyncAEMsgBuffer::uRmMsg
 
 uEHM::uAsyncAEMsg *uEHM::uAsyncAEMsgBuffer::uRmMsg( uAsyncAEMsg *msg ) {
     // Only lock at the end or the start of the list as these are the only
     // places where interference can occur.
 
-    if ( msg == uTail() || msg == uHead() ) {
+    if ( msg == tail() || msg == head() ) {
 	uCSpinLock dummy( lock );
-	uRemove( msg );
+	remove( msg );
     } else {
-	uRemove( msg );
+	remove( msg );
     } // if
     return msg;
 } // uEHM::uAsyncAEMsgBuffer::uRmMsg
@@ -185,7 +199,7 @@ uEHM::uAsyncAEMsg *uEHM::uAsyncAEMsgBuffer::uRmMsg( uAsyncAEMsg *msg ) {
 uEHM::uAsyncAEMsg *uEHM::uAsyncAEMsgBuffer::uNextVisible( uAsyncAEMsg *msg ) {
     // find the next msg node that is visible or null
     do {						// do-while because current node could be visible
-	msg = uSucc( msg );
+	msg = succ( msg );
     } while ( msg && msg->uHidden );
     return msg;
 } // uEHM::uAsyncAEMsgBuffer::uNextVisible
@@ -194,41 +208,39 @@ uEHM::uAsyncAEMsg *uEHM::uAsyncAEMsgBuffer::uNextVisible( uAsyncAEMsg *msg ) {
 //######################### uDualClass ########################
 
 
-uEHM::uDualClass::uDualClass( const char *const msg ) : msg( msg ), src( uThisCoroutine() ) {
-    const char *name = src.uGetName();
-    int lnth = strlen( name );
-    strncpy( uName, name, uEHMMaxName );
-    if ( lnth > uEHMMaxName ) {				// name too long ?
-	strcpy( &uName[uEHMMaxName], "..." );		// add 4 character ...
-    } // if
+uEHM::uDualClass::uDualClass( const char *const msg ) : src( NULL ) {
+    uStrncpy( uEHM::uDualClass::msg, msg, uEHMMaxMsg );	// copy message
 }; // uEHM::uDualClass::uDualClass
 
 uEHM::uDualClass::~uDualClass() {}
 
-const char *const uEHM::uDualClass::message() const { return msg; }
-const uBaseCoroutine &uEHM::uDualClass::source() const { return src; }
-const char *uEHM::uDualClass::sourceName() const { return uName; }
+const char *uEHM::uDualClass::message() const { return msg; }
+const uBaseCoroutine &uEHM::uDualClass::source() const { return *src; }
+const char *uEHM::uDualClass::sourceName() const { return src != NULL ? srcName : "*unnamed*"; }
 
-const uEHM::uDualClass * const uEHM::uDualClass::setOriginalThrower( const void * p ) const {
+void uEHM::uDualClass::setSrc( uBaseCoroutine &cor ) {
+    src = &cor;
+    uStrncpy( srcName, cor.getName(), uEHMMaxName );	// copy source name
+} // uEHM::uDualClass::setSrc
+
+const uEHM::uDualClass &uEHM::uDualClass::setOriginalThrower( const void * p ) const {
     // Calls to this routine are generated by the translator at each throw
     // site. Because the exception object being thrown may be const, this
     // routine still has to modify the exception object. Hence, the need for
     // the const cast.
     const_cast< uEHM::uDualClass * >(this)->uStaticallyBoundObject = p;
-    return this;
+    return *this;
 } // uEHM::uDualClass::setOriginalThrower
 
 void uEHM::uDualClass::defaultTerminate() const {
 } // uEHM::uDualClass::defaultTerminate
 
 void uEHM::uDualClass::defaultResume() const {
-    uStackThrow();
+    stackThrow();
     // CONTROL NEVER REACHES HERE!
 } // uEHM::uDualClass::defaultResume
 
 
-uInitEvent(uEHM::uDualClass);
-
 
 //######################### uEHM::uThrowClass ########################
 
@@ -243,31 +255,25 @@ void uEHM::uThrowClass::defaultResume() const {
 #endif // __DEBUG__
 
 
-uInitEvent(uEHM::uThrowClass);
+//######################### uEHM::uResumeClass ########################
 
 
-//######################### uEHM::uRaiseClass ########################
+void uEHM::uResumeClass::stackThrow() const {
+    uAbort( "uResumeClass object cannot be thrown." );
+} // uEHM::uResumeClass::stackThrow
 
-
-void uEHM::uRaiseClass::uStackThrow() const {
-    uAbort( "Event cannot be thrown." );
-} // uEHM::uRaiseClass::uStackThrow
-
-uEHM::uRaiseClass::uRaiseClass( const char *const msg ) : uDualClass( msg ) {}
-uEHM::uRaiseClass::~uRaiseClass() {}
+uEHM::uResumeClass::uResumeClass( const char *const msg ) : uDualClass( msg ) {}
+uEHM::uResumeClass::~uResumeClass() {}
 
 #ifdef __DEBUG__
-void uEHM::uRaiseClass::defaultTerminate() const {
-    uAbort( "uRaiseClass object cannot be casted to a throw-able object." );
-} // uEHM::uRaiseClass::defaultTerminate
+void uEHM::uResumeClass::defaultTerminate() const {
+    uAbort( "uResumeClass object cannot be casted to a throw-able object." );
+} // uEHM::uResumeClass::defaultTerminate
 #endif // __DEBUG__
 
-void uEHM::uRaiseClass::defaultResume() const {
+void uEHM::uResumeClass::defaultResume() const {
     uTerminate();
-} // uEHM::uRaiseClass::defaultResume
-
-
-uInitEvent(uEHM::uRaiseClass);
+} // uEHM::uResumeClass::defaultResume
 
 
 //######################### uEHM::uResumptionHandlers ########################
@@ -291,7 +297,7 @@ uEHM::uResumptionHandlers::~uResumptionHandlers() {
 //######################### uEHM::uDeliverAEStack ########################
 
 
-uEHM::uDeliverAEStack::uDeliverAEStack( bool f, void **t, unsigned int msg ) : uDeliverFlag( f ), table_size( msg ), event_table( t ) {
+uEHM::uDeliverAEStack::uDeliverAEStack( bool f, const std::type_info **t, unsigned int msg ) : uDeliverFlag( f ), table_size( msg ), event_table( t ) {
     // the current node applies to all exceptions when table_size is 0
     uBaseCoroutine &c = uThisCoroutine();		// optimization
     next = c.uDAEStack;
@@ -303,7 +309,7 @@ uEHM::uDeliverAEStack::~uDeliverAEStack() {
 } // uEHM::uDeliverAEStack::~uDeliverAEStack
 
 
-//######################### uEHM::uRaiseWorkHorseInit ########################
+//######################### uEHM::uResumeWorkHorseInit ########################
 
 
 // Initialization and finalization when handling a signalled event after
@@ -311,26 +317,29 @@ uEHM::uDeliverAEStack::~uDeliverAEStack() {
 // hierarchies are properly maintained.  As well, it maintains the currently
 // handled resumption object for reraise.
 
-class uEHM::uRaiseWorkHorseInit {
+class uEHM::uResumeWorkHorseInit {
     uResumptionHandlers *prevVisualTop;
     uDualClass *prevResumption;
   public:
-    uRaiseWorkHorseInit( uResumptionHandlers *h, uDualClass & newResumption ) {
+    uResumeWorkHorseInit( uResumptionHandlers *h, uDualClass & newResumption ) {
 	uBaseCoroutine &c = uThisCoroutine();		// optimization
-	prevResumption = c.RaisedObj;
-	c.RaisedObj = &newResumption;
-
+	prevResumption = c.ResumedObj;
+	c.ResumedObj = &newResumption;
+	c.TopResumedType = &typeid(newResumption);
 	uBaseCoroutine &current = c;
 	prevVisualTop = current.uHandlerStackVisualTop;
 	current.uHandlerStackVisualTop = h;
-    } // uEHM::uRaiseWorkHorseInit::uRaiseWorkHorse
+    } // uEHM::uResumeWorkHorseInit::uResumeWorkHorse
 
-    ~uRaiseWorkHorseInit() {
+    ~uResumeWorkHorseInit() {
 	uBaseCoroutine &c = uThisCoroutine();		// optimization
-	c.RaisedObj = prevResumption;
+	c.ResumedObj = prevResumption;
+	if ( ! std::uncaught_exception() ) {		// update top, unless it's a forceful unwind
+	    c.TopResumedType = prevResumption ? &typeid(prevResumption) : NULL;
+	} // if
 	c.uHandlerStackVisualTop = prevVisualTop;
-    } // uEHM::uRaiseWorkHorseInit::~uRaiseWorkHorse
-}; // uEHM::uRaiseWorkHorseInit
+    } // uEHM::uResumeWorkHorseInit::~uResumeWorkHorse
+}; // uEHM::uResumeWorkHorseInit
 
 
 //######################### uEHM::uEHMAutoResourceCleanup ########################
@@ -358,113 +367,114 @@ class uEHM::uEHMAutoResourceCleanup {
 
 
 #ifdef __U_DEBUG__
-static void uEHMCheck( uBaseCoroutine &target, char *kind ) {
-    if ( &target == NULL || &target == (uBaseCoroutine *) -1 || *((void **) &target) == NULL || *((void **) &target) == (void *) -1 ) {
-	uAbort( "attempt by task %.256s (0x%p) to %s a nonlocal exception at target %.256s (0x%p), but the target is invalid or has been deleted",
-		uThisTask().uGetName(), &uThisTask(), kind, target.uGetName(), &target );
+static void Check( uBaseCoroutine &target, const char *kind ) {
+    if ( &target == NULL || &target == (uBaseCoroutine *)-1 || *((void **)&target) == NULL || *((void **)&target) == (void *)-1 ) {
+	uAbort( "Attempt by task %.256s (0x%p) to %s a nonlocal exception at target 0x%p, but the target is invalid or has been deleted",
+		uThisTask().getName(), &uThisTask(), kind, &target );
     } // if
-} // uEHMCheck
+} // Check
 #endif // __U_DEBUG__
 
-void uEHM::uEHMThrow( const uDualClass &ae_obj ) {
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "uEHM::uEHMThrow( uDualClass::ae_obj:0x%p ) from task %.256s (0x%p)\n", &ae_obj, uThisTask().uGetName(), &uThisTask() );
-#endif // __U_DEBUG_H__
-    ae_obj.uStackThrow();
-    // CONTROL NEVER REACHES HERE!
-} // uEHM::uEHMThrow
 
-void uEHM::uEHMThrow( const uThrowClass &ae_obj ) {
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "uEHM::uEHMThrow( uThrowClass::ae_obj:0x%p ) from task %.256s (0x%p)\n", &ae_obj, uThisTask().uGetName(), &uThisTask() );
-#endif // __U_DEBUG_H__
-    ae_obj.uStackThrow();
-    // CONTROL NEVER REACHES HERE!
-} // uEHM::uEHMThrow
-
-void uEHM::uEHMThrow( const uThrowClass &ae_obj, uBaseCoroutine &target ) {
-#ifdef __U_DEBUG_H__
-    uDebugPrt( "uEHM::uEHMThrow( uThrowClass::ae_obj:0x%p, target:0x%p ) from task %.256s (0x%p)\n", &ae_obj, &target, uThisTask().uGetName(), &uThisTask() );
-#endif // __U_DEBUG_H__
+void uEHM::asyncToss( const uDualClass &ex, uBaseCoroutine &target, uFlagT f, bool rethrow ) {
 #ifdef __U_DEBUG__
-    uEHMCheck( target, "throw" );
+    Check( target, f == uResumeF ? "resume" : "throw" );
 #endif // __U_DEBUG__
-    if ( target.uGetState() != uBaseCoroutine::uHalt ) {
-	uAsyncAEMsg *temp = new uAsyncAEMsg( ae_obj );
-	temp->ae->setOriginalThrower ( (void *)&ae_obj.source() );
+
+    if ( target.getState() != uBaseCoroutine::Halt ) {
+	uAsyncAEMsg *temp = new uAsyncAEMsg( ex, f );
+	uBaseCoroutine &cor = uThisCoroutine();
+	if ( ! rethrow ) {				// reset current raiser ?
+	    temp->ae->setOriginalThrower( (void *)&cor );
+	    temp->ae->setSrc( cor );
+	} // if
 	target.uAsyncAEBuf.uAddMsg( temp );
     } // if
-} // uEHM::uEHMThrow
+} // uEHM::asyncToss
 
-void uEHM::uEHMThrow( const uDualClass &ae_obj, uBaseCoroutine &target ) {
-#ifdef __U_DEBUG__
-    uEHMCheck( target, "throw" );
-#endif // __U_DEBUG__
-    if ( target.uGetState() != uBaseCoroutine::uHalt ) {
-	uAsyncAEMsg *temp = new uAsyncAEMsg( ae_obj, uDualThrowF );
-	temp->ae->setOriginalThrower( (void *)&ae_obj.source() );
-	target.uAsyncAEBuf.uAddMsg( temp );
+void uEHM::asyncReToss( uBaseCoroutine &target, uFlagT f ) {
+    uDualClass *r;
+
+    if (f == uResumeF) {
+	r = getCurrentResumption();
+	if ( r == NULL ) {
+	    r = getCurrentException();
+	}//if
+    } else {
+	r = getCurrentException();
+	if ( r == NULL ) {
+	    r = getCurrentResumption();
+	} // if
     } // if
-} // uEHM::uEHMThrow
-
-
-void uEHM::uEHMRaise( const uDualClass &ae_obj ) {
-    uRaiseWorkHorse( ae_obj, true );
-} // uEHM::uEHMRaise
-
-void uEHM::uEHMRaise( const uRaiseClass &ae_obj ) {
-    uRaiseWorkHorse( (uDualClass &)ae_obj, true );
-} // uEHM::uEHMRaise
-
-void uEHM::uEHMRaise( const uDualClass &ae_obj, uBaseCoroutine &target ) {
-#ifdef __U_DEBUG__
-    uEHMCheck( target, "raise" );
-#endif // __U_DEBUG__
-    if ( target.uGetState() != uBaseCoroutine::uHalt ) {
-	uAsyncAEMsg *temp = new uAsyncAEMsg( ae_obj, uDualRaiseF );
-	temp->ae->setOriginalThrower( (void *)&ae_obj.source() );
-	target.uAsyncAEBuf.uAddMsg( temp );
-    } // if
-} // uEHM::uEHMRaise
-
-void uEHM::uEHMRaise( const uRaiseClass &ae_obj, uBaseCoroutine &target ) {
-#ifdef __U_DEBUG__
-    uEHMCheck( target, "raise" );
-#endif // __U_DEBUG__
-    if ( target.uGetState() != uBaseCoroutine::uHalt ) {
-	uAsyncAEMsg *temp = new uAsyncAEMsg( ae_obj );
-	temp->ae->setOriginalThrower( (void *)&ae_obj.source() );
-	target.uAsyncAEBuf.uAddMsg( temp );
-    } // if
-} // uEHM::uEHMRaise
-
-
-void uEHM::uReRaise() {
-    uBaseCoroutine &c = uThisCoroutine();		// optimization
-    if ( c.RaisedObj == NULL ) {
+    
+    if ( r == NULL ) {					// => there is nothing to resume => terminate
 	uTerminateHandler();
+    } else {
+	asyncToss( *r, target, f, true );
     } // if
-    uRaiseWorkHorse( (uDualClass &) *(c.RaisedObj), true );
-}; // uEHM::uReRaise
+} // uEHM::asyncReToss
+
+
+void uEHM::Throw( const uDualClass &ex ) {
+#ifdef __U_DEBUG_H__
+    uDebugPrt( "uEHM::Throw( uDualClass::ex:0x%p ) from task %.256s (0x%p)\n", &ex, uThisTask().getName(), &uThisTask() );
+#endif // __U_DEBUG_H__
+    ex.stackThrow();
+    // CONTROL NEVER REACHES HERE!
+} // uEHM::Throw
+
+void uEHM::ReThrow() {
+    uDualClass *e = getCurrentException();		// optimization
+    if ( e == NULL ) {
+	e = getCurrentResumption();
+    } // if
+
+    if ( e != NULL ) {
+	e->stackThrow();
+    } // if
+    throw;
+} // uEHM::ReThrow
+
+
+void uEHM::Resume( const uDualClass &ex ) {
+    uResumeWorkHorse( ex, true );
+} // uEHM::Resume
+
+void uEHM::ReResume() {
+    uDualClass *r = getCurrentResumption();		// optimization
+
+    if ( r == NULL ) {
+	r = getCurrentException();
+    } // if
+
+    if ( r == NULL ) {					// => there is nothing to resume => terminate
+	uTerminateHandler();
+    } else {						// => there is something to resume
+	uResumeWorkHorse( *r, true );	
+    } // if
+}; // uEHM::ReResume
 
 
 // Check for and handle pending nonlocal exceptions.
 
-void uEHM::uPoll() {
+bool uEHM::uPoll() {
     uAsyncAEMsgBuffer &msgbuf = uThisCoroutine().uAsyncAEBuf;
-    uAsyncAEMsg *ae_msg = msgbuf.uHead();		// find first node in queue
-    if ( ae_msg && ae_msg->uHidden ) {
-	ae_msg = msgbuf.uNextVisible(ae_msg);		// from there, find first visible node
+    uAsyncAEMsg *ae_msg = msgbuf.head();		// find first node in queue
+
+  if ( ae_msg == NULL ) return false;
+
+    if ( ae_msg->uHidden ) {
+	ae_msg = msgbuf.uNextVisible( ae_msg );		// from there, find first visible node
     } // if
 
     // For each visible node, check if responsible for its delivery. If yes,
     // hide it from any recursive uPoll call, handle the event, and remove it
     // from the queue through the automatic resource clean-up.
 
-    while ( ae_msg ) {
-    	if ( deliverable_exception( (void *)(ae_msg->ae->uEvent_id()) ) ) {
+    while ( ae_msg != NULL ) {
+    	if ( deliverable_exception( ae_msg->ae->uGetEventType() ) ) {
 	    // Note, implicit context switches only call uYieldNoPoll(), hence
-	    // uPoll can only be called from uRaiseWorkHorse again, which is a
+	    // uPoll can only be called from uResumeWorkHorse again, which is a
 	    // safe recursion.
 	    ae_msg->uHidden = true;                     // hide node from recursive children of uPoll
 	    uDualClass *ae = ae_msg->ae;
@@ -476,14 +486,15 @@ void uEHM::uPoll() {
 	    uEHMAutoResourceCleanup dummy_var( ae_msg, msgbuf ); // This ensures removal and deletion of the node at end of block.
 	                                                        // Necessary because of return or throw.
 
-	    if ( ae_msg->flag <= uDualThrowF ) {	// throw the event
-		ae->uStackThrow();
+	    if ( ae_msg->flag == uThrowF ) {		// throw the event
+		ae->stackThrow();
 		// CONTROL NEVER REACHES HERE!
 	    } // if
-	    uRaiseWorkHorse( *ae, false );		// handle event, potential recursion! also potential exception
+	    uResumeWorkHorse( *ae, false );		// handle event, potential recursion! also potential exception
 	    
 	    ae_msg = msgbuf.uNextVisible(ae_msg);	// advance to next visible node
 
+	    return true;
 	    // NOTE: AE_MSG IS DESTROYED HERE !!
 	} else {
 	    ae_msg = msgbuf.uNextVisible(ae_msg);	// advance to next visible node (without deleting)
@@ -492,30 +503,79 @@ void uEHM::uPoll() {
 
     // NOTE: finalizer is destroyed here, sets the progress flag to its old
     // value, i.e., the first level turns it off
+
+    return false;
 } // uEHM::uPoll
 
 
-bool uEHM::uMatch_exception_type( void *derived_id, void *const parent_id ) {
-    // return true if derived_id event is derived from parent_id event
+uEHM::uDualClass *uEHM::getCurrentException() {
+    __cxxabiv1::__cxa_eh_globals *globals = __cxxabiv1::__cxa_get_globals();
+    if ( globals != NULL ) {
+	__cxxabiv1::__cxa_exception *header = globals->caughtExceptions;	
+	if ( header != NULL ) {			// handling an exception and want to turn it into resumption
+	    return (uEHM::uDualClass*)((char *)header + sizeof(__cxxabiv1::__cxa_exception)); 
+	} // if
+    } // if
+    return NULL;
+} // uEHM::getCurrentException
+
+uEHM::uDualClass *uEHM::getCurrentResumption() {
+    return uThisCoroutine().ResumedObj;			// optimization
+} // uEHM::getCurrentResumption
+
+const std::type_info * uEHM::getTopResumptionType() {
+    return uThisCoroutine().TopResumedType;
+} // uEHM::getCurrentResumptionType()
+
+
+char *uEHM::getCurrentEventName( uFlagT f, char *s1, size_t n ) {
+    const std::type_info *t;
+
+    if ( f == uResumeF ) {
+	t = uEHM::getTopResumptionType();
+    } else {
+	t = __cxxabiv1::__cxa_current_exception_type();
+    } // if
+
+    if ( t != NULL ) {
+	int status;
+	char *s2 = __cxxabiv1::__cxa_demangle( t->name(), 0, 0, &status );
+	uStrncpy( s1, s2, n );
+	free( s2 );
+    } else {
+	s1[0] = '\0';
+    } // if
+    return s1;
+} // uEHM::getCurrentExceptionName
+
+
+char *uEHM::uStrncpy( char *s1, const char *s2, size_t n ) {
+    strncpy( s1, s2, n );
+    if ( strlen( s2 ) > n ) {				// name too long ?
+	strcpy( &s1[n], "..." );			// add 4 character ...
+    } // if
+    return s1;
+} // uEHM::uStrncpy
+
+
+bool uEHM::uMatch_exception_type( const std::type_info *derived_type, const std::type_info *parent_type ) {
+    // return true if derived_type event is derived from parent_type event
+    void *dummy;
 #ifdef __DEBUG__
-    if ( ! parent_id ) uAbort( "internal error, error in setting up guarded region." );
+    if ( ! parent_type ) uAbort( "internal error, error in setting up guarded region." );
 #endif // __DEBUG__
-    for ( ; derived_id && derived_id != parent_id; derived_id = *((void **)derived_id) ) {
-    } // for
-
-    // all the ancestors of raised_id have been tested or a match found
-    return derived_id;
-}  // uEHM::uMatch_exception_type
+    return parent_type->__do_catch( derived_type, &dummy, 0 );
+} // uEHM::uMatch_exception_type
 
 
-bool uEHM::deliverable_exception( void *event_id ) {
+bool uEHM::deliverable_exception( const std::type_info *event_type ) {
     for ( uDeliverAEStack *tmp = uThisCoroutine().uDAEStack; tmp; tmp = tmp->next ) {
 	if ( tmp->table_size == 0 ) {			// table_size == 0 is a short hand for all exceptions
 	    return tmp->uDeliverFlag;
 	} // if
 
 	for ( int i = 0; i < tmp->table_size; i += 1 ) {
-	    if ( uMatch_exception_type( event_id, tmp->event_table[i] ) ) {
+	    if ( uMatch_exception_type( event_type, tmp->event_table[i] ) ) {
 		return tmp->uDeliverFlag;
 	    } // if
 	} // for
@@ -532,18 +592,18 @@ bool uEHM::deliverable_exception( void *event_id ) {
 // earlier resumption handlers. In this case, the virtual top
 // (uHandlerStackVisualTop) of the handler stack is used.
 
-void uEHM::uRaiseWorkHorse( const uDualClass &ae_obj, const bool conseq ) {
+void uEHM::uResumeWorkHorse( const uDualClass &ex, const bool conseq ) {
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "uEHM::uRaiseWorkHorse( ae_obj:0x%p, conseq:%d ) from task %.256s (0x%p)\n",
-	       &ae_obj, conseq, uThisTask().uGetName(), &uThisTask() );
+    uDebugPrt( "uEHM::uResumeWorkHorse( ex:0x%p, conseq:%d ) from task %.256s (0x%p)\n",
+	       &ex, conseq, uThisTask().getName(), &uThisTask() );
 #endif // __U_DEBUG_H__
 
-    void *eventId = ae_obj.uEvent_id();
+    const std::type_info *raisedtype = ex.uGetEventType();
     uResumptionHandlers *tmp = (conseq) ? uThisCoroutine().uHandlerStackVisualTop : uThisCoroutine().uHandlerStackTop;
 
     while ( tmp ) {
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "uEHM::uRaiseWorkHorse tmp:0x%p, eventId:0x%p\n", tmp, eventId );
+	uDebugPrt( "uEHM::uResumeWorkHorse tmp:0x%p, raisedtype:0x%p\n", tmp, raisedtype );
 #endif // __U_DEBUG_H__
 
 	uResumptionHandlers *next = (conseq) ? tmp->uConseqNext : tmp->uNext;
@@ -551,19 +611,19 @@ void uEHM::uRaiseWorkHorse( const uDualClass &ae_obj, const bool conseq ) {
 	// search all resumption handlers in the same handler clause
 	for ( unsigned int i = 0; i < tmp->size; i += 1 ) {
 	    uHandlerBase *elem = tmp->table[i];		// optimization
-	    const void *bound = ae_obj.getOriginalThrower();
+	    const void *bound = ex.getOriginalThrower();
 #ifdef __U_DEBUG_H__
-	    uDebugPrt( "uEHM::uRaiseWorkHorse table[%d]:0x%p, originalThrower:0x%p, eventId:0x%p, bound:0x%p\n",
-		       i, elem, elem->originalThrower, elem->eventId, bound );
+	    uDebugPrt( "uEHM::uResumeWorkHorse table[%d]:0x%p, originalThrower:0x%p, EventType:0x%p, bound:0x%p\n",
+		       i, elem, elem->originalThrower, elem->EventType, bound );
 #endif // __U_DEBUG_H__
-	    // if (no binding OR binding match) AND type match => handler found
+	    // if (no binding OR binding match) AND (type match OR resume_any) => handler found
 	    if ( ( elem->originalThrower == 0 || bound == elem->originalThrower ) &&
-		 uMatch_exception_type( eventId, elem->eventId ) ) {
+		 ( elem->EventType == 0 || uMatch_exception_type( raisedtype, elem->EventType ) ) ) {
 #ifdef __U_DEBUG_H__
-		uDebugPrt( "uEHM::uRaiseWorkHorse match\n" );
+		uDebugPrt( "uEHM::uResumeWorkHorse match\n" );
 #endif // __U_DEBUG_H__
-		uRaiseWorkHorseInit newStackVisualTop( next, (uDualClass &)(ae_obj) );
-		elem->uHandler( (uDualClass &)(ae_obj) );
+		uResumeWorkHorseInit newStackVisualTop( next, (uDualClass &)ex );
+		elem->uHandler( (uDualClass &)ex );
 		return;					// return after handling the exception
 	    } // if
 	} // for
@@ -571,9 +631,9 @@ void uEHM::uRaiseWorkHorse( const uDualClass &ae_obj, const bool conseq ) {
     } // while
 
     // cannot find a handler, use the default handler
-
-    ae_obj.defaultResume();				// default handler can change the exception
-} // uEHM::uRaiseWorkHorse
+    uResumeWorkHorseInit newStackVisualTop( NULL, (uDualClass &)ex ); // record the current resumption
+    ex.defaultResume();					// default handler can change the exception
+} // uEHM::uResumeWorkHorse
 
 
 // Local Variables: //
