@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uHeapLmmm.cc -- Lean Mean Malloc Machine - a runtime configurable replacement
 //                 for malloc.
@@ -8,8 +8,8 @@
 // Author           : Peter A. Buhr
 // Created On       : Sat Nov 11 16:07:20 1988
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Sep  2 12:21:16 2004
-// Update Count     : 640
+// Last Modified On : Mon Jun 27 19:19:49 2005
+// Update Count     : 684
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -95,7 +95,7 @@ bool uTraceHeapOff() {
 
 
 void uHeapManager::uNoMemory() {
-    uAbort( ": heap memory exhausted at %lu bytes.\n"
+    uAbort( "Heap memory exhausted at %lu bytes.\n"
 	    "Possible cause is very large memory allocation and/or large amount of unfreed storage allocated by the program or system/library routines.",
 	     (unsigned long int)((char *)(sbrk( 0 )) - (char *)(uHeapManager::uHeapManagerInstance->uHeapBegin)) );
 } // uHeapManager::uNoMemory
@@ -104,7 +104,7 @@ void uHeapManager::uNoMemory() {
 inline void uHeapManager::uHeaders( char *name, void *addr, uStorage *&block, uFreeHeader *&freeElem, size_t &alignment ) {
 #ifdef __U_DEBUG__
     if ( addr < uHeapBegin || uHeapEnd <= addr ) {
-	uAbort( ": attempt to %s storage 0x%p outside the current heap range:0x%p to 0x%p.\n"
+	uAbort( "Attempt to %s storage 0x%p outside the current heap range:0x%p to 0x%p.\n"
 		"Possible cause is invalid pointer.",
 		name, addr, uHeapBegin, uHeapEnd );
     } // if
@@ -122,7 +122,7 @@ inline void uHeapManager::uHeaders( char *name, void *addr, uStorage *&block, uF
 
 #ifdef __U_DEBUG__
     if ( freeElem < &freeLists[0] || &freeLists[31] < freeElem ) {
-	uAbort( ": attempt to %s storage 0x%p with corrupted header.\n"
+	uAbort( "Attempt to %s storage 0x%p with corrupted header.\n"
 		"Possible cause is duplicate free on same block or overwriting of header information.",
 		name, addr );
     } // if
@@ -212,12 +212,10 @@ void *uHeapManager::uDoMalloc( size_t size ) {
 #ifdef __U_DEBUG__
     if ( uTraceAlloc ) {
 	uDebugPrt( "0x%p = Malloc( %u ) (allocated %u)\n", area, size, tsize );
+	uThisTask().uPrintCallStack();
     } // if
 #endif // __U_DEBUG__
 
-    if ( uThisTask().uProfileActive && uProfiler::uProfiler_RegisterMemoryAllocate ) {
-	block->uHdr.uProfileMallocEntry = (*uProfiler::uProfiler_RegisterMemoryAllocate)( uProfiler::uProfilerInstance, area, size, tsize ); 
-    } // if
 #ifdef __U_DEBUG_H__
     uDebugPrt( "0x%p = (uHeap &)0x%p.uDoMalloc\n", area, this );
 #endif // __U_DEBUG_H__
@@ -238,6 +236,7 @@ void uHeapManager::uDoFree( void *addr ) {
 #ifdef __U_DEBUG__
       if ( uTraceAlloc ) {
 	  uDebugPrt( "Free( 0x%p ) size:0\n", addr );
+	  uThisTask().uPrintCallStack();
       } // if
 #endif // __U_DEBUG__
       return;
@@ -262,6 +261,7 @@ void uHeapManager::uDoFree( void *addr ) {
 #ifdef __U_DEBUG__
     if ( uTraceAlloc ) {
 	uDebugPrt( "Free( 0x%p ) size:%u\n", addr, freeElem->blockSize );
+	uThisTask().uPrintCallStack();
     } // if
 #endif // __U_DEBUG__
 
@@ -323,9 +323,9 @@ uHeapManager::~uHeapManager() {
     size_t underby = uCheckFree() - uHeapManager::PreAlloc;
     if ( underby != 0 ) {
 	// DO NOT USE STREAMS AS THEY MAY BE UNAVAILABLE AT THIS POINT.
-	fprintf( stderr, "uC++ Runtime warning (UNIX pid:%ld) : program terminating with %d(0x%x) bytes of storage allocated but not freed.\n"
+	fprintf( stderr, "uC++ Runtime warning (UNIX pid:%ld) : program terminating with %ld(0x%lx) bytes of storage allocated but not freed.\n"
 		 "Possible cause is unfreed storage allocated by the program or system/library routines called from the program.\n",
-		 (long int)getpid(), underby, underby ); // always print the UNIX pid
+		 (long int)getpid(), (unsigned long)underby, (unsigned long)underby ); // always print the UNIX pid
     } // if
 #endif // __U_DEBUG__
 } // uHeapManager::~uHeapManager
@@ -347,7 +347,7 @@ void uHeapManager::boot() {
     // SKULLDUGGERY: This ensures that calls to uThisCoroutine work before the
     // kernel is initialized.
 
-    ((uBaseTask *)&uKernelModule::uTaskBootStorage)->uCurrCoroutine = (uBaseTask *)&uKernelModule::uTaskBootStorage;
+    ((uBaseTask *)&uKernelModule::uTaskBootStorage)->currCoroutine = (uBaseTask *)&uKernelModule::uTaskBootStorage;
     ((uBaseTask *)&uKernelModule::uTaskBootStorage)->uInheritTask = (uBaseTask *)&uKernelModule::uTaskBootStorage;
     uHeapManager::uHeapManagerInstance = new((void *)&uHeapStorage) uHeapManager;
 } // uHeapManager::boot
@@ -363,17 +363,21 @@ void *uHeapManager::operator new( size_t size ) {
 } // uHeapManager::operator new
 
 
-// Unnecessary to redefine __builtin_new, __builtin_vec_new, __builtin_delete
-// as they call malloc and free, which are redefined below.
+// Operators new and new [] call malloc; delete calls free
 
 
 extern "C" {
-void *malloc( size_t size ) {
+void *malloc( size_t size ) __THROW {
     if ( uHeapManager::uHeapManagerInstance == NULL ) {
 	uHeapManager::boot();
     } // if
 
     void *area = uHeapManager::uHeapManagerInstance->uDoMalloc( size );
+
+    if ( uThisTask().uProfileActive && uProfiler::uProfiler_RegisterMemoryAllocate ) {
+	uHeapManager::uStorage *block = (uHeapManager::uStorage *)( (char *)area - sizeof(uHeapManager::uStorage::uHeader) );
+	block->uHdr.uProfileMallocEntry = (*uProfiler::uProfiler_RegisterMemoryAllocate)( uProfiler::uProfilerInstance, area, size, block->uHdr.uVar.home->blockSize );
+    } // if
 #ifdef __U_DEBUG_H__
     uDebugPrt( "0x%p = malloc( %u )\n", area, size );
 #endif // __U_DEBUG_H__
@@ -381,12 +385,8 @@ void *malloc( size_t size ) {
 } // malloc
 
 
-void *calloc( size_t noOfElems, size_t elemSize ) {
-    if ( uHeapManager::uHeapManagerInstance == NULL ) {
-	uHeapManager::boot();
-    } // if
-
-    void *area = uHeapManager::uHeapManagerInstance->uDoMalloc( noOfElems * elemSize );
+void *calloc( size_t noOfElems, size_t elemSize ) __THROW {
+    void *area = malloc( noOfElems * elemSize );
   if ( area == NULL ) return NULL;
     memset( area, '\0', noOfElems * elemSize );		// must set to zeros
 #ifdef __U_DEBUG_H__
@@ -396,14 +396,14 @@ void *calloc( size_t noOfElems, size_t elemSize ) {
 } // calloc
 
 
-void *realloc( void *addr, size_t size ) {
+void *realloc( void *addr, size_t size ) __THROW {
     if ( uHeapManager::uHeapManagerInstance == NULL ) {
 	uHeapManager::boot();
     } // if
 
-  if ( addr == NULL ) return uHeapManager::uHeapManagerInstance->uDoMalloc( size );
+  if ( addr == NULL ) return malloc( size );
   if ( size == 0 ) {
-	uHeapManager::uHeapManagerInstance->uDoFree( addr );
+	free( addr );
 	return NULL;
     } // exit
 
@@ -414,7 +414,12 @@ void *realloc( void *addr, size_t size ) {
 
     // Subtract off storage before user location (handles memalign)
     size_t s = (char *)block + freeElem->blockSize - (char *)addr;
-  if ( s >= size ) return addr;				// already sufficient storage
+  if ( s >= size ) {					// already sufficient storage
+      // This case does not result in a new profiler entry because the previous
+      // one still exists and it must match with the free for this memory.
+      // Hence, this realloc does not appear in the profiler output.
+      return addr;
+    } // if
 
     void *area;
     if ( alignment != 0 ) {				// previous request memalign?
@@ -424,7 +429,7 @@ void *realloc( void *addr, size_t size ) {
     } // if
   if ( area == NULL ) return NULL;
     memcpy( area, addr, s < size ? s : size );
-    uHeapManager::uHeapManagerInstance->uDoFree( addr );
+    free( addr );
 #ifdef __U_DEBUG_H__
     uDebugPrt( "0x%p = realloc( 0x%p, %u )\n", area, addr, size );
 #endif // __U_DEBUG_H__
@@ -432,15 +437,15 @@ void *realloc( void *addr, size_t size ) {
 } // realloc
 
 
-void *memalign( size_t alignment, size_t size ) {
+void *memalign( size_t alignment, size_t size ) __THROW {
     if ( uHeapManager::uHeapManagerInstance == NULL ) {
 	uHeapManager::boot();
     } // if
 
     // range check for alignment
 
-    if ( alignment < sizeof(int) || ((alignment - 1) & alignment) != 0 ) {
-	uAbort( ": alignment %lu for memory allocation is less than sizeof(int) and/or not a power of 2.",
+    if ( alignment < sizeof(int) || ! uPow2( alignment ) ) {
+	uAbort( "Alignment %lu for memory allocation is less than sizeof(int) and/or not a power of 2.",
 		(unsigned long int)alignment );
     } // if
 
@@ -448,7 +453,7 @@ void *memalign( size_t alignment, size_t size ) {
     // unnecessary
 
   if ( alignment <= sizeof(uHeapManager::uStorage::uHeader) ) {
-	void *area = uHeapManager::uHeapManagerInstance->uDoMalloc( size );
+	void *area = malloc( size );
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "0x%p = memalign( %u, %u )\n", area, alignment, size );
 #endif // __U_DEBUG_H__
@@ -476,6 +481,11 @@ void *memalign( size_t alignment, size_t size ) {
     // fake header.
     block->uHdr.uProfileMallocEntry = (uMemoryInfoEntry *)alignment;
     fake->uHdr.uVar.home = (uHeapManager::uFreeHeader *)block;
+
+    if ( uThisTask().uProfileActive && uProfiler::uProfiler_RegisterMemoryAllocate ) {
+	uHeapManager::uStorage *block = (uHeapManager::uStorage *)( (char *)area - sizeof(uHeapManager::uStorage::uHeader) );
+	block->uHdr.uProfileMallocEntry = (*uProfiler::uProfiler_RegisterMemoryAllocate)( uProfiler::uProfilerInstance, area, size, block->uHdr.uVar.home->blockSize );
+    } // if
 #ifdef __U_DEBUG_H__
     uDebugPrt( "0x%p = memalign( %u, %u )\n", user, alignment, size );
 #endif // __U_DEBUG_H__
@@ -483,12 +493,12 @@ void *memalign( size_t alignment, size_t size ) {
 } // memalign
 
 
-void *valloc( size_t size ) {
+void *valloc( size_t size ) __THROW {
     return memalign( sysconf( _SC_PAGESIZE ), size );
 } // valloc
 
 
-void free( void *addr ) {
+void free( void *addr ) __THROW {
     uHeapManager::uHeapManagerInstance->uDoFree( addr );
 #ifdef __U_DEBUG_H__
     uDebugPrt( "free( 0x%p )\n", addr );
