@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Russell Mok 1997
+// uC++ Version 5.3.0, Copyright (C) Russell Mok 1997
 // 
 // uKernelEvent.cc -- 
 // 
 // Author           : Russell Mok
 // Created On       : Mon Jun 30 22:14:03 1997
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Aug 31 18:03:05 2004
-// Update Count     : 59
+// Last Modified On : Wed Mar 30 10:03:15 2005
+// Update Count     : 62
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -29,15 +29,12 @@
 
 
 uKernelFailure::uKernelFailure( const char *const msg ) : uEHM::uDualClass( msg ) {}
-
 uKernelFailure::~uKernelFailure() {}
 
 void uKernelFailure::defaultTerminate() const {
     uAbort( "Unhandled exception of type uKernelFailure : %s", message() );
 } // uKernelFailure::defaultTerminate
 
-uInitEvent(uKernelFailure);
-
 
 // Local Variables: //
 // compile-command: "gmake install" //
