@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Russell Mok 1997
+// uC++ Version 5.3.0, Copyright (C) Russell Mok 1997
 // 
 // uKernelEvent.h -- 
 // 
 // Author           : Russell Mok
 // Created On       : Mon Jun 30 22:14:03 1997
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Aug 26 08:43:08 2004
-// Update Count     : 55
+// Last Modified On : Fri Jun 24 14:32:34 2005
+// Update Count     : 59
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -29,7 +29,7 @@
 #define __U_KERNELEVENT_H__
 
 
-uDualEvent uKernelFailure {				// exceptional event during mutex session or synchronization session
+_DualEvent uKernelFailure {				// exceptional event during mutex session or synchronization session
   public:
     uKernelFailure( const char *const msg = "" );
     virtual ~uKernelFailure();
