@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Richard Bilson and Ashif Harji 2003
+// uC++ Version 5.3.0, Copyright (C) Richard Bilson and Ashif Harji 2003
 // 
 // uKernelThreads.h -- 
 // 
 // Author           : Richard Bilson and Ashif Harji
 // Created On       : Wed Jul 16 16:44:10 2003
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Aug 12 09:04:53 2004
-// Update Count     : 18
+// Last Modified On : Wed Jun 22 12:10:22 2005
+// Update Count     : 24
 // 
 
 /* Most of this code is borrowed from the gnu glibc library machine dependent
@@ -145,8 +145,96 @@ extern int __modify_ldt (int, struct modify_ldt_ldt_s *, size_t);
 
 #endif
 
+#elif defined( __x86_64__ )
+
+/* Read member of the thread descriptor directly.  */
+#define THREAD_GETMEM(member) \
+({										\
+  __typeof__ (((uKernelModule *)0)->member) __value;				\
+  /* There should not be any value with a size other than 1, 4 or 8.  */	\
+  _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
+		   sizeof(__value) == 8 );					\
+  if (sizeof(__value) == 1)							\
+    __asm__ __volatile__ ("movb %%fs:_ZN13uKernelModule17uKernelModuleBootE@tpoff+%P2,%b0" \
+			  : "=q" (__value)					\
+			  : "0" (0),						\
+			    "i" (offsetof (struct uKernelModule,		\
+					   member)));				\
+  else if (sizeof(__value) == 4)						\
+    __asm__ __volatile__ ("movl %%fs:_ZN13uKernelModule17uKernelModuleBootE@tpoff+%P1,%0" \
+			  : "=r" (__value)					\
+			  : "i" (offsetof (struct uKernelModule,		\
+					   member)));				\
+  else if (sizeof(__value) == 8)						\
+    __asm__ __volatile__ ("movq %%fs:_ZN13uKernelModule17uKernelModuleBootE@tpoff+%P1,%0" \
+			  : "=r" (__value)					\
+			  : "i" (offsetof (struct uKernelModule,		\
+					   member)));				\
+  __value;									\
+})
+
+/* Set member of the thread descriptor directly.  */
+#define THREAD_SETMEM(member, value) \
+({										\
+  __typeof__ (((uKernelModule *)0)->member) __value = (value);			\
+  /* There should not be any value with a size other than 1, 4 or 8.  */	\
+  _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
+		   sizeof(__value) == 8 );					\
+  if (sizeof(__value) == 1)							\
+    __asm__ __volatile__ ("movb %0,%%fs:_ZN13uKernelModule17uKernelModuleBootE@tpoff+%P1" : \
+			  : "q" (__value),					\
+			    "i" (offsetof (struct uKernelModule,		\
+					   member)));				\
+  else if (sizeof(__value) == 4)						\
+    __asm__ __volatile__ ("movl %0,%%fs:_ZN13uKernelModule17uKernelModuleBootE@tpoff+%P1" : \
+			  : "r" (__value),					\
+			    "i" (offsetof (struct uKernelModule,		\
+					   member)));				\
+  else if (sizeof(__value) == 8)						\
+    __asm__ __volatile__ ("movq %0,%%fs:_ZN13uKernelModule17uKernelModuleBootE@tpoff+%P1" : \
+			  : "r" (__value),					\
+			    "i" (offsetof (struct uKernelModule,		\
+					   member)));				\
+})
+
 #elif defined( __ia64__ )
 
+#if defined( __INTEL_COMPILER )
+
+extern "C" char thread_getmem_1( size_t off );
+extern "C" int thread_getmem_4( size_t off );
+extern "C" long thread_getmem_8( size_t off );
+extern "C" void thread_setmem_1( size_t off, char value );
+extern "C" void thread_setmem_4( size_t off, int value );
+extern "C" void thread_setmem_8( size_t off, long value );
+
+#define THREAD_GETMEM( member ) \
+({										\
+  __typeof__ (((uKernelModule *)0)->member) __value;				\
+  /* There should not be any value with a size other than 1, 4 or 8.  */	\
+  if (sizeof(__value) == 1)							\
+    __value = (typeof(__value))thread_getmem_1( offsetof( struct uKernelModule, member ) ); \
+  else if (sizeof(__value) == 4)							\
+    __value = (typeof(__value))thread_getmem_4( offsetof( struct uKernelModule, member ) ); \
+  else if (sizeof(__value) == 8)						\
+    __value = (typeof(__value))thread_getmem_8( offsetof( struct uKernelModule, member ) ); \
+  __value;									\
+})
+
+#define THREAD_SETMEM( member, value ) \
+({										\
+  __typeof__ (((uKernelModule *)0)->member) __value = (value);			\
+  /* There should not be any value with a size other than 1, 4 or 8.  */	\
+  if (sizeof(__value) == 1)							\
+    thread_setmem_1( offsetof( struct uKernelModule, member ), (char)(__value) ); \
+  else if (sizeof(__value) == 4)						\
+    thread_setmem_4( offsetof( struct uKernelModule, member ), (int)(__value) ); \
+  else if (sizeof(__value) == 8)						\
+    thread_setmem_8( offsetof( struct uKernelModule, member ), (long)(__value) ); \
+})
+
+#else // ! __INTEL_COMPILER
+
 /* Making a system call is much like a procedure call in that it may clobber
    any of the scratch (caller-save) registers.  So we need to tell gcc that any
    of these registers can be clobbered when making a syscall from inline asm.
@@ -217,7 +305,11 @@ extern int __modify_ldt (int, struct modify_ldt_ldt_s *, size_t);
    It is important not to affect the value of errno in the user task.  Neither
    of these system calls can fail, and even if they could the fact that the are
    coded in assembler precludes an update to errno.
+*/
 
+#if ! defined( __U_TLS__ )
+
+/*
    Magic numbers: 1041 == __NR_getpid (<asm/unistd.h>)
                   1053 == __NR_kill (<asm/unistd.h>)
                   14 == SIGALRM (<bits/signum.h>)
@@ -235,8 +327,6 @@ extern int __modify_ldt (int, struct modify_ldt_ldt_s *, size_t);
 
 #define HANDLE_CLOBBERS "out0", "out1", SCRATCH_REGS
 
-#if ! defined( __U_TLS__ )
-
 #define GETMEM_ASM(operand, member) \
     __asm__ __volatile__ (DISABLE						\
                           "add r15 = %1, r13;;\n"				\
@@ -291,6 +381,23 @@ extern int __modify_ldt (int, struct modify_ldt_ldt_s *, size_t);
 })
 
 #else
+/*
+   Magic numbers: 1041 == __NR_getpid (<asm/unistd.h>)
+                  1229 == __NR_tkill (<asm/unistd.h>)
+                  10 == SIGUSR1 (<bits/signum.h>)
+*/
+
+#define HANDLE \
+        "(p7) br.cond.sptk.many 0f;;\n" \
+        "mov r15 = 1041\n"              \
+        "break 0x100000;;\n"            \
+        "mov r15 = 1229\n"              \
+        "mov out0 = r8\n"               \
+        "mov out1 = 10\n"               \
+        "break 0x100000;;\n"            \
+        "0:"
+
+#define HANDLE_CLOBBERS "out0", "out1", SCRATCH_REGS
 
 #define __LOAD_OFFSET \
         ";;mf\ncmp.eq p7, p0 = r0, r0\n"       \
@@ -351,19 +458,145 @@ extern int __modify_ldt (int, struct modify_ldt_ldt_s *, size_t);
     SETMEM_ASM( "st8", member );						\
 })
 
+#endif // ! __INTEL_COMPILER
+
 #endif // __U_TLS__
 
 #endif // __linux__
 
 #elif defined( __solaris__ )
 
-/* Registers %g7 is reserved by the Solaris ABI for the thread pointer.  */
-struct uKernelModule;
-register volatile struct uKernelModule *__thread_self __asm__("%g7");
+// this variable is not used directly, but must be in place to prevent warnings
+// about global register use from the 64-bit assembler
+register unsigned long sparc_tp __asm__( "%g7" );
 
-/* Access to data in the thread descriptor is easy.  */
-#define THREAD_GETMEM(member) __thread_self->member
-#define THREAD_SETMEM(member, value) __thread_self->member = (value)
+#if ! defined( __U_TLS__ )
+
+/* Register %g7 is reserved by the Solaris ABI for the thread pointer.  */
+/* Read member of the thread descriptor directly.  */
+#define THREAD_GETMEM(member) \
+({										\
+  __typeof__ (((uKernelModule *)0)->member) __value;				\
+  /* There should not be any value with a size other than 1, 4 or 8.  */	\
+  _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
+		   sizeof(__value) == 8 );					\
+  if (sizeof(__value) == 1)							\
+    __asm__ __volatile__ ("ldub [%%g7+%1], %0"					\
+			  : "=r" (__value)					\
+			  : "i" (offsetof (struct uKernelModule,		\
+					   member)));				\
+  else if (sizeof(__value) == 4)						\
+    __asm__ __volatile__ ("lduw [%%g7+%1], %0"					\
+			  : "=r" (__value)					\
+			  : "i" (offsetof (struct uKernelModule,		\
+					   member)));				\
+  else if (sizeof(__value) == 8)						\
+    __asm__ __volatile__ ("ldx [%%g7+%1], %0"					\
+			  : "=r" (__value)					\
+			  : "i" (offsetof (struct uKernelModule,		\
+					   member)));				\
+  __value;									\
+})
+
+/* Set member of the thread descriptor directly.  */
+#define THREAD_SETMEM(member, value) \
+({										\
+  __typeof__ (((uKernelModule *)0)->member) __value = (value);			\
+  /* There should not be any value with a size other than 1, 4 or 8.  */	\
+  _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
+		   sizeof(__value) == 8 );					\
+  if (sizeof(__value) == 1)							\
+    __asm__ __volatile__ ("stb %0, [%%g7+%1]" :					\
+			  : "r" (__value),					\
+			    "i" (offsetof (struct uKernelModule,		\
+					   member)));				\
+  else if (sizeof(__value) == 4)						\
+    __asm__ __volatile__ ("stw %0, [%%g7+%1]" :					\
+			  : "r" (__value),					\
+			    "i" (offsetof (struct uKernelModule,		\
+					   member)));				\
+  else if (sizeof(__value) == 8)						\
+    __asm__ __volatile__ ("stx %0, [%%g7+%1]" :					\
+			  : "r" (__value),					\
+			    "i" (offsetof (struct uKernelModule,		\
+					   member)));				\
+})
+
+#else
+
+#define THREAD_GETMEM(member) \
+({										\
+  __typeof__ (((uKernelModule *)0)->member) __value;				\
+  /* There should not be any value with a size other than 1, 4 or 8.  */	\
+  _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
+		   sizeof(__value) == 8 );					\
+  if (sizeof(__value) == 1)							\
+    __asm__ __volatile__ ("sethi %%tle_hix22(_ZN13uKernelModule17uKernelModuleBootE), %%g1\n\t" \
+		  	  "xor %%g1, %%tle_lox10(_ZN13uKernelModule17uKernelModuleBootE), %%g1\n\t" \
+			  "add %%g1, %1, %%g1\n\t"				\
+			  "ldub [%%g7+%%g1], %0"				\
+			  : "=r" (__value)					\
+			  : "i" (offsetof (struct uKernelModule,		\
+					   member))				\
+			  : "%g1" );						\
+  else if (sizeof(__value) == 4)						\
+    __asm__ __volatile__ ("sethi %%tle_hix22(_ZN13uKernelModule17uKernelModuleBootE), %%g1\n\t" \
+		  	  "xor %%g1, %%tle_lox10(_ZN13uKernelModule17uKernelModuleBootE), %%g1\n\t" \
+			  "add %%g1, %1, %%g1\n\t"				\
+			  "lduw [%%g7+%%g1], %0"				\
+			  : "=r" (__value)					\
+			  : "i" (offsetof (struct uKernelModule,		\
+					   member))				\
+			  : "%g1" );						\
+  else if (sizeof(__value) == 8)						\
+    __asm__ __volatile__ ("sethi %%tle_hix22(_ZN13uKernelModule17uKernelModuleBootE), %%g1\n\t" \
+		  	  "xor %%g1, %%tle_lox10(_ZN13uKernelModule17uKernelModuleBootE), %%g1\n\t" \
+			  "add %%g1, %1, %%g1\n\t"				\
+			  "ldx [%%g7+%%g1], %0"					\
+			  : "=r" (__value)					\
+			  : "i" (offsetof (struct uKernelModule,		\
+					   member))				\
+			  : "%g1" );						\
+  __value;									\
+})
+
+/* Set member of the thread descriptor directly.  */
+#define THREAD_SETMEM(member, value) \
+({										\
+  __typeof__ (((uKernelModule *)0)->member) __value = (value);			\
+  /* There should not be any value with a size other than 1, 4 or 8.  */	\
+  _STATIC_ASSERT_( sizeof(__value) == 1 || sizeof(__value) == 4 ||		\
+		   sizeof(__value) == 8 );					\
+  if (sizeof(__value) == 1)							\
+    __asm__ __volatile__ ("sethi %%tle_hix22(_ZN13uKernelModule17uKernelModuleBootE), %%g1\n\t" \
+		  	  "xor %%g1, %%tle_lox10(_ZN13uKernelModule17uKernelModuleBootE), %%g1\n\t" \
+			  "add %%g1, %1, %%g1\n\t"				\
+			  "stb %0, [%%g7+%%g1]"					\
+			  :: "r" (__value),					\
+			     "i" (offsetof (struct uKernelModule,		\
+					   member))				\
+			  : "%g1" );						\
+  else if (sizeof(__value) == 4)						\
+    __asm__ __volatile__ ("sethi %%tle_hix22(_ZN13uKernelModule17uKernelModuleBootE), %%g1\n\t" \
+		  	  "xor %%g1, %%tle_lox10(_ZN13uKernelModule17uKernelModuleBootE), %%g1\n\t" \
+			  "add %%g1, %1, %%g1\n\t"				\
+			  "stw %0, [%%g7+%%g1]"					\
+			  :: "r" (__value),					\
+			     "i" (offsetof (struct uKernelModule,		\
+					   member))				\
+			  : "%g1" );						\
+  else if (sizeof(__value) == 8)						\
+    __asm__ __volatile__ ("sethi %%tle_hix22(_ZN13uKernelModule17uKernelModuleBootE), %%g1\n\t" \
+		  	  "xor %%g1, %%tle_lox10(_ZN13uKernelModule17uKernelModuleBootE), %%g1\n\t" \
+			  "add %%g1, %1, %%g1\n\t"				\
+			  "stx %0, [%%g7+%%g1]"					\
+			  :: "r" (__value),					\
+			     "i" (offsetof (struct uKernelModule,		\
+					   member))				\
+			  : "%g1" );						\
+})
+
+#endif // __U_TLS__
 
 #elif defined( __irix__ )
 
@@ -374,7 +607,7 @@ register volatile struct uKernelModule *__thread_self __asm__("%g7");
 #define THREAD_SETMEM(member, value) ((volatile uKernelModule *)&(PRDA->usr_prda))->member = (value)
 
 #else
-    #error uC++ internal error : unsupported architecture
+    #error uC++ : internal error, unsupported architecture
 
 #endif
 
