@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uMachContext.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Fri Feb 25 15:46:42 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Aug 31 11:23:04 2004
-// Update Count     : 462
+// Last Modified On : Mon Oct 10 10:55:48 2005
+// Update Count     : 517
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -35,8 +35,11 @@
 #include <cstdio>					// fprintf
 #include <cerrno>
 
-#if defined( __sparc__ )
+#if defined( __sparc__ ) || defined( __mips__ ) || defined( __x86_64__ ) || defined( __ia64__ )
 extern "C" void uInvokeStub( uMachContext * );
+#endif // __sparc__ || __mips__
+
+#if defined( __sparc__ )
 #if defined(  __solaris__ )
 #include <sys/stack.h>
 #else
@@ -54,8 +57,8 @@ void uMachContext::uInvokeCoroutine( uBaseCoroutine &This ) { // magically invok
     // Called from the kernel when starting a coroutine or task so must switch
     // back to user mode.
 
-    This.uSetState( uBaseCoroutine::uActive );		// set state of next coroutine to active
-    THREAD_GETMEM( uSelf )->uEnableInterrupts();
+    This.setState( uBaseCoroutine::Active );		// set state of next coroutine to active
+    THREAD_GETMEM( uSelf )->enableInterrupts();
 
     if ( uThisTask().uProfileActive && uProfiler::uProfiler_PostallocateMetricMemory ) {
 	(*uProfiler::uProfiler_PostallocateMetricMemory)( uProfiler::uProfilerInstance, uThisTask() );
@@ -68,10 +71,17 @@ void uMachContext::uInvokeCoroutine( uBaseCoroutine &This ) { // magically invok
     try {
 	This.uCoStarter();				// moved from uCoroutineMain to allow recursion on "main"
 	This.main();					// start coroutine's "main" routine
-    } catch ( ... ) {					// unhandled exception ?
-	uRaise uBaseCoroutine::uFailure( This, "unhandled exception propagated to resumer" ) uAt *(This.uLast);
-	This.uNotHalted = false;			// terminate coroutine
-	This.uCoSuspend();				// restart last resumer, which should immediately propagate the nonlocal exception
+    } catch( uBaseCoroutine::UnHandledException &ex ) {
+	ex.multiple = true;				// set multiple exceptions
+	_Resume ex _At This.resumer();                    
+	This.notHalted = false;				// terminate coroutine
+	This.suspend();					// restart last resumer, which should immediately propagate the nonlocal exception
+    } catch( ... ) {					// unhandled exception ?
+	char msg[uEHMMaxMsg], name[uEHMMaxName + sizeof("...")]; // room for "...\0"
+	strcat( strcpy( msg, "an unhandled exception of type " ), uEHM::getCurrentEventName( uEHM::uThrowF, name, uEHMMaxName ) );
+	_Resume uBaseCoroutine::UnHandledException( msg ) _At This.resumer();
+	This.notHalted = false;				// terminate coroutine
+	This.suspend();					// restart last resumer, which should immediately propagate the nonlocal exception
     } // try
     This.uCoFinish();
 } // uMachContext::uInvokeCoroutine
@@ -81,14 +91,14 @@ void uMachContext::uInvokeTask( uBaseTask &This ) {	// magically invoke the "mai
     // Called from the kernel when starting a coroutine or task so must switch
     // back to user mode.
 
-#if defined (__U_MULTI__)
+#if defined(__U_MULTI__)
     THREAD_SETMEM( uActiveTask, ((uBaseTask *)&This) );
 #endif
 
     errno = 0;						// reset errno for each task
-    This.uCurrCoroutine->uSetState( uBaseCoroutine::uActive ); // set state of next coroutine to active
-    This.uSetState( uBaseTask::uRunning );
-    THREAD_GETMEM( uSelf )->uEnableInterrupts();
+    This.currCoroutine->setState( uBaseCoroutine::Active ); // set state of next coroutine to active
+    This.setState( uBaseTask::Running );
+    THREAD_GETMEM( uSelf )->enableInterrupts();
 
     if ( uThisTask().uProfileActive && uProfiler::uProfiler_PostallocateMetricMemory ) {
 	(*uProfiler::uProfiler_PostallocateMetricMemory)( uProfiler::uProfilerInstance, uThisTask() );
@@ -100,9 +110,9 @@ void uMachContext::uInvokeTask( uBaseTask &This ) {	// magically invoke the "mai
 
     try {
 	This.main();					// start task's "main" routine
-	uDisable {					// task has terminated so ignore concurrent exceptions
-	    This.uNotHalted = false;
-	    This.uSetState( uBaseTask::uTerminate );
+	_Disable {					// task has terminated so ignore concurrent exceptions
+	    This.notHalted = false;
+	    This.setState( uBaseTask::Terminate );
 
 	    // Clean up storage associated with the task for pthread
 	    // thread-specific data, e.g., exception handling associates
@@ -111,16 +121,23 @@ void uMachContext::uInvokeTask( uBaseTask &This ) {	// magically invoke the "mai
 	    if ( This.pthreadData != NULL ) {
 		_pthread_deletespecific( This.pthreadData );
 	    } // if
-	    This.serial->uLeave2();
+	    This.getSerial().uLeave2();
 	    uAbort( "(uMachContext::uInvokeTask() : internal error, CONTROL NEVER REACHES HERE!" );
-	} // uDisable
+	} // _Disable
     } catch( uEHM::uDualClass &evt ) {
 	evt.defaultTerminate();
+	cleanup( This );				// preserve current exception
     } catch( uEHM::uThrowClass &evt ) {
 	evt.defaultTerminate();
+	cleanup( This );				// preserve current exception
     } catch( ... ) {
+	cleanup( This );				// preserve current exception
     } // try
+    // CONTROL NEVER REACHES HERE!
+} // uMachContext::uInvokeTask
 
+
+void uMachContext::cleanup( uBaseTask &This ) {
     try {
 	std::terminate();				// call task terminate routine
     } catch( ... ) {					// control should not return
@@ -131,7 +148,7 @@ void uMachContext::uInvokeTask( uBaseTask &This ) {	// magically invoke the "mai
     } // if
 
     uEHM::uTerminate();					// call abort terminate routine
-} // uMachContext::uInvokeTask
+} // uMachContext::cleanup
 
 
 void *uMachContext::uRtnAdr( void (*rtn)() ) {
@@ -150,6 +167,20 @@ void *uMachContext::uRtnAdr( void (*rtn)() ) {
 } // uMachContext::uRtnAdr
 
 
+#if defined( __linux__ ) && defined( __ia64__ )
+void *uMachContext::uGpAdr( void (*rtn)() ) {
+    if ( ! rtn ) return NULL;
+
+    struct TOC {
+	void *rtn;
+	void *toc;
+    };
+
+    return ((TOC *)rtn)->toc;
+} // uMachContext::uGpAdr
+#endif
+
+
 unsigned int uMachContext::uMagic() {
     return 0x12345678;
 } // uMachContext::uMagic
@@ -207,12 +238,86 @@ void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
     ::makecontext( (ucontext *)uStorage, (void (*)())uInvoke, 2, this );
     // TEMPORARY: stack is incorrectly initialized to allow stack walking
     ((ucontext *)uStorage)->uc_mcontext.gregs[ REG_EBP ] = 0; // terminate stack with NULL fp
+#if defined( __U_MULTI__ ) && defined( __U_ONETIMER__ )
+    sigaddset( (sigset_t*)&((ucontext *)uStorage)->uc_sigmask, SIGALRM );
+#endif // __U_MULTI__ && __U_ONETIMER__
+#endif
+
+#elif defined( __x86_64__ )
+
+    // set base and limits of stack
+
+    uLimit = (char *)uStorage + uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + 16;
+    uBase = (char *)uLimit + uSize;
+
+#if ! defined( __U_SWAPCONTEXT__ )
+    struct uFakeStack {
+	void *uFixedRegisters[5];			// fixed registers rbx, r12, r13, r14, r15
+	void *uReturn;
+    };
+
+    ((uContext_t *)uStorage)->uSP = (char *)uBase - sizeof( uFakeStack );
+    ((uContext_t *)uStorage)->uFP = NULL;		// terminate stack with NULL fp
+
+    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->uReturn = uRtnAdr( (void (*)())uInvokeStub );
+    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->uFixedRegisters[0] = this;
+    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->uFixedRegisters[1] = uRtnAdr( (void (*)())uInvoke );
+#else
+    // makecontext is difficult to support.  See http://sources.redhat.com/bugzilla/show_bug.cgi?id=404
+    #error uC++ : internal error, swapcontext cannot be used on the x86_64 architecture
 #endif
 
 #elif defined( __ia64__ )
 
 #if ! defined( __U_SWAPCONTEXT__ )
-    #error uC++ internal error : swapcontext must be used on the ia64 architecture
+
+    // set base and limits of stack
+
+    uLimit = (char *)uStorage + uCeiling( sizeof(__U_CONTEXT_T__), 16 );
+    uBase = (char *)uLimit + uSize;
+
+    struct uFakeStack {
+	void *scratch1[2];				// abi-mandated scratch area
+	struct uPreservedState {
+	    void *b5;
+	    void *b4;
+	    void *b3;
+	    void *b2;
+	    void *b1;
+	    void *b0;
+	    void *pr;
+	    void *lc;
+	    void *pfs;
+	    void *fpsr;
+	    void *unat;
+	    void *spill_unat;
+	    void *rnat;
+	    void *r7;
+	    void *r6;
+	    void *r5;
+	    void *r4;
+	    void *r1;
+	} preserved;
+	void *scratch2[2];				// abi-mandated scratch area
+    };
+
+    ((uContext_t *)uStorage)->uSP = (char *)uBase - sizeof( uFakeStack );
+    ((uContext_t *)uStorage)->uBSP = (char*)uLimit + 16;
+    sigemptyset( &((uContext_t *)uStorage)->uSigmask );
+#ifdef __U_MULTI__
+    sigaddset( &((uContext_t *)uStorage)->uSigmask, SIGALRM );
+#endif // __U_MULTI__
+    memset( ((uContext_t *)uStorage)->uSP, 0, sizeof( uFakeStack ) );
+    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->preserved.b0 = uRtnAdr( (void (*)())uInvokeStub );
+    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->preserved.r1 = uGpAdr( (void (*)())uInvokeStub );
+#if defined( __INTEL_COMPILER )
+    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->preserved.fpsr = (void*)__getReg( _IA64_REG_AR_FPSR );
+#else
+    asm ( "mov.m %0 = ar.fpsr" : "=r" (((uFakeStack *)(((uContext_t *)uStorage)->uSP))->preserved.fpsr) );
+#endif // __INTEL_COMPILER
+    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->preserved.r4 = this;
+    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->preserved.b1 = uRtnAdr( (void (*)())uInvoke );
+    ((uFakeStack *)(((uContext_t *)uStorage)->uSP))->preserved.b2 = NULL; // null terminate for stack walking
 #else
     // set base and limits of stack
 
@@ -228,11 +333,12 @@ void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
     ::makecontext( (ucontext *)uStorage, (void (*)())uInvoke, 2, this );
 
     // TEMPORARY: getcontext doesn't get the signal mask properly
-    sigset_t new_mask;
-    sigemptyset( &new_mask );
-    if ( sigprocmask( SIG_BLOCK, &new_mask, (sigset_t*)&(((ucontext *)uStorage)->uc_sigmask) ) == -1 ) {
+    if ( sigprocmask( SIG_BLOCK, NULL, (sigset_t*)&(((ucontext *)uStorage)->uc_sigmask) ) == -1 ) {
         uAbort( "internal error, sigprocmask" );
     } // if
+#if defined( __U_MULTI__ ) && defined( __U_ONETIMER__ )
+    sigaddset( (sigset_t*)&((ucontext *)uStorage)->uc_sigmask, SIGALRM );
+#endif // __U_MULTI__ && __U_ONETIMER__
 #endif
 
 #elif defined( __sparc__ )
@@ -246,20 +352,22 @@ void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
     struct uFakeStack {
 	void *uLocalRegs[8];
 	void *uInRegs[8];
+#if defined( _ILP32 )
 	void *uStructRetAddress;
+#endif
 	void *uCalleeRegArgs[6];
     };
 
-    ((uContext_t *)uStorage)->uFP = (char *)(SA( (unsigned long)uBase - STACK_ALIGN + 1 ) - SA( MINFRAME ));
+    ((uContext_t *)uStorage)->uFP = (char *)(SA( (unsigned long)uBase - STACK_ALIGN + 1 ) - SA( MINFRAME ) - STACK_BIAS );
     ((uContext_t *)uStorage)->uSP = (char *)((uContext_t *)uStorage)->uFP - SA( MINFRAME );
     ((uContext_t *)uStorage)->uPC = (char *)uRtnAdr( (void (*)())uInvokeStub ) - 8;
 
-    ((uFakeStack *)((uContext_t *)uStorage)->uFP)->uInRegs[0] = this; // argument to uInvoke
-    ((uFakeStack *)((uContext_t *)uStorage)->uFP)->uInRegs[1] = (void *)uInvoke; // uInvoke routine
-    ((uFakeStack *)((uContext_t *)uStorage)->uFP)->uInRegs[6] = NULL; // terminate stack with NULL fp
+    ((uFakeStack *)((char *)((uContext_t *)uStorage)->uFP + STACK_BIAS))->uInRegs[0] = this; // argument to uInvoke
+    ((uFakeStack *)((char *)((uContext_t *)uStorage)->uFP + STACK_BIAS))->uInRegs[1] = (void *)uInvoke; // uInvoke routine
+    ((uFakeStack *)((char *)((uContext_t *)uStorage)->uFP + STACK_BIAS))->uInRegs[6] = NULL; // terminate stack with NULL fp
 #else
     if ( ::getcontext( (ucontext *)uStorage ) == -1 ) {	// initialize ucontext area
-	uAbort( "internal error, getcontext failed" );
+	uAbort( " : internal error, getcontext failed" );
     } // if
     ((ucontext *)uStorage)->uc_stack.ss_sp = (char *)uBase - 8;	// TEMPORARY: -8 for bug in Solaris (fixed in Solaris 4.10)
     ((ucontext *)uStorage)->uc_stack.ss_size = uSize; 
@@ -267,25 +375,29 @@ void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
     ::makecontext( (ucontext *)uStorage, (void (*)(...))uInvoke, 2, this );
     // TEMPORARY: stack is incorrectly initialized to allow stack walking
     *((int *)uBase - 8) = 0;				// terminate stack with NULL fp
+#if defined( __U_MULTI__ ) && defined( __U_ONETIMER__ )
+    sigaddset( (sigset_t*)&((ucontext *)uStorage)->uc_sigmask, SIGALRM );
+#endif // __U_MULTI__ && __U_ONETIMER__
 #endif
 
 #elif defined( __mips__ )
 
 #if ! defined( __U_SWAPCONTEXT__ )
     struct uFakeStack {
-	void *uFixedRegisters[10];			// fixed registers r16-r23,r30,r31
-	void *uDummyAlign[2];				// make multiple of 16
+	unsigned long long uFixedRegisters[11];		// fixed registers r16-r23,r30,r31,gp
+	void *uDummyAlign[1];				// make multiple of 16
     };
 
-    uLimit = uStorage;
-    uBase = (char *)uStorage + uSize - uAlign();
+    uLimit = (char *)uStorage + uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + 16;
+    uBase = (char *)uStorage + uSize;
 
-    uSP = (char *)uBase - sizeof( uFakeStack );
+    ((uContext_t *)uStorage)->uSP = (char *)uBase - sizeof( uFakeStack );
 
-    uProcVal  = (void (*)())uInvoke;
+    ((uFakeStack *)((uContext_t *)uStorage)->uSP)->uFixedRegisters[0] = reinterpret_cast<unsigned long long>( this ); // argument to uInvoke (r16)
+    ((uFakeStack *)((uContext_t *)uStorage)->uSP)->uFixedRegisters[1] = reinterpret_cast<unsigned long long>( uRtnAdr( (void (*)())uInvoke ) );	// uInvoke routine (r17)
+    ((uFakeStack *)((uContext_t *)uStorage)->uSP)->uFixedRegisters[8] = 0; // terminate stack with NULL fp (r30)
+    ((uFakeStack *)((uContext_t *)uStorage)->uSP)->uFixedRegisters[9] = reinterpret_cast<unsigned long long>( uRtnAdr( (void (*)())uInvokeStub ) ); // (r31)
 
-    // argument to uInvoke appears by magic, see uSwitch
-    ((uFakeStack *)uSP)->uFixedRegisters[9] = uRtnAdr( (void (*)())uInvoke );
 #else
     // set base and limits of stack
 
@@ -299,10 +411,13 @@ void uMachContext::uStartHere( void (*uInvoke)( uMachContext & ) ) {
     ((ucontext *)uStorage)->uc_stack.ss_size = uSize; 
     ((ucontext *)uStorage)->uc_stack.ss_flags = 0;
     ::makecontext( (ucontext *)uStorage, (void (*)())uInvoke, 2, this );
+#if defined( __U_MULTI__ ) && defined( __U_ONETIMER__ )
+    sigaddset( (sigset_t*)&((ucontext *)uStorage)->uc_sigmask, SIGALRM );
+#endif // __U_MULTI__ && __U_ONETIMER__
 #endif
 
 #else
-    #error uC++ internal error : unsupported architecture
+    #error uC++ : internal error, unsupported architecture
 #endif
 
     // set magic words on stack
@@ -325,7 +440,7 @@ uMachContext::uMachContext( unsigned int stacksize ) {
     // use malloc because "new" handles the overflow
     uStorage = malloc( uCeiling( sizeof(__U_CONTEXT_T__), 16 ) + uSize + 32 );
     if ( uStorage == NULL ) {				// allocate stack from heap
-	uAbort( "attempt to allocate %d bytes of storage for coroutine or task execution-state but insufficient memory available.", stacksize );
+	uAbort( "Attempt to allocate %d bytes of storage for coroutine or task execution-state but insufficient memory available.", stacksize );
     } // if
 } // uMachContext::uMachContext
 
@@ -335,25 +450,32 @@ uMachContext::~uMachContext() {
 } // uMachContext::~uMachContext
 
 
-void *uMachContext::uStackPointer() const {
+void *uMachContext::stackPointer() const {
     if ( &uThisCoroutine() == this ) {			// accessing myself ?
 	void *sp;					// use my current stack value
 #if defined( __i386__ )
 	asm("movl %%esp,%0" : "=m" (sp) : );
+#elif defined( __x86_64__ )
+	asm("movq %%rsp,%0" : "=m" (sp) : );
 #elif defined( __ia64__ )
+#if defined( __INTEL_COMPILER )
+	sp = (void*)__getReg( _IA64_REG_SP );
+#else
 	asm("mov %0 = r12" : "=r" (sp) : );
+#endif // __INTEL_COMPILER
 #elif defined( __sparc__ )
-	asm("st %%sp,%0" : "=m" (sp) : );
+	asm("mov %%sp,%0" : "=r" (sp) : );
+	sp = (void*)((char*)sp + STACK_BIAS);
 #elif defined( __mips__ )
 #ifdef _ABIN32
 	asm("sw $sp,%0" : "=m" (sp) : );
 #elif _ABI64
 	asm("sd $sp,%0" : "=m" (sp) : );
 #else
-	#error uC++ internal error : unsupported architecture
+	#error uC++ : internal error, unsupported architecture
 #endif
 #else
-	#error uC++ internal error : unsupported architecture
+	#error uC++ : internal error, unsupported architecture
 #endif
 	return sp;
     } else {						// accessing another coroutine
@@ -361,90 +483,100 @@ void *uMachContext::uStackPointer() const {
 	return (void *)(((ucontext_t *)uStorage)->uc_mcontext.
 #if defined( __linux__ ) && defined( __i386__ )
 	    gregs[REG_ESP]);
+#elif defined( __linux__ ) && defined( __x86_64__ )
+	    gregs[REG_RSP]);
 #elif defined( __linux__ ) && defined( __ia64__ )
 	    sc_gr[12]);
 #elif defined( __solaris__ ) && defined( __sparc__ )
-	    gregs[REG_SP]);
+	    (void*)((char*)gregs[REG_SP] + STACK_BIAS));
 #elif defined( __irix__ ) &&  defined( __mips__ )
 	    gregs[CTX_SP]);
 #else
-	    #error uC++ internal error : unsupported architecture
+	    #error uC++ : internal error, unsupported architecture
 #endif
+#else
+#if defined( __sparc__ )
+	return (void*)((char*)((uContext_t *)uStorage)->uSP + STACK_BIAS);
 #else
 	return ((uContext_t *)uStorage)->uSP;
+#endif // __sparc__
 #endif
     } // if
-} // uMachContext::uStackPointer
+} // uMachContext::stackPointer
 
 
 #if defined( __ia64__ )
-void *uMachContext::uRegisterStackPointer() const {
+void *uMachContext::registerStackPointer() const {
 #if defined( __U_SWAPCONTEXT__ )
     if ( &uThisCoroutine() == this ) {			// accessing myself ?
+#if defined( __INTEL_COMPILER )
+	return (void*)__getReg( _IA64_REG_AR_BSP );
+#else
 	void *bsp;					// use my current stack value
 	asm("mov %0 = ar.bsp" : "=r" (bsp) : );
 	return bsp;
+#endif // __INTEL_COMPILER
     } else {						// accessing another coroutine
 	return (void *)(((ucontext_t *)uStorage)->uc_mcontext.sc_ar_bsp);
     } // if
 #else
-    #error uC++ internal error : swapcontext must be used on the ia64 architecture
+    return ((uContext_t *)uStorage)->uBSP;
 #endif
-} // uMachContext::uRegisterStackPointer
+} // uMachContext::registerStackPointer
 #endif // __ia64__
 
 
-unsigned int uMachContext::uStackSize() const {
+unsigned int uMachContext::stackSize() const {
     return uSize;
-} // uMachContext::uStackSize
+} // uMachContext::stackSize
 
 
-ptrdiff_t uMachContext::uStackFree() const {
-    return (char *)uStackPointer() - (char *)uLimit;
-} // uMachContext::uStackFree
+ptrdiff_t uMachContext::stackFree() const {
+    return (char *)stackPointer() - (char *)uLimit;
+} // uMachContext::stackFree
 
 
-ptrdiff_t uMachContext::uStackUsed() const {
-    ptrdiff_t amt = (char *)uBase - (char *)uStackPointer();
+ptrdiff_t uMachContext::stackUsed() const {
+    ptrdiff_t amt = (char *)uBase - (char *)stackPointer();
     return amt < 0 ? -amt : amt;			// abs, for stacks growing up
-} // uMachContext::uStackUsed
+} // uMachContext::stackUsed
 
 
-void uMachContext::uVerify() {
+void uMachContext::verify() {
     // Ignore the boot task as it uses the UNIX stack.
     if ( uStorage == ((uBaseTask *)uKernelModule::uTaskBoot)->uStorage ) return;
 
-    if ( uStackPointer() < uLimit ) {
-	uAbort( ": stack overflow detected: stack pointer 0x%p below limit 0x%p.\n"
+    if ( stackPointer() < uLimit ) {
+	uAbort( "Stack overflow detected: stack pointer 0x%p below limit 0x%p.\n"
 		"Possible cause is allocation of large stack frame(s) and/or deep call stack.",
-		uStackPointer(), uLimit );
-    } else if ( (char *)uStackPointer() + 4 * 1024 < uLimit ) {
-	fprintf( stderr, ": WARNING within 4K of stack limit: stack pointer 0x%p and limit 0x%p.\n"
+		stackPointer(), uLimit );
+    } else if ( (char *)stackPointer() + 4 * 1024 < uLimit ) {
+	fprintf( stderr, "WARNING within 4K of stack limit: stack pointer 0x%p and limit 0x%p.\n"
 		 "Possible cause is allocation of large stack frame(s) and/or deep call stack.\n",
-		 uStackPointer(), uLimit );
-    } else if ( uStackPointer() > uBase ) {
-	uAbort( ": stack corruption detected.\n"
+		 stackPointer(), uLimit );
+    } else if ( stackPointer() > uBase ) {
+	uAbort( "Stack underflow detected.\n"
 		"Possible cause is corrupted stack frame via overwriting memory." );
     } else if ( ( *(unsigned int *)uBase != uMagic() ) || ( *(unsigned int *)((char *)uLimit - 16) != uMagic() ) ) {
-	uAbort( ": stack corruption detected.\n"
+	uAbort( "Stack corruption detected.\n"
 		"Possible cause is corrupted stack frame via overwriting memory." );
 #if defined( __ia64__ )
-    } else if ( uRegisterStackPointer() >= uStackPointer() ) {
+    } else if ( registerStackPointer() >= stackPointer() ) {
         // on ia64 the stack grows from both ends; when the two stack pointers cross, we have overflow
-	uAbort( ": stack overflow detected: stack pointer 0x%p at or below register stack pointer 0x%p.\n"
+	uAbort( "Stack overflow detected: stack pointer 0x%p at or below register stack pointer 0x%p.\n"
 		"Possible cause is allocation of large stack frame(s) and/or deep call stack.",
-		uStackPointer(), uRegisterStackPointer() );
+		stackPointer(), registerStackPointer() );
 #endif // __ia64__
     } // if
-} // uMachContext::uVerify
+} // uMachContext::verify
 
 
 void uMachContext::uExtraSave() {
     // Don't need to test extras bit, it is sufficent to check context list
 
     uContext *context;
-    for ( uSeqGen<uContext> gen(uAdditionalContexts); gen >> context; ) {
-	context->uSave();
+    for ( uSeqIter<uContext> iter(uAdditionalContexts); iter >> context; ) {
+	context->save();
     } // for
 } // uMachContext::uExtraSave
 
@@ -453,8 +585,8 @@ void uMachContext::uExtraRestore() {
     // Don't need to test extras bit, it is sufficent to check context list
 
     uContext *context;
-    for ( uSeqGen<uContext> gen(uAdditionalContexts); gen >> context; ) {
-	context->uRestore();
+    for ( uSeqIter<uContext> iter(uAdditionalContexts); iter >> context; ) {
+	context->restore();
     } // for
 } // uMachContext::uExtraRestore
 
