@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uNBIO.cc -- non-blocking IO
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Mar  7 13:56:53 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Aug  7 11:21:51 2004
-// Update Count     : 491
+// Last Modified On : Sat Dec  3 08:27:31 2005
+// Update Count     : 510
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -74,9 +74,9 @@ void uNBIO::uCheckIO( uDuration delay ) {
     // Make a local copy of the fd sets because the select operation destroys
     // the sets and the master information is lost.
 
-    fd_set lrfds = uRFDs;
-    fd_set lwfds = uWFDs;
-    fd_set lefds = uEFDs;
+    lrfds = uRFDs;
+    lwfds = uWFDs;
+    lefds = uEFDs;
 
     // This processor is about to become idle. First, interrupts are disabled
     // because the following operations affect some kernel data structures.
@@ -89,9 +89,9 @@ void uNBIO::uCheckIO( uDuration delay ) {
     // "select". In such a case, the SIGALRM is treated as spurious.
     // Therefore, it is necessary to poll.
 
-    THREAD_GETMEM( uSelf )->uDisableInterrupts();
+    THREAD_GETMEM( uSelf )->disableInterrupts();
 
-    int uPrevTime = uThisProcessor().uGetPreemption();	// remember previous preemption time
+    int uPrevTime = uThisProcessor().getPreemption();	// remember previous preemption time
     if ( uPrevTime != 0 ) {				// optimize out UNIX call if possible
 	uThisProcessor().uSetContextSwitchEvent( 0 );	// turn off preemption or it keeps waking the UNIX processor
     } // if
@@ -130,7 +130,7 @@ void uNBIO::uCheckIO( uDuration delay ) {
 	uThisProcessor().uSetContextSwitchEvent( uPrevTime ); // reset processor preemption time
     } // if
 
-    THREAD_GETMEM( uSelf )->uEnableInterrupts();	// does necessary roll forward
+    THREAD_GETMEM( uSelf )->enableInterrupts();		// does necessary roll forward
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uNBIO &)0x%p.uCheckIO: select returns: found %d, timeout:%ld,%ld\n", this, uFound, timeout.tv_sec, timeout.tv_usec );
@@ -180,12 +180,12 @@ void uNBIO::uCheckIO( uDuration delay ) {
 
 	uNBIOnode *p;
 	int cnt;
-	for ( uSeqGen<uNBIOnode> gen(uPendingIO); gen >> p; ) {
+	for ( uSeqIter<uNBIOnode> iter(uPendingIO); iter >> p; ) {
 	    cnt = 0;
 	    if ( p->fdType == uNBIOnode::singleFd ) {	// single fd
 #ifdef __U_DEBUG_H__
 		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: found task %.256s (0x%p) waiting on single fd %d with mask 0x%x\n",
-			   this, p->uPendingTask->uGetName(), p->uPendingTask, p->smfd.sfd.fd, *p->smfd.sfd.uRWE );
+			   this, p->uPendingTask->getName(), p->uPendingTask, p->smfd.sfd.fd, *p->smfd.sfd.uRWE );
 #endif // __U_DEBUG_H__
 		int temp = 0;
 		if ( (*p->smfd.sfd.uRWE & uCluster::uReadSelect) && FD_ISSET( p->smfd.sfd.fd, &lrfds ) ) {
@@ -206,7 +206,7 @@ void uNBIO::uCheckIO( uDuration delay ) {
 	    } else {					// multiple fds
 #ifdef __U_DEBUG_H__
 		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: found task %.256s (0x%p) waiting for multiple fd, nfd:%ld\n",
-			   this, p->uPendingTask->uGetName(), p->uPendingTask, p->smfd.mfd.uNFDs );
+			   this, p->uPendingTask->getName(), p->uPendingTask, p->smfd.mfd.uNFDs );
 #endif // __U_DEBUG_H__
 		fd_set tfds;				// temporary masks to construct result mask
 		int nmasks = howmany( p->smfd.mfd.uNFDs, NFDBITS );
@@ -313,9 +313,9 @@ void uNBIO::uCheckIO( uDuration delay ) {
 #ifdef __U_DEBUG_H__
 		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: removing node 0x%p, cnt:%d, uTimedout:%d\n", this, p, cnt, p->uTimedout );
 #endif // __U_DEBUG_H__
-		uPendingIO.uRemove( p );		// remove node from list of waiting tasks
+		uPendingIO.remove( p );			// remove node from list of waiting tasks
 		p->nfds = cnt;				// set return value
-		uSignal p->uPending;			// wake up waiting task (empty for IOPoller)
+		p->uPending.signal();			// wake up waiting task (empty for IOPoller)
 	    } // if
 	} // for
     } else if ( uFound == 0 ) {				// time limit expired, no IO is ready
@@ -325,14 +325,14 @@ void uNBIO::uCheckIO( uDuration delay ) {
 	// Check for timed out IO
 
 	uNBIOnode *p;
-	for ( uSeqGen<uNBIOnode> gen(uPendingIO); gen >> p; ) {
+	for ( uSeqIter<uNBIOnode> iter(uPendingIO); iter >> p; ) {
 	    if ( p->uTimedout ) {			// timed out waiting for I/O for this task ?
 #ifdef __U_DEBUG_H__
 		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: removing node 0x%p\n", this, p );
 #endif // __U_DEBUG_H__
-		uPendingIO.uRemove( p );		// remove node from list of waiting tasks
+		uPendingIO.remove( p );			// remove node from list of waiting tasks
 		p->nfds = 0;				// set return value
-		uSignal p->uPending;			// wake up waiting task (empty for IOPoller)
+		p->uPending.signal();			// wake up waiting task (empty for IOPoller)
 	    } // if
 	} // for
     } else {
@@ -352,10 +352,10 @@ void uNBIO::uCheckIO( uDuration delay ) {
 	    // hope they catch the error this time.
 
 	    uNBIOnode *p;
-	    for ( uSeqGen<uNBIOnode> gen(uPendingIO); gen >> p; ) {
-		uPendingIO.uRemove( p );		// remove node from list of waiting tasks
+	    for ( uSeqIter<uNBIOnode> iter(uPendingIO); iter >> p; ) {
+		uPendingIO.remove( p );			// remove node from list of waiting tasks
 		p->nfds = -1;				// mark the fact that something is wrong
-		uSignal p->uPending;			// wake up waiting task (empty for IOPoller)
+		p->uPending.signal();			// wake up waiting task (empty for IOPoller)
 	    } // for
 	} else {
 	    uAbort( "(uNBIO &)0x%p.uCheckIO() : internal error, error(%d) %s.", this, errno, strerror( errno ) );
@@ -365,7 +365,7 @@ void uNBIO::uCheckIO( uDuration delay ) {
 
 
 bool uNBIO::uCheckPoller( uNBIOnode &uNode ) {
-    uPendingIO.uAddTail( &uNode );			// node is removed by IOPoller
+    uPendingIO.addTail( &uNode );			// node is removed by IOPoller
 
     // If this is the first task to register interest, this task is nominated
     // as the IO poller task.
@@ -373,19 +373,19 @@ bool uNBIO::uCheckPoller( uNBIOnode &uNode ) {
     if ( uIOPoller == NULL ) {
 	uIOPoller = &uThisTask();			// make this task the poller
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uNBIO &)0x%p.uCheckPoller, set poller task %.256s (0x%p)\n", this, uIOPoller->uGetName(), uIOPoller );
+	uDebugPrt( "(uNBIO &)0x%p.uCheckPoller, set poller task %.256s (0x%p)\n", this, uIOPoller->getName(), uIOPoller );
 #endif // __U_DEBUG_H__
 	return true;
     } else {
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uNBIO &)0x%p.uCheckPoller, blocking non-poller I/O task %.256s (0x%p))\n", this, uThisTask().uGetName(), &uThisTask() );
+	uDebugPrt( "(uNBIO &)0x%p.uCheckPoller, blocking non-poller I/O task %.256s (0x%p))\n", this, uThisTask().getName(), &uThisTask() );
 #endif // __U_DEBUG_H__
 	// This is not the poller task so add it to the list of tasks waiting
 	// for IO events.  It is woken when an IO event is ready or nominated
 	// as the poller.
 
-	uWait uNode.uPending;
-	if ( uNode.uListed() ) {			// poller ?
+	uNode.uPending.wait();
+	if ( uNode.listed() ) {			// poller ?
 	    uAssert( uIOPoller == &uThisTask() );
 	    return true;
 	} else {
@@ -399,11 +399,15 @@ void uNBIO::setMaxFD(){
     int prevMax = maxFD;
     maxFD = 0;
 #if 1
+#if defined( __irix__ )
+    fd_mask_t combined;
+#else
     unsigned long combined;
+#endif
 
     // This code makes assumptions about the implemenetation of fd_set.  Namely
-    // that each chunk is an unsigned long and that the rightmost bit contains
-    // the lowest numbered fd.
+    // that the size of each chunk is the same as the size of "combined" and that
+    // the rightmost bit contains the lowest numbered fd.
     _STATIC_ASSERT_( (sizeof(combined) * 8) == NFDBITS );
     
     // Search backwards from previous max
@@ -469,8 +473,8 @@ bool uNBIO::uPollIO( uNBIOnode &uNode ) {
 	uTime nexttime;
 	uDuration timeout;
 
-	nexttime = uThisProcessor().uEvents->uNextAlarm(); // find first non-context-switch event
-	timeout = nexttime - uThisProcessor().uGetClock().uGetTime(); // time to sleep
+	nexttime = uEventList::uNextAlarm();		// find first non-context-switch event
+	timeout = nexttime - uThisProcessor().getClock().getTime(); // time to sleep
 
 	// The minimum wake up time is always uSelectTimeOut to deal with the
 	// problem of a missing SIGALRM due to the race condition with
@@ -490,19 +494,19 @@ bool uNBIO::uPollIO( uNBIOnode &uNode ) {
     // If the IOPoller's I/O completed, attempt to nominate another waiting
     // task to be the IOPoller.
 
-    if ( ! uNode.uListed() ) {				// IOPoller's node removed ?
-	if ( ! uPendingIO.uEmpty() ) {			// any other tasks waiting for IO?
+    if ( ! uNode.listed() ) {				// IOPoller's node removed ?
+	if ( ! uPendingIO.empty() ) {			// any other tasks waiting for IO?
 	    // For the uniprocessor kernel, the new poller will appear to have
 	    // found some IO because uFound is not cleared until the new poller
 	    // makes a call to check for IO.
 
-	    uNBIOnode *p = uPendingIO.uHead();		// node from list of waiting tasks
+	    uNBIOnode *p = uPendingIO.head();		// node from list of waiting tasks
 	    uIOPoller = p->uPendingTask;		// next poller task
 #ifdef __U_DEBUG_H__
 	    uDebugPrt( "(uNBIO &)0x%p.uPollIO, poller %.256s (0x%p) nominating task %.256s (0x%p) to be next poller\n",
-		       this, uThisTask().uGetName(), &uThisTask(), uIOPoller->uGetName(), uIOPoller );
+		       this, uThisTask().getName(), &uThisTask(), uIOPoller->getName(), uIOPoller );
 #endif // __U_DEBUG_H__
-	    uSignal p->uPending;			// wake up waiting task
+	    p->uPending.signal();			// wake up waiting task
 	} else {
 	    uIOPoller = NULL;
 	} // if
@@ -531,7 +535,7 @@ bool uNBIO::uInitSfd( uNBIOnode &uNode ) {
 } // uNBIO::uInitSfd
 
 
-bool uNBIO::uInitSfd( uNBIOnode &uNode, uEventNode &uTimeoutEvent, uProcessor &proc ) {
+bool uNBIO::uInitSfd( uNBIOnode &uNode, uEventNode &uTimeoutEvent ) {
     if ( uNode.smfd.sfd.fd > maxFD ) {			// increase maxFD if necessary
 	maxFD = uNode.smfd.sfd.fd;
     } // if
@@ -545,7 +549,7 @@ bool uNBIO::uInitSfd( uNBIOnode &uNode, uEventNode &uTimeoutEvent, uProcessor &p
     uDebugPrt( "(uNBIO &)0x%p.uInitSfd, adding node 0x%p\n", this, &uNode );
 #endif // __U_DEBUG_H__
 
-    proc.uEvents->uAddEvent( uTimeoutEvent, proc );
+    uTimeoutEvent.add();
 
     return uCheckPoller( uNode );
 } // uNBIO::uInitSfd
@@ -584,7 +588,7 @@ int uNBIO::uSelect( int fd, int &rwe, timeval *timeout ) {
 
 #ifdef __U_DEBUG__
     if ( fd < 0 || FD_SETSIZE <= fd ) {
-	uAbort( ": attempt to select on file descriptor %d, which exceeds range 0-%d.",
+	uAbort( "Attempt to select on file descriptor %d, which exceeds range 0-%d.",
 		fd, FD_SETSIZE - 1 );
     } // if
 #endif // __U_DEBUG__
@@ -604,27 +608,26 @@ int uNBIO::uSelect( int fd, int &rwe, timeval *timeout ) {
 
 	    uNode.uTimedout = true;
 	    if ( uInitSfd( uNode ) ) {			// poller task ?
-		while ( uPollIO( uNode ) ) uThisTask().uYield(); // busy wait
+		while ( uPollIO( uNode ) ) uThisTask().yield(); // busy wait
 	    } // if
 	} else {
 	    uDuration delay( timeout->tv_sec, timeout->tv_usec * 1000 );
-	    uTime time = uActiveProcessorKernel->uKernelClock.uGetTime() + delay;
+	    uTime time = uActiveProcessorKernel->uKernelClock.getTime() + delay;
 	    uSelectTimeoutHndlr handler( uThisTask(), uNode );
 
 	    uEventNode uTimeoutEvent( uThisTask(), handler, time ); // event node for event list
 	    uTimeoutEvent.uExecuteLocked = true;
-	    uProcessor &proc = uThisProcessor();	// copy the current processor as it could change during execution
 
-	    if ( uInitSfd( uNode, uTimeoutEvent, proc ) ) { // poller task ?
-		while ( uPollIO( uNode ) ) uThisTask().uYield(); // busy wait
+	    if ( uInitSfd( uNode, uTimeoutEvent ) ) {	// poller task ?
+		while ( uPollIO( uNode ) ) uThisTask().yield(); // busy wait
 	    } // if
 
 	    // always doing remove guarantees the node is not deallocated prematurely
-	    proc.uEvents->uRemoveEvent( uTimeoutEvent, proc );
+	    uTimeoutEvent.remove();
 	} // if
     } else {
 	if ( uInitSfd( uNode ) ) {			// poller task ?
-	    while ( uPollIO( uNode ) ) uThisTask().uYield(); // busy wait
+	    while ( uPollIO( uNode ) ) uThisTask().yield(); // busy wait
 	} // if
     } // if
 
@@ -656,7 +659,7 @@ bool uNBIO::uInitMfds( fd_mask nfds, uNBIOnode &uNode ) {
 } // uNBIO::uInitMfds
 
      
-bool uNBIO::uInitMfds( fd_mask nfds, uNBIOnode &uNode, uEventNode &uTimeoutEvent, uProcessor &proc ) {
+bool uNBIO::uInitMfds( fd_mask nfds, uNBIOnode &uNode, uEventNode &uTimeoutEvent ) {
     if ( nfds > maxFD ) {				// increase maxFD if necessary
 	maxFD = nfds - 1;
     } // if
@@ -673,7 +676,7 @@ bool uNBIO::uInitMfds( fd_mask nfds, uNBIOnode &uNode, uEventNode &uTimeoutEvent
     uDebugPrt( "(uNBIO &)0x%p.uInitMfds, adding node 0x%p\n", this, &uNode );
 #endif // __U_DEBUG_H__
 
-    proc.uEvents->uAddEvent( uTimeoutEvent, proc );
+    uTimeoutEvent.add();
 
     return uCheckPoller( uNode );
 } // uNBIO::uInitMfds
@@ -716,7 +719,7 @@ int uNBIO::uSelect( fd_mask nfds, fd_set *rfds, fd_set *wfds, fd_set *efds, time
 
 #ifdef __U_DEBUG__
     if ( nfds < 1 || FD_SETSIZE < nfds ) {
-	uAbort( ": attempt to select with a file descriptor set size of %ld, which exceeds range 0-%d.",
+	uAbort( "Attempt to select with a file descriptor set size of %ld, which exceeds range 0-%d.",
 		(long int)nfds, FD_SETSIZE );
     } // if
 #endif // __U_DEBUG__
@@ -738,27 +741,26 @@ int uNBIO::uSelect( fd_mask nfds, fd_set *rfds, fd_set *wfds, fd_set *efds, time
 
 	    uNode.uTimedout = true;
 	    if ( uInitMfds( nfds, uNode ) ) {		// poller task ?
-		while ( uPollIO( uNode ) ) uThisTask().uYield(); // busy wait
+		while ( uPollIO( uNode ) ) uThisTask().yield(); // busy wait
 	    } // if
 	} else {
 	    uDuration delay( timeout->tv_sec, timeout->tv_usec * 1000 );
-	    uTime time = uActiveProcessorKernel->uKernelClock.uGetTime() + delay;
+	    uTime time = uActiveProcessorKernel->uKernelClock.getTime() + delay;
 	    uSelectTimeoutHndlr handler( uThisTask(), uNode );
 
 	    uEventNode uTimeoutEvent( uThisTask(), handler, time ); // event node for event list
 	    uTimeoutEvent.uExecuteLocked = true;
-	    uProcessor &proc = uThisProcessor();	// copy the current processor as it could change during execution
 
-	    if ( uInitMfds( nfds, uNode, uTimeoutEvent, proc ) ) { // poller task ?
-		while ( uPollIO( uNode ) ) uThisTask().uYield(); // busy wait
+	    if ( uInitMfds( nfds, uNode, uTimeoutEvent ) ) { // poller task ?
+		while ( uPollIO( uNode ) ) uThisTask().yield(); // busy wait
 	    } // if
 
 	    // always doing remove guarantees the node is not deallocated prematurely
-	    proc.uEvents->uRemoveEvent( uTimeoutEvent, proc );
+	    uTimeoutEvent.remove();
 	} // if
     } else {
 	if ( uInitMfds( nfds, uNode ) ) {		// poller task ?
-	    while ( uPollIO( uNode ) ) uThisTask().uYield(); // busy wait
+	    while ( uPollIO( uNode ) ) uThisTask().yield(); // busy wait
 	} // if
     } // if
 
