@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 2002
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 2002
 // 
 // Unix.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Dec  2 22:46:18 2002
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Aug  6 14:16:17 2004
-// Update Count     : 16
+// Last Modified On : Fri Aug 12 17:24:57 2005
+// Update Count     : 19
 // 
 
 #include <uC++.h>
@@ -19,16 +19,16 @@ extern "C" unsigned int sleep( unsigned int sec ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "sleep ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ\n" );
 #endif // __U_DEBUG_H__
-    uTimeout( uDuration( sec, 0 ) );
+    _Timeout( uDuration( sec, 0 ) );
     return 0;
 } // sleep
 
 extern "C" int usleep( unsigned int usec ) {
-    uTimeout( uDuration( 0, usec ) );
+    _Timeout( uDuration( 0, usec ) );
     return 0;
 } // usleep
 
-extern "C" unsigned int alarm( unsigned int sec ) {
+extern "C" unsigned int alarm( unsigned int sec ) __THROW {
     uAbort( "alarm : not implemented" );
     return 0;
 } // alarm
