@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uFile.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Tue Mar 29 16:42:36 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Aug 11 14:11:49 2004
-// Update Count     : 279
+// Last Modified On : Fri Jun 24 14:48:32 2005
+// Update Count     : 293
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -28,15 +28,12 @@
 #define __U_KERNEL__
 #include <uC++.h>
 #include <uFile.h>
-#include <uSocket.h>
 
 //#include <uDebug.h>
 
 #include <cstring>					// strerror
 #include <unistd.h>					// read, write, close, etc.
-#if defined( __linux__ )
 #include <sys/uio.h>					// readv, writev
-#endif // __linux__
 
 
 //######################### uFile #########################
@@ -46,35 +43,41 @@ void uFile::access() {
     accessCnt += 1;
 } // uFile::access
 
+
 void uFile::unaccess() {
     accessCnt -= 1;
 } // uFile::unaccess
 
+
 void uFile::uCreateFile( const char *name ) {
     uName = new char[strlen( name ) + 1];
     strcpy( uName, name );
     accessCnt = 0;
 } // uFile::uCreateFile
 
+
 uFile::uFile( const char *name ) {
     uCreateFile( name );
 } // uFile::uFile
 
+
 uFile::~uFile() {
-    uTerminateFailure temp( *this, accessCnt, "terminating access with outstanding accessor(s)" );
+    TerminateFailure temp( *this, accessCnt, "terminating access with outstanding accessor(s)" );
     if ( uName != 0 ) delete uName;			// safe to delete name as the name is copied in the exception object
     if ( accessCnt != 0 ) {
-	if ( ! std::uncaught_exception() ) uThrow temp;
+	if ( ! std::uncaught_exception() ) _Throw temp;
     } // if
 } // uFile::~uFile
 
-const char *uFile::uGetName() const {
+
+const char *uFile::getName() const {
     return
 #ifdef __U_DEBUG__
 	( uName == NULL || uName == (const char *)-1 ) ? "*unknown*" : // storage might be scrubbed
 #endif // __U_DEBUG__
 	uName;
-} // uFile::uGetName
+} // uFile::getName
+
 
 void uFile::status( struct stat &buf ) {
     int code;
@@ -85,7 +88,7 @@ void uFile::status( struct stat &buf ) {
       if ( errno != EINTR ) break;			// timer interrupt ?
     } // for
     if ( code == -1 ) {
-	uRaise uFile::uStatusFailure( *this, buf, "could not obtain statistical information for file" );
+	_Resume uFile::StatusFailure( *this, buf, "could not obtain statistical information for file" );
     } // if
 } // uFile::status
 
@@ -96,9 +99,11 @@ void uFile::status( struct stat &buf ) {
 uFileIO::uFileIO( uIOaccess &acc ) : access( acc ) {
 } // uFileIO::uFileIO
 
+
 uFileIO::~uFileIO() {
 } // uFileIO::~uFileIO
 
+
 int uFileIO::_read( char *buf, int len ) {
     if ( access.poll.uGetStatus() == uPoll::uPollOnDemand ) access.poll.uSetPollFlag( access.fd );
     int rlen = ::read( access.fd, buf, len );
@@ -111,13 +116,10 @@ int uFileIO::_read( char *buf, int len ) {
     return rlen;
 } // uFileIO::_read
 
+
 int uFileIO::_readv( const struct iovec *iov, int iovcnt ) {
     if ( access.poll.uGetStatus() == uPoll::uPollOnDemand ) access.poll.uSetPollFlag( access.fd );
-    int rlen = ::readv( access.fd,
-#ifdef __osf__
-			(struct iovec *)		// TEMPORARY: missing "const"
-#endif // __osf__
-			iov, iovcnt );
+    int rlen = ::readv( access.fd, iov, iovcnt );
     int terrno = errno;					// preserve errno across calls
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uFileIO &)0x%p._readv attempting readv to fd:%d, rlen:%d, errno:%d\n", this, access.fd, rlen, errno );
@@ -127,6 +129,7 @@ int uFileIO::_readv( const struct iovec *iov, int iovcnt ) {
     return rlen;
 } // uFileIO::_readv
 
+
 int uFileIO::_write( char *buf, int len ) {
     if ( access.poll.uGetStatus() == uPoll::uPollOnDemand ) access.poll.uSetPollFlag( access.fd );
     int wlen = ::write( access.fd, buf, len );
@@ -139,13 +142,10 @@ int uFileIO::_write( char *buf, int len ) {
     return wlen;
 } // uFileIO::_write
 
+
 int uFileIO::_writev( const struct iovec *iov, int iovcnt ) {
     if ( access.poll.uGetStatus() == uPoll::uPollOnDemand ) access.poll.uSetPollFlag( access.fd );
-    int wlen = ::writev( access.fd,
-#ifdef __osf__
-			(struct iovec *)		// TEMPORARY: missing "const"
-#endif // __osf__
-			 iov, iovcnt );
+    int wlen = ::writev( access.fd, iov, iovcnt );
     int terrno = errno;					// preserve errno across calls
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uFileIO &)0x%p._writev attempting writev to fd:%d, wlen:%d, errno:%d\n", this, access.fd, wlen, errno );
@@ -155,6 +155,7 @@ int uFileIO::_writev( const struct iovec *iov, int iovcnt ) {
     return wlen;
 } // uFileIO::_writev
 
+
 int uFileIO::read( char *buf, int len, uDuration *timeout ) {
     int rlen;
 
@@ -173,31 +174,14 @@ int uFileIO::read( char *buf, int len, uDuration *timeout ) {
 	    } else {
 		timeval t = *timeout;			// convert to timeval for select
 		if ( uThisCluster().uSelect( access.fd, mask, &t ) == 0 ) { // timeout ?
-		    // determine derived type using C++ idiom
-		    if ( uFileAccess *fa = dynamic_cast<uFileAccess *>(this) ) {
-			uThrow uFileAccess::uReadTimeout( *fa, buf, len, timeout, "timeout during file read" );
-		    } else if ( uSocketAccept *sa = dynamic_cast<uSocketAccept *>(this) ) {
-			uThrow uSocketAccept::uReadTimeout( *sa, buf, len, 0, NULL, 0, timeout, "timeout during socket read" );
-		    } else if ( uSocketClient *sc = dynamic_cast<uSocketClient *>(this) ) {
-			uThrow uSocketClient::uReadTimeout( *sc, buf, len, 0, NULL, 0, timeout, "timeout during socket read" );
-		    } else {
-			uAbort( "(uFileIO &)0x%p.read : internal error, invalid runtime type", this );
-		    } // if
+		    readTimeout( buf, len, timeout, "read" );
 		} // if
 	    } // if
 	} // if
     } // for    
 
     if ( rlen == -1 ) {
-	if ( uFileAccess *fa = dynamic_cast<uFileAccess *>(this) ) {
-	    uThrow uFileAccess::uReadFailure( *fa, buf, len, timeout, "file read fails" );
-	} else if ( uSocketAccept *sa = dynamic_cast<uSocketAccept *>(this) ) {
-	    uThrow uSocketAccept::uReadFailure( *sa, buf, len, 0, NULL, 0, timeout, "socket read fails" );
-	} else if ( uSocketClient *sc = dynamic_cast<uSocketClient *>(this) ) {
-	    uThrow uSocketClient::uReadFailure( *sc, buf, len, 0, NULL, 0, timeout, "socket read fails" );
-	} else {
-	    uAbort( "(uFileIO &)0x%p.read : internal error, invalid runtime type", this );
-	} // if
+	readFailure( buf, len, timeout, "read" );
     } // if
 
 #ifdef __U_DEBUG_H__
@@ -206,6 +190,7 @@ int uFileIO::read( char *buf, int len, uDuration *timeout ) {
     return rlen;
 } // uFileIO::read
 
+
 int uFileIO::readv( const struct iovec *iov, int iovcnt, uDuration *timeout ) {
     int rlen;
 
@@ -224,30 +209,13 @@ int uFileIO::readv( const struct iovec *iov, int iovcnt, uDuration *timeout ) {
 	    } else {
 		timeval t = *timeout;			// convert to timeval for select
 		if ( uThisCluster().uSelect( access.fd, mask, &t ) == 0 ) { // timeout ?
-		    // determine derived type using C++ idiom
-		    if ( uFileAccess *fa = dynamic_cast<uFileAccess *>(this) ) {
-			uThrow uFileAccess::uReadTimeout( *fa, (const char *)iov, iovcnt, timeout, "timeout during file readv" );
-		    } else if ( uSocketAccept *sa = dynamic_cast<uSocketAccept *>(this) ) {
-			uThrow uSocketAccept::uReadTimeout( *sa, (const char *)iov, iovcnt, 0, NULL, 0, timeout, "timeout during socket readv" );
-		    } else if ( uSocketClient *sc = dynamic_cast<uSocketClient *>(this) ) {
-			uThrow uSocketClient::uReadTimeout( *sc, (const char *)iov, iovcnt, 0, NULL, 0, timeout, "timeout during socket readv" );
-		    } else {
-			uAbort( "(uFileIO &)0x%p.readv : internal error, invalid runtime type", this );
-		    } // if
+		    readTimeout( (const char *)iov, iovcnt, timeout, "readv" );
 		} // if
 	    } // if
 	} // if
     } // for    
     if ( rlen == -1 ) {
-	if ( uFileAccess *fa = dynamic_cast<uFileAccess *>(this) ) {
-	    uThrow uFileAccess::uReadFailure( *fa, (const char *)iov, iovcnt, timeout, "file readv fails" );
-	} else if ( uSocketAccept *sa = dynamic_cast<uSocketAccept *>(this) ) {
-	    uThrow uSocketAccept::uReadFailure( *sa, (const char *)iov, iovcnt, 0, NULL, 0, timeout, "socket readv fails" );
-	} else if ( uSocketClient *sc = dynamic_cast<uSocketClient *>(this) ) {
-	    uThrow uSocketClient::uReadFailure( *sc, (const char *)iov, iovcnt, 0, NULL, 0, timeout, "socket readv fails" );
-	} else {
-	    uAbort( "(uFileIO &)0x%p.readv : internal error, invalid runtime type", this );
-	} // if
+	readFailure( (const char *)iov, iovcnt, timeout, "readv" );
     } // if
 
 #ifdef __U_DEBUG_H__
@@ -256,6 +224,7 @@ int uFileIO::readv( const struct iovec *iov, int iovcnt, uDuration *timeout ) {
     return rlen;
 } // uFileIO::readv
 
+
 int uFileIO::write( char *buf, int len, uDuration *timeout ) {
     int count, wlen;
 
@@ -275,15 +244,7 @@ int uFileIO::write( char *buf, int len, uDuration *timeout ) {
 		} else {
 		    timeval t = *timeout;		// convert to timeval for select
 		    if ( uThisCluster().uSelect( access.fd, mask, &t ) == 0 ) { // timeout ?
-			if ( uFileAccess *fa = dynamic_cast<uFileAccess *>(this) ) {
-			    uThrow uFileAccess::uWriteTimeout( *fa, buf, len, timeout, "timeout during file write" );
-			} else if ( uSocketAccept *sa = dynamic_cast<uSocketAccept *>(this) ) {
-			    uThrow uSocketAccept::uWriteTimeout( *sa, buf, len, 0, NULL, 0, timeout, "timeout during socket write" );
-			} else if ( uSocketClient *sc = dynamic_cast<uSocketClient *>(this) ) {
-			    uThrow uSocketClient::uWriteTimeout( *sc, buf, len, 0, NULL, 0, timeout, "timeout during socket write" );
-			} else {
-			    uAbort( "(uFileIO &)0x%p.write : internal error, invalid runtime type", this );
-			} // if
+			writeTimeout( buf, len, timeout, "write" );
 		    } // if
 		} // if
 	    } // if
@@ -297,15 +258,7 @@ int uFileIO::write( char *buf, int len, uDuration *timeout ) {
 
       if ( errno == EIO ) break;
 
-	    if ( uFileAccess *fa = dynamic_cast<uFileAccess *>(this) ) {
-		uThrow uFileAccess::uWriteFailure( *fa, buf, len, timeout, "file write fails" );
-	    } else if ( uSocketAccept *sa = dynamic_cast<uSocketAccept *>(this) ) {
-		uThrow uSocketAccept::uWriteFailure( *sa, buf, len, 0, NULL, 0, timeout, "socket write fails" );
-	    } else if ( uSocketClient *sc = dynamic_cast<uSocketClient *>(this) ) {
-		uThrow uSocketClient::uWriteFailure( *sc, buf, len, 0, NULL, 0, timeout, "socket write fails" );
-	    } else {
-		uAbort( "(uFileIO &)0x%p.write : internal error, invalid runtime type", this );
-	    } // if
+      	    writeFailure( buf, len, timeout, "write" );
 	} // if
     } // for
 
@@ -315,6 +268,7 @@ int uFileIO::write( char *buf, int len, uDuration *timeout ) {
     return len;						// always return the specified length
 } // uFileIO::write
 
+
 int uFileIO::writev( const struct iovec *iov, int iovcnt, uDuration *timeout ) {
     int wlen;
 
@@ -333,15 +287,7 @@ int uFileIO::writev( const struct iovec *iov, int iovcnt, uDuration *timeout ) {
 	    } else {
 		timeval t = *timeout;		// convert to timeval for select
 		if ( uThisCluster().uSelect( access.fd, mask, &t ) == 0 ) { // timeout ?
-		    if ( uFileAccess *fa = dynamic_cast<uFileAccess *>(this) ) {
-			uThrow uFileAccess::uWriteTimeout( *fa, (const char *)iov, iovcnt, timeout, "timeout during file writev" );
-		    } else if ( uSocketAccept *sa = dynamic_cast<uSocketAccept *>(this) ) {
-			uThrow uSocketAccept::uWriteTimeout( *sa, (const char *)iov, iovcnt, 0, NULL, 0, timeout, "timeout during socket writev" );
-		    } else if ( uSocketClient *sc = dynamic_cast<uSocketClient *>(this) ) {
-			uThrow uSocketClient::uWriteTimeout( *sc, (const char *)iov, iovcnt, 0, NULL, 0, timeout, "timeout during socket writev" );
-		    } else {
-			uAbort( "(uFileIO &)0x%p.writev : internal error, invalid runtime type", this );
-		    } // if
+		    writeTimeout( (const char *)iov, iovcnt, timeout, "writev" );
 		} // if
 	    } // if
 	} // if
@@ -352,15 +298,7 @@ int uFileIO::writev( const struct iovec *iov, int iovcnt, uDuration *timeout ) {
     // redirected to /dev/null, instead of aborting the program.
 
     if ( wlen == -1 && errno != EIO ) {
-	if ( uFileAccess *fa = dynamic_cast<uFileAccess *>(this) ) {
-	    uThrow uFileAccess::uWriteFailure( *fa, (const char *)iov, iovcnt, timeout, "file writev fails" );
-	} else if ( uSocketAccept *sa = dynamic_cast<uSocketAccept *>(this) ) {
-	    uThrow uSocketAccept::uWriteFailure( *sa, (const char *)iov, iovcnt, 0, NULL, 0, timeout, "socket writev fails" );
-	} else if ( uSocketClient *sc = dynamic_cast<uSocketClient *>(this) ) {
-	    uThrow uSocketClient::uWriteFailure( *sc, (const char *)iov, iovcnt, 0, NULL, 0, timeout, "socket writev fails" );
-	} else {
-	    uAbort( "(uFileIO &)0x%p.writev : internal error, invalid runtime type", this );
-	} // if
+	writeFailure( (const char *)iov, iovcnt, timeout, "writev" );
     } // if
 
 #ifdef __U_DEBUG_H__
@@ -378,12 +316,41 @@ int uFileIO::fd() {
 //######################### uFileAccess #########################
 
 
+void uFileAccess::readFailure( const char *buf, const int len, const uDuration *timeout, const char *const op ) {
+    char msg[32];
+    strcat( strcat( strcpy( msg, "file " ), op ), " fails" );
+    _Throw uFileAccess::ReadFailure( *this, buf, len, timeout, msg );
+} // uFileAccess::readFailure
+
+
+void uFileAccess::readTimeout( const char *buf, const int len, const uDuration *timeout, const char *const op ) {
+    char msg[32];
+    strcat( strcpy( msg, "timeout during file " ), op );
+    _Throw uFileAccess::ReadTimeout( *this, buf, len, timeout, msg );
+} // uFileAccess::readTimeout
+
+
+void uFileAccess::writeFailure( const char *buf, const int len, const uDuration *timeout, const char *const op ) {
+    char msg[32];
+    strcat( strcat( strcpy( msg, "file " ), op ), " fails" );
+    _Throw uFileAccess::WriteFailure( *this, buf, len, timeout, msg );
+} // uFileAccess::writeFailure
+
+
+void uFileAccess::writeTimeout( const char *buf, const int len, const uDuration *timeout, const char *const op ) {
+    char msg[32];
+    strcat( strcpy( msg, "timeout during file " ), op );
+    _Throw uFileAccess::WriteTimeout( *this, buf, len, timeout, msg );
+} // uFileAccess::writeTimeout
+
+
 uFileAccess::uFileAccess( int fd, uFile &f ) : uFileIO( access ), ufile( f ) {
     access.fd = fd;
     access.poll.uSetStatus( uPoll::uPollOnDemand );
     ufile.access();
 } // uFileAccess::uFileAccess
 
+
 uFileAccess::uFileAccess( uFile &f, int flags, int mode ) : uFileIO( access ), ufile( f ) {
     for ( ;; ) {
 	access.fd = ::open( ufile.uName, flags, mode );
@@ -391,13 +358,14 @@ uFileAccess::uFileAccess( uFile &f, int flags, int mode ) : uFileIO( access ), u
       if ( errno != EINTR ) break;			// timer interrupt ?
     } // for
     if ( access.fd == -1 ) {
-        uThrow uFileAccess::uOpenFailure( *this, flags, mode, "unable to access file" );
+        _Throw uFileAccess::OpenFailure( *this, flags, mode, "unable to access file" );
     } // if
     access.poll.uComputeStatus( access.fd );
     if ( access.poll.uGetStatus() == uPoll::uAlwaysPoll ) access.poll.uSetPollFlag( access.fd );
     ufile.access();
 } // uFileAccess::uFileAccess
 
+
 uFileAccess::~uFileAccess() {
     ufile.unaccess();
     if ( access.poll.uGetStatus() == uPoll::uAlwaysPoll ) access.poll.uClearPollFlag( access.fd );
@@ -411,11 +379,12 @@ uFileAccess::~uFileAccess() {
 	  if ( errno != EINTR ) break;			// timer interrupt ?
 	} // for
 	if ( code == -1 ) {
-	    if ( ! std::uncaught_exception() ) uRaise uFileAccess::uCloseFailure( *this, "unable to terminate access to file" );
+	    if ( ! std::uncaught_exception() ) _Resume uFileAccess::CloseFailure( *this, "unable to terminate access to file" );
 	} // if
     } // if
 } // uFileAccess::~uFileAccess
 
+
 off_t uFileAccess::lseek( off_t offset, int whence ) {
     off_t code;
 
@@ -425,11 +394,12 @@ off_t uFileAccess::lseek( off_t offset, int whence ) {
       if ( errno != EINTR ) break;			// timer interrupt ?
     } // for
     if ( code == -1 ) {
-        uThrow uFileAccess::uSeekFailure( *this, offset, whence, "could not seek file" );
+        _Throw uFileAccess::SeekFailure( *this, offset, whence, "could not seek file" );
     } // if
     return code;
 } // uFileAccess::lseek
 
+
 int uFileAccess::fsync() {
     int code;
 
@@ -439,7 +409,7 @@ int uFileAccess::fsync() {
       if ( errno != EINTR ) break;			// timer interrupt ?
     } // for
     if ( code == -1 ) {
-        uThrow uFileAccess::uSyncFailure( *this, "could not fsync file" );
+        _Throw uFileAccess::SyncFailure( *this, "could not fsync file" );
     } // if
     return code;
 } // uFileAccess::fsync
@@ -448,141 +418,122 @@ int uFileAccess::fsync() {
 //######################### uFile (cont) #########################
 
 
-uFile::uFailure::uFailure( const uFile &f, const char *const msg ) : uIOFailure( msg ), f( f ) {
+uFile::Failure::Failure( const uFile &f, const char *const msg ) : uIOFailure( msg ), f( f ) {
     // file name is copied because its storage can be freed and scrubbed before handler starts
-    strncpy( uName, f.uGetName(), uEHMMaxName );
-    if ( strlen( f.uGetName() ) > uEHMMaxName ) {	// name too long ?
-	strcpy( &uName[uEHMMaxName], "..." );		// add 4 character ...
-    } // if
-} // uFile::uFailure::uFailure
+    uEHM::uStrncpy( uName, f.getName(), uEHMMaxName );
+} // uFile::Failure::Failure
 
-uFile::uFailure::~uFailure() {}
+uFile::Failure::~Failure() {}
 
-const uFile &uFile::uFailure::file() const { return f; }
+const uFile &uFile::Failure::file() const { return f; }
 
-const char *uFile::uFailure::uGetName() const { return uName; }
+const char *uFile::Failure::getName() const { return uName; }
 
-void uFile::uFailure::defaultTerminate() const {
-    uAbort( "(uFile &)0x%p, %.256s \"%.256s\".", &file(), message(), uGetName() );
-} // uFile::uFailure::defaultTerminate
+void uFile::Failure::defaultTerminate() const {
+    uAbort( "(uFile &)0x%p, %.256s \"%.256s\".", &file(), message(), getName() );
+} // uFile::Failure::defaultTerminate
 
 
-uFile::uTerminateFailure::uTerminateFailure( const uFile &f, const int accessCnt, const char *const msg ) :
-	uFile::uFailure( f, msg ), accessCnt( accessCnt ) {}
+uFile::TerminateFailure::TerminateFailure( const uFile &f, const int accessCnt, const char *const msg ) :
+	uFile::Failure( f, msg ), accessCnt( accessCnt ) {}
 
-void uFile::uTerminateFailure::defaultTerminate() const {
+void uFile::TerminateFailure::defaultTerminate() const {
     uAbort( "(uFile &)0x%p.~uFile(), %.256s, %d accessor(s) outstanding.", &file(), message(), accessCnt );
-} // uFile::uTerminateFailure::defaultTerminate
+} // uFile::TerminateFailure::defaultTerminate
 
 
-uFile::uStatusFailure::uStatusFailure( const uFile &f, const struct stat &buf, const char *const msg ) : uFile::uFailure( f, msg ), buf( buf ) {}
+uFile::StatusFailure::StatusFailure( const uFile &f, const struct stat &buf, const char *const msg ) : uFile::Failure( f, msg ), buf( buf ) {}
 
-void uFile::uStatusFailure::defaultTerminate() const {
+void uFile::StatusFailure::defaultTerminate() const {
     uAbort( "(uFile &)0x%p.status( buf:0x%p ), %.256s \"%.256s\".\nError(%d) : %s.",
-	    &file(), &buf, message(), uGetName(), errNo(), strerror( errNo() ) );
-} // uFile::uStatusFailure::defaultTerminate
-
-
-uInitEvent(uFile::uFailure);
-uInitEvent(uFile::uTerminateFailure);
-uInitEvent(uFile::uStatusFailure);
+	    &file(), &buf, message(), getName(), errNo(), strerror( errNo() ) );
+} // uFile::StatusFailure::defaultTerminate
 
 
 //######################### uFileAccess (cont) #########################
 
 
-uFileAccess::uFailure::uFailure( const uFileAccess &fa, const char *const msg ) : uFile::uFailure( fa.ufile, msg ), fa( fa ) {
+uFileAccess::Failure::Failure( const uFileAccess &fa, const char *const msg ) : uFile::Failure( fa.ufile, msg ), fa( fa ) {
     fd = fa.access.fd;
-} // uFileAccess::uFailure::uFailure
+} // uFileAccess::Failure::Failure
 
-const uFileAccess &uFileAccess::uFailure::fileAccess() const {
+const uFileAccess &uFileAccess::Failure::fileAccess() const {
     return fa;
-} // uFileAccess::uFailure::fileAccess
+} // uFileAccess::Failure::fileAccess
 
-int uFileAccess::uFailure::fileDescriptor() const {
+int uFileAccess::Failure::fileDescriptor() const {
     return fd;
-} // uFileAccess::uFailure::fileDescriptor
+} // uFileAccess::Failure::fileDescriptor
 
-void uFileAccess::uFailure::defaultTerminate() const {
+void uFileAccess::Failure::defaultTerminate() const {
     uAbort( "(uFileAccess &)0x%p( file:0x%p ), %.256s file \"%.256s\".",
-	    &fileAccess(), &file(), message(), uGetName() );
-} // uFileAccess::uFailure::defaultTerminate
+	    &fileAccess(), &file(), message(), getName() );
+} // uFileAccess::Failure::defaultTerminate
 
 
-uFileAccess::uOpenFailure::uOpenFailure( uFileAccess &fa, int flags, int mode, const char *const msg ) :
-	uFileAccess::uFailure( fa, msg ), flags( flags ), mode( mode ) {}
+uFileAccess::OpenFailure::OpenFailure( uFileAccess &fa, int flags, int mode, const char *const msg ) :
+	uFileAccess::Failure( fa, msg ), flags( flags ), mode( mode ) {}
 
-void uFileAccess::uOpenFailure::defaultTerminate() const {
+void uFileAccess::OpenFailure::defaultTerminate() const {
     uAbort( "(uFileAccess &)0x%p.uFileAccess( file:0x%p, flags:0x%x, mode:0x%x ), %.256s \"%.256s\".\nError(%d) : %s.",
-	    &fileAccess(), &file(), flags, mode, message(), uGetName(), errNo(), strerror( errNo() ) );
-} // uFile::uOpenFailure::defaultTerminate
+	    &fileAccess(), &file(), flags, mode, message(), getName(), errNo(), strerror( errNo() ) );
+} // uFile::OpenFailure::defaultTerminate
 
 
-uFileAccess::uCloseFailure::uCloseFailure( uFileAccess &fa, const char *const msg ) : uFileAccess::uFailure( fa, msg ) {}
+uFileAccess::CloseFailure::CloseFailure( uFileAccess &fa, const char *const msg ) : uFileAccess::Failure( fa, msg ) {}
 
-void uFileAccess::uCloseFailure::defaultTerminate() const {
+void uFileAccess::CloseFailure::defaultTerminate() const {
     uAbort( "(uFileAccess &)0x%p.~uFileAccess(), %.256s \"%.256s\".\nError(%d) : %s.",
-	    &fileAccess(), message(), uGetName(), errNo(), strerror( errNo() ) );
-} // uFile::uCloseFailure::defaultTerminate
+	    &fileAccess(), message(), getName(), errNo(), strerror( errNo() ) );
+} // uFile::CloseFailure::defaultTerminate
 
 
-uFileAccess::uSeekFailure::uSeekFailure( const uFileAccess &fa, const off_t offset, const int whence, const char *const msg ) :
-	uFileAccess::uFailure( fa, msg ), offset( offset ), whence( whence ) {}
+uFileAccess::SeekFailure::SeekFailure( const uFileAccess &fa, const off_t offset, const int whence, const char *const msg ) :
+	uFileAccess::Failure( fa, msg ), offset( offset ), whence( whence ) {}
 
-void uFileAccess::uSeekFailure::defaultTerminate() const {
+void uFileAccess::SeekFailure::defaultTerminate() const {
     uAbort( "(uFile &)0x%p.lseek( offset:%ld, whence:%d ), %.256s file \"%.256s\".\nError(%d) : %s.",
-	    &file(), (long int)offset, whence, message(), uGetName(), errNo(), strerror( errNo() ) );
-} // uFileAccess::uSeekFailure::defaultTerminate
+	    &file(), (long int)offset, whence, message(), getName(), errNo(), strerror( errNo() ) );
+} // uFileAccess::SeekFailure::defaultTerminate
 
 
-uFileAccess::uSyncFailure::uSyncFailure( const uFileAccess &fa, const char *const msg ) : uFileAccess::uFailure( fa, msg ) {}
+uFileAccess::SyncFailure::SyncFailure( const uFileAccess &fa, const char *const msg ) : uFileAccess::Failure( fa, msg ) {}
 
-void uFileAccess::uSyncFailure::defaultTerminate() const {
+void uFileAccess::SyncFailure::defaultTerminate() const {
     uAbort( "(uFileAccess &)0x%p.fsync(), %.256s \"%.256s\".\nError(%d) : %s.",
-	    &file(), message(), uGetName(), errNo(), strerror( errNo() ) );
-} // uFileAccess::uSyncFailure::defaultTerminate
+	    &file(), message(), getName(), errNo(), strerror( errNo() ) );
+} // uFileAccess::SyncFailure::defaultTerminate
 
 
-void uFileAccess::uWriteFailure::defaultResume() const {
+void uFileAccess::WriteFailure::defaultResume() const {
     if ( errNo() != EIO ) {
-	uThrow *this;
+	_Throw *this;
     } // if
-} // uFileAccess::uWriteFailure::defaultResume
+} // uFileAccess::WriteFailure::defaultResume
 
 
-uFileAccess::uReadFailure::uReadFailure( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg ) :
-	uFileAccess::uFailure( fa, msg ), buf( buf ), len( len ), timeout( timeout ) {}
+uFileAccess::ReadFailure::ReadFailure( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg ) :
+	uFileAccess::Failure( fa, msg ), buf( buf ), len( len ), timeout( timeout ) {}
 
-void uFileAccess::uReadFailure::defaultTerminate() const {
+void uFileAccess::ReadFailure::defaultTerminate() const {
     uAbort( "(uFileAccess &)0x%p.read( buf:0x%p, len:%d, timeout:0x%p ) : %.256s for file descriptor %d.\nError(%d) : %s.",
 	    &fileAccess(), buf, len, timeout, message(), fileDescriptor(), errNo(), strerror( errNo() ) );
-} // uFileAccess::uReadFailure::defaultTerminate
+} // uFileAccess::ReadFailure::defaultTerminate
 
-uFileAccess::uReadTimeout::uReadTimeout( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg ) :
-	uFileAccess::uReadFailure( fa, buf, len, timeout, msg ) {}
+uFileAccess::ReadTimeout::ReadTimeout( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg ) :
+	uFileAccess::ReadFailure( fa, buf, len, timeout, msg ) {}
 
 
-uFileAccess::uWriteFailure::uWriteFailure( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg ) :
-	uFileAccess::uFailure( fa, msg ), buf( buf ), len( len ), timeout( timeout ) {}
+uFileAccess::WriteFailure::WriteFailure( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg ) :
+	uFileAccess::Failure( fa, msg ), buf( buf ), len( len ), timeout( timeout ) {}
 
-void uFileAccess::uWriteFailure::defaultTerminate() const {
+void uFileAccess::WriteFailure::defaultTerminate() const {
     uAbort( "(uFileAccess &)0x%p.write( buf:0x%p, len:%d, timeout:0x%p ) : %.256s for file descriptor %d.\nError(%d) : %s.",
 	    &fileAccess(), buf, len, timeout, message(), fileDescriptor(), errNo(), strerror( errNo() ) );
-} // uFileAccess::uWriteFailure::defaultTerminate
+} // uFileAccess::WriteFailure::defaultTerminate
 
-uFileAccess::uWriteTimeout::uWriteTimeout( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg ) :
-	uFileAccess::uWriteFailure( fa, buf, len, timeout, msg ) {}
-
-
-uInitEvent(uFileAccess::uFailure);
-uInitEvent(uFileAccess::uOpenFailure);
-uInitEvent(uFileAccess::uCloseFailure);
-uInitEvent(uFileAccess::uSyncFailure);
-uInitEvent(uFileAccess::uSeekFailure);
-uInitEvent(uFileAccess::uReadFailure);
-uInitEvent(uFileAccess::uReadTimeout);
-uInitEvent(uFileAccess::uWriteFailure);
-uInitEvent(uFileAccess::uWriteTimeout);
+uFileAccess::WriteTimeout::WriteTimeout( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg ) :
+	uFileAccess::WriteFailure( fa, buf, len, timeout, msg ) {}
 
 
 // Local Variables: //
