@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uFile.h -- Nonblocking UNIX I/O library
 // 
 // Author           : Peter Buhr
 // Created On       : Tue Mar 29 16:38:54 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Aug 11 14:11:57 2004
-// Update Count     : 109
+// Last Modified On : Sun Jul 31 20:17:27 2005
+// Update Count     : 121
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -46,24 +46,23 @@
 class uFile {
     friend class uFileWrapper;
     friend class uFileAccess;
-    friend class uFilebuf;
 
     char *uName;
     int accessCnt;
 
     void uCreateFile( const char *name );
-    uMutex void access();
-    uMutex void unaccess();
+    _Mutex void access();
+    _Mutex void unaccess();
   public:
     uFile( const char *name );
     virtual ~uFile();
 
-    const char *uGetName() const;
+    const char *getName() const;
     void status( struct stat &buf );
 
-    uDualEvent uFailure;
-    uDualEvent uTerminateFailure;
-    uDualEvent uStatusFailure;
+    _DualEvent Failure;
+    _DualEvent TerminateFailure;
+    _DualEvent StatusFailure;
 }; // uFile
 
 
@@ -78,12 +77,17 @@ class uFileIO {
   protected:
     uIOaccess &access;
 
+    virtual void readFailure( const char *buf, const int len, const uDuration *timeout, const char *const op ) = 0;
+    virtual void readTimeout( const char *buf, const int len, const uDuration *timeout, const char *const op ) = 0;
+    virtual void writeFailure( const char *buf, const int len, const uDuration *timeout, const char *const op ) = 0;
+    virtual void writeTimeout( const char *buf, const int len, const uDuration *timeout, const char *const op ) = 0;
+
     uFileIO( uIOaccess &acc );
     virtual ~uFileIO();
   public:
     int read( char *buf, int len, uDuration *timeout = NULL );
     int readv( const struct iovec *iov, int iovcnt, uDuration *timeout = NULL );
-    uMutex int write( char *buf, int len, uDuration *timeout = NULL );
+    _Mutex int write( char *buf, int len, uDuration *timeout = NULL );
     int writev( const struct iovec *iov, int iovcnt, uDuration *timeout = NULL );
     int fd();
 }; // uFileIO
@@ -93,142 +97,147 @@ class uFileIO {
 
 
 class uFileAccess : public uFileIO {		// monitor
-    friend class uFilebuf;
+    template< class char_t, class traits > friend class std::basic_filebuf; // access: constructor
 
     uFile &ufile;
     uIOaccess access;
 
     uFileAccess( int fd, uFile &f );
+  protected:
+    void readFailure( const char *buf, const int len, const uDuration *timeout, const char *const op );
+    void readTimeout( const char *buf, const int len, const uDuration *timeout, const char *const op );
+    void writeFailure( const char *buf, const int len, const uDuration *timeout, const char *const op );
+    void writeTimeout( const char *buf, const int len, const uDuration *timeout, const char *const op );
   public:
     uFileAccess( uFile &f, int flags, int mode = 0644 );
-    uMutex virtual ~uFileAccess();
+    _Mutex virtual ~uFileAccess();
 
     off_t lseek( off_t offset, int whence );
     int fsync();
 
-    uDualEvent uFailure;
-    friend uDualEvent uFailure;
-    uDualEvent uOpenFailure;
-    uDualEvent uCloseFailure;
-    uDualEvent uSeekFailure;
-    uDualEvent uSyncFailure;
-    uDualEvent uReadFailure;
-    uDualEvent uReadTimeout;
-    uDualEvent uWriteFailure;
-    uDualEvent uWriteTimeout;
+    _DualEvent Failure;
+    friend _DualEvent Failure;
+    _DualEvent OpenFailure;
+    _DualEvent CloseFailure;
+    _DualEvent SeekFailure;
+    _DualEvent SyncFailure;
+    _DualEvent ReadFailure;
+    _DualEvent ReadTimeout;
+    _DualEvent WriteFailure;
+    _DualEvent WriteTimeout;
 }; // uFileAccess
 
 
 //######################### uFile (cont) #########################
 
 
-uDualEvent uFile::uFailure : public uIOFailure {
+_DualEvent uFile::Failure : public uIOFailure {
     const uFile &f;
     char uName[uEHMMaxName + sizeof("...")];		// room for "...\0"
   public:
-    uFailure( const uFile &f, const char *const msg );
-    ~uFailure();
+    Failure( const uFile &f, const char *const msg );
+    ~Failure();
     const uFile &file() const;
-    const char *uGetName() const;
+    const char *getName() const;
     virtual void defaultTerminate() const;
-}; // uFile::uFailure
+}; // uFile::Failure
 
 
-uDualEvent uFile::uTerminateFailure : public uFile::uFailure {
+_DualEvent uFile::TerminateFailure : public uFile::Failure {
     const int accessCnt;
   public:
-    uTerminateFailure( const uFile &f, const int accessCnt, const char *const msg );
+    TerminateFailure( const uFile &f, const int accessCnt, const char *const msg );
     virtual void defaultTerminate() const;
-}; // uFile::uTerminateFailure
+}; // uFile::TerminateFailure
 
 
-uDualEvent uFile::uStatusFailure : public uFile::uFailure {
+_DualEvent uFile::StatusFailure : public uFile::Failure {
     const struct stat &buf;
   public:
-    uStatusFailure( const uFile &f, const struct stat &buf, const char *const msg );
+    StatusFailure( const uFile &f, const struct stat &buf, const char *const msg );
     virtual void defaultTerminate() const;
-}; // uFile::uStatusFailure
+}; // uFile::StatusFailure
 
 
 //######################### uFileAccess (cont) #########################
 
 
-uDualEvent uFileAccess::uFailure : public uFile::uFailure {
+_DualEvent uFileAccess::Failure : public uFile::Failure {
     const uFileAccess &fa;
     int fd;
   public:
-    uFailure( const uFileAccess &fa, const char *const msg );
+    Failure( const uFileAccess &fa, const char *const msg );
     const uFileAccess &fileAccess() const;
     int fileDescriptor() const;
     virtual void defaultTerminate() const;
-}; // uFileAccess::uFailure
+}; // uFileAccess::Failure
 
 
-uDualEvent uFileAccess::uOpenFailure : public uFileAccess::uFailure {
+_DualEvent uFileAccess::OpenFailure : public uFileAccess::Failure {
     const int flags;
     const int mode;
   public:
-    uOpenFailure( uFileAccess &fa, int flags, int mode, const char *const msg );
+    OpenFailure( uFileAccess &fa, int flags, int mode, const char *const msg );
     virtual void defaultTerminate() const;
-}; // uFileAccess::uOpenFailure
+}; // uFileAccess::OpenFailure
 
 
-uDualEvent uFileAccess::uCloseFailure : public uFileAccess::uFailure {
+_DualEvent uFileAccess::CloseFailure : public uFileAccess::Failure {
   public:
-    uCloseFailure( uFileAccess &fa, const char *const msg );
+    CloseFailure( uFileAccess &fa, const char *const msg );
     virtual void defaultTerminate() const;
-}; // uFileAccess::uCloseFailure
+}; // uFileAccess::CloseFailure
 
 
-uDualEvent uFileAccess::uSeekFailure : public uFileAccess::uFailure {
+_DualEvent uFileAccess::SeekFailure : public uFileAccess::Failure {
     const off_t offset;
     const int whence;
   public:
-    uSeekFailure( const uFileAccess &fa, const off_t offset, const int whence, const char *const msg );
+    SeekFailure( const uFileAccess &fa, const off_t offset, const int whence, const char *const msg );
     virtual void defaultTerminate() const;
-}; // uFileAccess::uSeekFailure
+}; // uFileAccess::SeekFailure
 
 
-uDualEvent uFileAccess::uSyncFailure : public uFileAccess::uFailure {
+_DualEvent uFileAccess::SyncFailure : public uFileAccess::Failure {
   public:
-    uSyncFailure( const uFileAccess &fa, const char *const msg );
+    SyncFailure( const uFileAccess &fa, const char *const msg );
     virtual void defaultTerminate() const;
-}; // uFileAccess::uSyncFailure
+}; // uFileAccess::SyncFailure
 
 
-uDualEvent uFileAccess::uReadFailure : public uFileAccess::uFailure {
+_DualEvent uFileAccess::ReadFailure : public uFileAccess::Failure {
   protected:
     const char *buf;
     const int len;
     const uDuration *timeout;
   public:
-    uReadFailure( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg );
+    ReadFailure( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg );
     virtual void defaultTerminate() const;
-}; // uFileAccess::uReadFailure
+}; // uFileAccess::ReadFailure
 
 
-uDualEvent uFileAccess::uReadTimeout : public uFileAccess::uReadFailure {
+_DualEvent uFileAccess::ReadTimeout : public uFileAccess::ReadFailure {
   public:
-    uReadTimeout( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg );
-}; // uFileAccess::uReadTimeout
+    ReadTimeout( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg );
+}; // uFileAccess::ReadTimeout
 
 
-uDualEvent uFileAccess::uWriteFailure : public uFileAccess::uFailure {
+_DualEvent uFileAccess::WriteFailure : public uFileAccess::Failure {
   protected:
     const char *buf;
     const int len;
     const uDuration *timeout;
   public:
-    uWriteFailure( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg );
+    WriteFailure( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg );
     virtual void defaultResume() const;			// handle special case when errno == EIO
     virtual void defaultTerminate() const;
-}; // uFileAccess::uWriteFailure
+}; // uFileAccess::WriteFailure
 
 
-uDualEvent uFileAccess::uWriteTimeout : public uFileAccess::uWriteFailure {
+_DualEvent uFileAccess::WriteTimeout : public uFileAccess::WriteFailure {
   public:
-    uWriteTimeout( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg );
-}; // uFileAccess::uWriteFailure
+    WriteTimeout( const uFileAccess &fa, const char *buf, const int len, const uDuration *timeout, const char *const msg );
+}; // uFileAccess::WriteTimeout
 
 
 #pragma __U_USER_CODE__
