@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Russell Mok 1997
+// uC++ Version 5.3.0, Copyright (C) Russell Mok 1997
 // 
 // uIOEvent.cc -- 
 // 
 // Author           : Russell Mok
 // Created On       : Fri Dec 12 10:24:56 1997
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Jun 30 15:55:10 2003
-// Update Count     : 101
+// Last Modified On : Sat Mar  5 09:18:21 2005
+// Update Count     : 102
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -41,9 +41,6 @@ int uIOFailure::errNo() const {
 } // uIOFailure::errNo
 
 
-uInitEvent(uIOFailure);
-
-
 // Local Variables: //
 // compile-command: "gmake install" //
 // End: //
