@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Russell Mok 1997
+// uC++ Version 5.3.0, Copyright (C) Russell Mok 1997
 // 
 // uIOEvent.h -- 
 // 
 // Author           : Russell Mok
 // Created On       : Thu Dec 11 17:34:59 1997
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Aug 26 08:42:58 2004
-// Update Count     : 105
+// Last Modified On : Fri Jun 24 14:34:14 2005
+// Update Count     : 106
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -32,7 +32,7 @@
 #pragma __U_NOT_USER_CODE__
 
 
-uDualEvent uIOFailure {
+_DualEvent uIOFailure {
     // general IO exception-type
     int uErrno;
   protected:
