@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uIOStream.h -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Tue Mar 29 16:49:28 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jul 15 12:04:40 2003
-// Update Count     : 7
+// Last Modified On : Sun Jul 31 20:20:45 2005
+// Update Count     : 8
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -27,6 +27,7 @@
 
 #ifndef __U_IOSTREAM_H__
 #define __U_IOSTREAM_H__
+#warning uIOStream.h deprecated: use C++ iostream
 
 
 #include <uOStream.h>
