@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
 // 
 // uSemaphore.h -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Tue Mar 29 13:42:33 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Mar 15 17:28:33 2004
-// Update Count     : 59
+// Last Modified On : Wed Nov 30 08:39:32 2005
+// Update Count     : 64
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -58,7 +58,7 @@ class uSemaphore {
 
 #else
 
-uMonitor uSemaphore {
+_Monitor uSemaphore {
     int count;						// semaphore counter
     uCondition blockedTasks;
   public:
@@ -67,7 +67,7 @@ uMonitor uSemaphore {
 
     void P() {						// wait on a semaphore
 	count -= 1;					// decrement semaphore counter
-	if ( count < 0 ) uWait blockedTasks;		// if semaphore less than zero, wait for next V
+	if ( count < 0 ) blockedTasks.wait();		// if semaphore less than zero, wait for next V
     } // uSemaphore::P
 
     // This routine forces the implementation to use internal scheduling,
@@ -88,11 +88,11 @@ uMonitor uSemaphore {
     void V( unsigned int times = 1 ) {			// signal a semaphore
 	count += times;					// increment semaphore counter
 	for ( unsigned int i = 0; i < times; i += 1 ) {	// wake up required number of tasks
-	    uSignal blockedTasks;
+	    blockedTasks.signal();
 	} // for
     } // uSemaphore::V
 
-    uNoMutex bool empty() const {			// no tasks waiting on semaphore ?
+    _Nomutex bool empty() const {			// no tasks waiting on semaphore ?
 	return count >= 0;
     } // uSemaphore::empty
 }; // uSemaphore
