@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
 // 
 // gen.c -- 
 // 
 // Author           : Richard A. Stroobosscher
 // Created On       : Tue Apr 28 15:00:53 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Aug 31 11:22:04 2004
-// Update Count     : 778
+// Last Modified On : Mon Dec 12 09:02:41 2005
+// Update Count     : 805
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -76,7 +76,7 @@ void gen_base_clause( token_t *before, symbol_t *symbol ) {
     uassert( symbol != NULL );
 
     if ( ( symbol->data->key == COROUTINE || symbol->data->key == TASK ||
-	   symbol->data->key == DUALEVENT || symbol->data->key == RAISEEVENT || symbol->data->key == THROWEVENT ) &&
+	   symbol->data->key == DUALEVENT || symbol->data->key == RESUMEEVENT || symbol->data->key == THROWEVENT ) &&
 	 ( symbol->data->base == NULL ||
 	   ( symbol->data->base->data->attribute.Mutex && ( symbol->data->base->data->key == STRUCT || symbol->data->base->data->key == CLASS ) ) ) ) {
 	uassert( before != NULL );
@@ -110,8 +110,8 @@ void gen_base_clause( token_t *before, symbol_t *symbol ) {
 	    } // if
 	} else if ( symbol->data->key == DUALEVENT ) {
 	    gen_code( next, "public uEHM :: uDualClass" );
-	} else if ( symbol->data->key == RAISEEVENT ) {
-	    gen_code( next, "public uEHM :: uRaiseClass" );
+	} else if ( symbol->data->key == RESUMEEVENT ) {
+	    gen_code( next, "public uEHM :: uResumeClass" );
 	} else if ( symbol->data->key == THROWEVENT ) {
 	    gen_code( next, "public uEHM :: uThrowClass" );
 	} // if
@@ -169,7 +169,7 @@ void gen_quote_hash( token_t *before, hash_t *hash ) {
 
 void gen_member_prefix( token_t *before, symbol_t *symbol ) {
     gen_code( before, "{" );
-    gen_code( before, "uSerialMember uSerialMemberInstance ( uSerialInstance ," );
+    gen_code( before, "uSerialMember uSerialMemberInstance ( this -> uSerialInstance , this ->" );
     uassert( symbol != NULL );
     gen_entry( before, symbol->data->index );
     gen_code( before, "," );
@@ -200,16 +200,16 @@ void gen_main_prefix( token_t *before, symbol_t *symbol ) {
 	if ( table->symbol->data->attribute.rttskkind.kind.PERIODIC ) {
 	    gen_code( before,
 		     "uSleep ( uFirstActivateTime ) ; "
-		     "if ( uEndTime == 0 || uThisProcessor ( ) . uGetClock ( ) . uGetTime ( ) < uEndTime ) { "
+		     "if ( uEndTime == 0 || uThisProcessor ( ) . getClock ( ) . getTime ( ) < uEndTime ) { "
 		     "for ( ; ; ) { "
-		     "uTime uStartTime = uThisProcessor ( ) . uGetClock ( ) . uGetTime ( ) + uGetPeriod ( ) ;"
+		     "uTime uStartTime = uThisProcessor ( ) . getClock ( ) . getTime ( ) + uGetPeriod ( ) ;"
 		     );
 	} else if ( table->symbol->data->attribute.rttskkind.kind.SPORADIC ) {
 	    gen_code( before,
 		     "uSleep ( uFirstActivateTime ) ; "
-		     "if ( uEndTime == 0 || uThisProcessor ( ) . uGetClock ( ) . uGetTime ( ) < uEndTime ) { "
+		     "if ( uEndTime == 0 || uThisProcessor ( ) . getClock ( ) . getTime ( ) < uEndTime ) { "
 		     "for ( ; ; ) { "
-		     "uTime uStartTime = uThisProcessor ( ) . uGetClock ( ) . uGetTime ( ) + uGetPeriod ( ) ;"
+		     "uTime uStartTime = uThisProcessor ( ) . getClock ( ) . getTime ( ) + uGetPeriod ( ) ;"
 		     );
 	} else if ( table->symbol->data->attribute.rttskkind.kind.APERIODIC ) {
 	    gen_code( before,
@@ -281,23 +281,13 @@ void gen_constructor_prefix( token_t *before, symbol_t *symbol ) {
 	gen_code( before, "{ uDestruct = uConstruct ;" );
     } // if
     
-    if ( symbol->data->key == DUALEVENT || symbol->data->key == RAISEEVENT || symbol->data->key == THROWEVENT ) {
-	gen_code( before, "{ uId = &" );
-	if ( symbol->data->base != NULL ) {
-	    gen_base_specifier_name( before, symbol );
-	} else {
-	    gen_event_kind( before, symbol );
-	} // if
-	gen_code( before, ":: uId ;" );
-    } // if
-
     // if mutex, generate constructor code
     
     if ( symbol->data->attribute.Mutex ) {			// is it a monitor?
 	if ( symbol->data->key == COROUTINE || symbol->data->key == TASK ) {
-	    gen_code( before, "uSerialConstructor uSerialConstructorInstance ( uConstruct , uSerialInstance ) ;" );
+	    gen_code( before, "uSerialConstructor uSerialConstructorInstance ( uConstruct , this -> uSerialInstance ) ;" );
 	} else {
-	    gen_code( before, "uSerialConstructor uSerialConstructorInstance ( uConstruct , uSerialInstance ," );
+	    gen_code( before, "uSerialConstructor uSerialConstructorInstance ( uConstruct , this -> uSerialInstance ," );
 	    gen_quote_hash( before, symbol->hash );
 	    gen_code( before, " ) ;" );
 	} // if
@@ -307,7 +297,7 @@ void gen_constructor_prefix( token_t *before, symbol_t *symbol ) {
     
     if ( symbol->data->key == COROUTINE ) {
 	if ( symbol->data->attribute.Mutex ) {		// is it a coroutine monitor?
-	    gen_code( before, "uCoroutineConstructor uCoroutineConstructorInstance ( uConstruct , uSerialInstance , * this ," );
+	    gen_code( before, "uCoroutineConstructor uCoroutineConstructorInstance ( uConstruct , this -> uSerialInstance , * this ," );
 	} else {
 	    gen_code( before, "uCoroutineConstructor uCoroutineConstructorInstance ( uConstruct , *(uSerial *)0, * this ," );
 	} // if
@@ -315,9 +305,9 @@ void gen_constructor_prefix( token_t *before, symbol_t *symbol ) {
 	gen_code( before, ") ;" );
     } else if ( symbol->data->key == TASK ) {
 	if ( symbol->data->attribute.startP == NULL ) {
-	    gen_code( before, "uTaskConstructor uTaskConstructorInstance ( uConstruct , uSerialInstance , * this , *(uBasePIQ *)0 ," );
+	    gen_code( before, "uTaskConstructor uTaskConstructorInstance ( uConstruct , this -> uSerialInstance , * this , *(uBasePIQ *)0 ," );
 	} else {
-	    gen_code( before, "uTaskConstructor uTaskConstructorInstance ( uConstruct , uSerialInstance , * this , uPIQInstance ," );
+	    gen_code( before, "uTaskConstructor uTaskConstructorInstance ( uConstruct , this -> uSerialInstance , * this , uPIQInstance ," );
 	} // if
 	gen_quote_hash( before, symbol->hash );
 	if ( profile ) {
@@ -333,9 +323,6 @@ void gen_constructor_prefix( token_t *before, symbol_t *symbol ) {
 void gen_constructor_suffix( token_t *before, symbol_t *symbol ) {
     uassert( symbol != NULL );
 
-    if ( symbol->data->key == DUALEVENT || symbol->data->key == RAISEEVENT || symbol->data->key == THROWEVENT ) {
-	gen_code( before, "}" );
-    } // if
     if ( symbol->data->key == COROUTINE || symbol->data->attribute.Mutex ) {
 	gen_code( before, "}" );
     } // if
@@ -402,7 +389,7 @@ void gen_mutex( token_t *before, symbol_t *symbol ) {
 	symbol->data->attribute.endM->remove_token();		// remove '>'
 	delete symbol->data->attribute.endM;
     } // if
-    gen_code( before, "uSerial uSerialInstance ;" );
+//    gen_code( before, "uSerial uSerialInstance ;" );
 } // gen_mutex
 
 
@@ -471,7 +458,7 @@ void gen_serial_initializer( token_t *rp, token_t *end, token_t *before, symbol_
 
 
 void gen_event_kind( token_t *before, symbol_t *symbol ) {
-    gen_code( before, symbol->data->key == DUALEVENT ? "uEHM :: uDualClass" : symbol->data->key == RAISEEVENT ? "uEHM :: uRaiseClass" : "uEHM :: uThrowClass" );
+    gen_code( before, symbol->data->key == DUALEVENT ? "uEHM :: uDualClass" : symbol->data->key == RESUMEEVENT ? "uEHM :: uResumeClass" : "uEHM :: uThrowClass" );
 } // gen_event_kind
 
 
@@ -485,7 +472,7 @@ void gen_constructor( token_t *before, symbol_t *symbol ) {
     // if necessary, generate a default constructor
     
     if ( symbol->data->key == COROUTINE || symbol->data->attribute.Mutex ||
-	 symbol->data->key == DUALEVENT || symbol->data->key == RAISEEVENT || symbol->data->key == THROWEVENT ) {
+	 symbol->data->key == DUALEVENT || symbol->data->key == RESUMEEVENT || symbol->data->key == THROWEVENT ) {
 
 	symbol->data->table->hasdefault = true;
 	gen_hash( table->public_area, symbol->hash );
@@ -522,7 +509,7 @@ void gen_destructor_prefix( token_t *before, symbol_t *symbol ) {
     // if mutex, generate serial destructor code
     
     if ( symbol->data->attribute.Mutex ) {
-	gen_code( before, "uSerialDestructor uSerialDestructorInstance ( uDestruct , uSerialInstance ," );
+	gen_code( before, "uSerialDestructor uSerialDestructorInstance ( uDestruct , this -> uSerialInstance , this ->" );
 	gen_entry( before, DESTRUCTORPOSN );
 	gen_code( before, "," );
 	gen_mask( before, DESTRUCTORPOSN );
@@ -590,7 +577,7 @@ void gen_class_prefix( token_t *before, symbol_t *symbol ) {
       case COROUTINE:
       case TASK:
       case DUALEVENT:
-      case RAISEEVENT:
+      case RESUMEEVENT:
       case THROWEVENT:
 	gen_code( before, "private :" );
 	break;
@@ -629,27 +616,29 @@ void gen_class_suffix( token_t *before, symbol_t *symbol ) {
     table = symbol->data->table;
     uassert( table != NULL );
 
-    if ( symbol->data->key == DUALEVENT || symbol->data->key == RAISEEVENT || symbol->data->key == THROWEVENT ) {
-	gen_code( table->public_area, "static void * uId ;" );
-	gen_code( table->protected_area, "virtual void * uEvent_id ( ) const { return & uId ; }" );
-	gen_code( table->protected_area, "virtual" );
-	gen_code( table->protected_area, "uDualClass * uDuplicate ( ) const { return new" );
+    if ( symbol->data->key == DUALEVENT || symbol->data->key == RESUMEEVENT || symbol->data->key == THROWEVENT ) {
+	gen_code( table->protected_area, "virtual uDualClass * duplicate ( ) const { return new" );
 	gen_hash( table->protected_area, symbol->hash );
 	gen_code( table->protected_area, "( * this ) ; }" );
 
 	if ( symbol->data->key == DUALEVENT || symbol->data->key == THROWEVENT ) {
-	    gen_code( table->protected_area,
-		     "virtual void uStackThrow ( ) const { "
-		     "throw * this ; }"
-		     );
+	    gen_code( table->protected_area, "virtual void stackThrow ( ) const { throw * this ; }" );
 	} // if
     } // if
 
+    // declare uSerialInstance *after* the mutex queues (uMutexList) because
+    // ~uSerial accesses these queues to check if there are outstanding tasks
+    // awaiting entry.
+
+    if ( symbol->data->attribute.Mutex && ( symbol->data->base == NULL || ! symbol->data->base->data->attribute.Mutex ) ) {
+	gen_code( table->protected_area, "uSerial uSerialInstance ;" );
+    } // if
+
     // classes (not mutex), structs, unions may not have mutex arguments
 
     if ( ( symbol->data->key == STRUCT || symbol->data->key == CLASS || symbol->data->key == UNION ) && ! symbol->data->attribute.Mutex ) {
 	if ( symbol->data->attribute.startE != NULL ) {
-	    gen_error( ahead, "cannot specify mutex arguments for non-mutex type." );
+	    gen_error( ahead, "cannot specify mutex arguments for nomutex type." );
 	} // if 
     } // if 
 
@@ -662,7 +651,7 @@ void gen_class_suffix( token_t *before, symbol_t *symbol ) {
 	    structor_t *structor = table->destructor.remove_structor();
 
 	    if ( structor->dclmutex.qual.NOMUTEX && symbol->data->attribute.Mutex ) {
-		gen_error( ahead, "destructor must be mutex for mutex type, uNoMutex attribute ignored." );
+		gen_error( ahead, "destructor must be mutex for mutex type, nomutex attribute ignored." );
 	    } // if
 
 	    if ( structor->prefix != NULL ) {
@@ -702,61 +691,59 @@ void gen_class_suffix( token_t *before, symbol_t *symbol ) {
 } // gen_class_suffix
 
 
-void gen_wait_prefix( token_t *before, token_t *after ) {
+void gen_wait_prefix( token_t *before, token_t *after ) { // deprecated
     gen_code( before, "(" );
-    gen_code( after, ") . uW ( uSerialInstance" );
+    gen_code( after, ") . wait (" );
 } // gen_wait_prefix
 
-void gen_with( token_t *before, token_t *after ) {
-    gen_code( before, ", (" );
+void gen_with( token_t *before, token_t *after ) {	// deprecated
+    gen_code( before, "(" );
     gen_code( after, ")" );
 } // gen_with
 
-void gen_wait_suffix( token_t *before ) {
+void gen_wait_suffix( token_t *before ) {		// deprecated
     gen_code( before, ")" );
 } // gen_wait_suffix
 
 
-void gen_signal_prefix( token_t *before ) {
+void gen_signal_prefix( token_t *before ) {		// deprecated
     gen_code( before, "(" );
 } // gen_signal_prefix
 
-void gen_signal_suffix( token_t *before ) {
-    gen_code( before, ") . uS ( uSerialInstance )" );
+void gen_signal_suffix( token_t *before ) {		// deprecated
+    gen_code( before, ") . signal ( )" );
 } // gen_signal_suffix
 
 
-void gen_signalblock_prefix( token_t *before ) {
+void gen_signalblock_prefix( token_t *before ) {	// deprecated
     gen_code( before, "(" );
 } // gen_signalblock_prefix
 
-void gen_signalblock_suffix( token_t *before ) {
-    gen_code( before, ") . uSBlock ( uSerialInstance )" );
+void gen_signalblock_suffix( token_t *before ) {	// deprecated
+    gen_code( before, ") . signalBlock ( )" );
 } // gen_signalblock_suffix
 
 
-void gen_suspend_prefix( token_t *before, symbol_t *symbol ) {
-    gen_code( before, "{" );
-    gen_code( before, "uCoSuspend ( )" );
+void gen_suspend_prefix( token_t *before, symbol_t *symbol ) { // deprecated
+    gen_code( before, "{ suspend ( )" );
 } // gen_suspend_prefix
 
-void gen_suspend_suffix( token_t *before, symbol_t *symbol ) {
+void gen_suspend_suffix( token_t *before, symbol_t *symbol ) { // deprecated
     gen_code( before, "}" );
 } // gen_suspend_suffix
 
 
-void gen_resume_prefix( token_t *before, symbol_t *symbol ) {
-    gen_code( before, "{" );
-    gen_code( before, "uCoResume ( )" );
+void gen_resume_prefix( token_t *before, symbol_t *symbol ) { // deprecated
+    gen_code( before, "{ resume ( )" );
 } // gen_resume
 
-void gen_resume_suffix( token_t *before, symbol_t *symbol ) {
+void gen_resume_suffix( token_t *before, symbol_t *symbol ) { // deprecated
     gen_code( before, "}" );
 } // gen_resume
 
 
 void gen_verify( token_t *before ) {
-    gen_code( before, "uThisCoroutine ( ) . uVerify ( ) ;" );
+    gen_code( before, "uThisCoroutine ( ) . verify ( ) ;" );
 } // gen_verify
 
 
@@ -766,28 +753,18 @@ void gen_yield( token_t *before ) {
 
 
 void gen_uthrow_prefix( token_t *before, token_t *after ) {
-    gen_code( before, "uEHM :: uEHMThrow (" );
+    gen_code( before, "uEHM :: Throw (" );
 } // gen_uthrow_prefix
 
-void gen_uthrow_uat_prefix( token_t *before, token_t *after ) {
-    gen_code( before, "uEHM :: uEHMThrow (" );
-    gen_code( after, "," );
-} // gen_uthrow_uat_prefix
-
 void gen_uthrow_suffix( token_t *before ) {
     gen_code( before, ")" );
 } // gen_uthrow_suffix
 
 
 void gen_raise_prefix( token_t *before, token_t *after ) {
-    gen_code( before, "uEHM :: uEHMRaise (" );
+    gen_code( before, "uEHM :: Resume (" );
 } // gen_raise_prefix
 
-void gen_raise_uat_prefix( token_t *before, token_t *after ) {
-    gen_code( before, "uEHM :: uEHMRaise (" );
-    gen_code( after, "," );
-} // gen_raise_uat_prefix
-
 void gen_raise_suffix( token_t *before ) {
     gen_code( before, ")" );
 } // gen_raise_suffix
