@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
 // 
 // key.c -- 
 // 
 // Author           : Richard A. Stroobosscher
 // Created On       : Tue Apr 28 15:06:35 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sun Aug  8 07:22:55 2004
-// Update Count     : 60
+// Last Modified On : Wed Nov 30 12:14:01 2005
+// Update Count     : 88
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -25,6 +25,7 @@
 //
 
 #include "key.h"
+#include "input.h"
 
 #include <cstddef>					// NULL
 
@@ -57,7 +58,7 @@ keyword_t key[] = {
     { "export", EXPORT },
     { "__extension__", EXTENSION },			// gcc specific
     { "extern", EXTERN },
-    { "false", FALSE_C },
+    { "false", FALSE },
     { "float", FLOAT },
     { "for", FOR },
     { "friend", FRIEND },
@@ -90,7 +91,7 @@ keyword_t key[] = {
     { "template", TEMPLATE },
     { "this", THIS },
     { "throw", THROW },
-    { "true", TRUE_C },
+    { "true", TRUE },
     { "try", TRY },
     { "typedef", TYPEDEF },
     { "typeof", TYPEOF },				// gcc specific
@@ -109,35 +110,119 @@ keyword_t key[] = {
     { "wchar_t", WCHAR_T },
     { "__wchar_t", WCHAR_T },				// gcc specific
     { "while", WHILE },
-    
-    { "uAccept", ACCEPT },				// uC++ specific
-    { "uAcceptReturn", ACCEPTRETURN },
-    { "uAcceptWait", ACCEPTWAIT },
-    { "uAt", AT },
-    { "uCoroutine", COROUTINE },
-    { "uDisable", DISABLE },
-    { "uDualEvent", DUALEVENT },
-    { "uElse", UELSE },
-    { "uEnable", ENABLE },
-    { "uMutex", MUTEX },
-    { "uNoMutex", NOMUTEX },
-    { "uOr", OR },
-    { "uPeriodicTask", PTASK },
-    { "uRaise", RAISE },
-    { "uRaiseEvent", RAISEEVENT },
-    { "uRealTimeTask", RTASK },
-    { "uResume", RESUME },
-    { "uSignal", SIGNAL },
-    { "uSignalBlock", SIGNALBLOCK },
-    { "uSporadicTask", STASK },
-    { "uSuspend", SUSPEND },
-    { "uTask", TASK },
-    { "uTimeout", TIMEOUT },
-    { "uWait", WAIT },
-    { "uWhen", WHEN },
+
+    { "and", AND_AND },					// alternate operator names
+    { "and_eq", AND_ASSIGN },
+    { "bitand", '&' },
+    { "bitor", '|' },
+    { "compl", '~' },
+    { "not", '!' },
+    { "not_eq", NE },
+    { "or", OR_OR },
+    { "or_eq", OR_ASSIGN },
+    { "xor", '^' },
+    { "xor_eq", XOR_ASSIGN },
+
+// uC++ specific    
+
+    { "__Accept", ACCEPT },
+    { "_Accept", ACCEPT },
+    { "uAccept", ACCEPT },				// deprecated
+
+    { "__AcceptReturn", ACCEPTRETURN },
+    { "_AcceptReturn", ACCEPTRETURN },
+    { "uAcceptReturn", ACCEPTRETURN },			// deprecated
+
+    { "__AcceptWait", ACCEPTWAIT },
+    { "_AcceptWait", ACCEPTWAIT },
+    { "uAcceptWait", ACCEPTWAIT },			// deprecated
+
+    { "__At", AT },
+    { "_At", AT },
+    { "uAt", AT },					// deprecated
+
+    { "__Coroutine", COROUTINE },
+    { "_Coroutine", COROUTINE },
+    { "uCoroutine", COROUTINE },			// deprecated
+
+    { "__Disable", DISABLE },
+    { "_Disable", DISABLE },
+    { "uDisable", DISABLE },				// deprecated
+
+    { "__DualEvent", DUALEVENT },
+    { "_DualEvent", DUALEVENT },
+    { "uDualEvent", DUALEVENT },			// deprecated
+
+    { "uElse", UELSE },					// deprecated
+
+    { "__Enable", ENABLE },
+    { "_Enable", ENABLE },
+    { "uEnable", ENABLE },				// deprecated
+
+    { "__Mutex", MUTEX },
+    { "_Mutex", MUTEX },
+    { "uMutex", MUTEX },				// deprecated
+
+    { "__Nomutex", NOMUTEX },
+    { "_Nomutex", NOMUTEX },
+    { "uNoMutex", NOMUTEX },				// deprecated
+
+    { "uOr", OR },					// deprecated
+
+    { "__PeriodicTask", PTASK },
+    { "_PeriodicTask", PTASK },
+    { "uPeriodicTask", PTASK },				// deprecated
+
+    { "__Raise", RAISE },				// deprecated
+    { "_Raise", RAISE },				// deprecated
+    { "uRaise", RAISE },				// deprecated
+    { "__Resume", RAISE },
+    { "_Resume", RAISE },
+
+    { "__RaiseEvent", RESUMEEVENT },			// deprecated
+    { "_RaiseEvent", RESUMEEVENT },			// deprecated
+    { "uRaiseEvent", RESUMEEVENT },			// deprecated
+
+    { "__ResumeEvent", RESUMEEVENT },
+    { "_ResumeEvent", RESUMEEVENT },
+
+    { "__RealTimeTask", RTASK },
+    { "_RealTimeTask", RTASK },
+    { "uRealTimeTask", RTASK },				// deprecated
+
+    { "uResume", RESUME },				// deprecated
+    { "uSignal", SIGNAL },				// deprecated
+    { "uSignalBlock", SIGNALBLOCK },			// deprecated
+
+    { "__SporadicTask", STASK },
+    { "_SporadicTask", STASK },
+    { "uSporadicTask", STASK },				// deprecated
+
+    { "uSuspend", SUSPEND },				// deprecated
+
+    { "__Task", TASK },
+    { "_Task", TASK },
+    { "uTask", TASK },					// deprecated
+
+    { "__Timeout", TIMEOUT },
+    { "_Timeout", TIMEOUT },
+    { "uTimeout", TIMEOUT },				// deprecated
+
+    { "uWait", WAIT },					// deprecated
+
+    { "__When", WHEN },
+    { "_When", WHEN },
+    { "uWhen", WHEN },					// deprecated
+
     { "uWith", WITH },
-    { "uThrow", UTHROW },
-    { "uThrowEvent", THROWEVENT },
+
+    { "__Throw", UTHROW },
+    { "_Throw", UTHROW },
+    { "uThrow", UTHROW },				// deprecated
+
+    { "__ThrowEvent", THROWEVENT },
+    { "_ThrowEvent", THROWEVENT },
+    { "uThrowEvent", THROWEVENT },			// deprecated
     
     { NULL, 0 }
 };
