@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr and Nikita Borisov 1995
+// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr and Nikita Borisov 1995
 // 
 // u++.cc -- 
 // 
 // Author           : Nikita Borisov
 // Created On       : Tue Apr 28 15:26:27 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Aug 12 08:24:29 2004
-// Update Count     : 764
+// Last Modified On : Wed Dec 21 11:23:45 2005
+// Update Count     : 786
 //
 // This  library is free  software; you  can redistribute  it and/or  modify it
 // under the terms of the GNU Lesser General Public License as published by the
@@ -41,6 +41,11 @@ using std::string;
 //#define __U_DEBUG_H__
 
 
+bool prefix( string arg, string pre ) {
+    return arg.substr( 0, pre.size() ) == pre;
+} // prefix
+
+
 void shuffle( const char *args[], int S, int E, int N ) {
     // S & E index 1 passed the end so adjust with -1
 #ifdef __U_DEBUG_H__
@@ -88,6 +93,7 @@ int main( int argc, char *argv[] ) {
     string compiler_path( CCAPP );			// path/name of C compiler
     string compiler_name;				// name of C compiler
 
+    bool nonoptarg = false;				// indicates non-option argument specified
     bool link = true;					// linking as well as compiling
     bool verbose = false;				// -v flag
     bool quiet = false;					// -quiet flag
@@ -124,7 +130,6 @@ int main( int argc, char *argv[] ) {
     string perfctrincdir;
     string perfctrlibdir;
     string token;
-    int executable = 0;
 
 #ifdef __U_DEBUG_H__
     cerr << "u++:" << endl;
@@ -144,10 +149,10 @@ int main( int argc, char *argv[] ) {
 #ifdef __U_DEBUG_H__
 	cerr << "arg:\"" << arg << "\"" << endl;
 #endif // __U_DEBUG_H__
-	if ( arg.substr(0,1) == "-" ) {
+	if ( prefix( arg, "-" ) ) {
 	    // pass through arguments
 
-	    if ( arg == "-Xlinker" ) {			// GNU linker pass through
+	    if ( arg == "-Xlinker" || arg == "-o" ) {
 		args[nargs] = argv[i];			// pass the argument along
 		nargs += 1;
 		i += 1;
@@ -194,7 +199,7 @@ int main( int argc, char *argv[] ) {
 		nargs += 1;
 #else
 		if ( putenv( (char *)( *new string( string( "__U_COMPILER__=" ) + argv[i]) ).c_str() ) != 0 ) {
-		    cerr << argv[0] << " Error cannot set environment variable." << endl;
+		    cerr << argv[0] << " error, cannot set environment variable." << endl;
 		    exit( -1 );
 		} // if
 #endif
@@ -209,11 +214,11 @@ int main( int argc, char *argv[] ) {
 		debugging = true;			// symbolic debugging required
 		args[nargs] = argv[i];			// pass the argument along
 		nargs += 1;
-	    } else if ( arg.substr(0,2) == "-B" ) {
+	    } else if ( prefix( arg, "-B" ) ) {
 		Bprefix = arg.substr(2);		// strip the -B flag
 		args[nargs] = ( *new string( string("-D__U_GCC_BPREFIX__=") + Bprefix ) ).c_str();
 		nargs += 1;
-	    } else if ( arg.substr(0,2) == "-b" ) {
+	    } else if ( prefix( arg, "-b" ) ) {
 		if ( arg.length() == 2 ) {		// separate argument ?
 		    i += 1;
 		    arg += argv[i];			// concatenate argument
@@ -226,13 +231,13 @@ int main( int argc, char *argv[] ) {
 		shuffle( args, sargs, nargs, 1 );	// make room at front of argument list
 		args[sargs] = ( *new string( arg ) ).c_str(); // pass the argument along
 		if ( putenv( (char *)( *new string( string( "__U_GCC_MACHINE__=" ) + arg ) ).c_str() ) != 0 ) {
-		    cerr << argv[0] << " Error cannot set environment variable." << endl;
+		    cerr << argv[0] << " error, cannot set environment variable." << endl;
 		    exit( -1 );
 		} // if
 		sargs += 1;
 #endif
 		nargs += 1;
-	    } else if ( arg.substr(0,2) == "-V" ) {
+	    } else if ( prefix( arg, "-V" ) && ! prefix( compiler_name, "icpc" ) ) {
 		if ( arg.length() == 2 ) {		// separate argument ?
 		    i += 1;
 		    arg += argv[i];			// concatenate argument
@@ -245,7 +250,7 @@ int main( int argc, char *argv[] ) {
 		shuffle( args, sargs, nargs, 1 );	// make room at front of argument list
 		args[sargs] = ( *new string( arg ) ).c_str(); // pass the argument along
 		if ( putenv( (char *)( *new string( string( "__U_GCC_VERSION__=" ) + arg ) ).c_str() ) != 0 ) {
-		    cerr << argv[0] << " Error cannot set environment variable." << endl;
+		    cerr << argv[0] << " error, cannot set environment variable." << endl;
 		    exit( -1 );
 		} // if
 		sargs += 1;
@@ -258,17 +263,10 @@ int main( int argc, char *argv[] ) {
 		    cpp_flag = true;			// cpp only
 		} // if
 		link = false;                           // no linkage required
-	    } else if ( arg.substr(1,1) == "l" ) {
+	    } else if ( arg[1] == 'l' ) {
 		// if the user specifies a library, load it after user code
 		libs[nlibs] = argv[i];
 		nlibs += 1;
-	    } else if ( arg == "-o" ) {			// TEMPORARY: should be a way to find this name in the application
-		args[nargs] = argv[i];
-		nargs += 1;
-		i += 1;
-		args[nargs] = argv[i];
-		nargs += 1;
-		executable = i;
 	    } else {
 		// concatenate any other arguments
 		args[nargs] = argv[i];
@@ -278,6 +276,7 @@ int main( int argc, char *argv[] ) {
 	    // concatenate other arguments
 	    args[nargs] = argv[i];
 	    nargs += 1;
+	    nonoptarg = true;
 	} // if
     } // for
 
@@ -290,7 +289,7 @@ int main( int argc, char *argv[] ) {
 #endif // __U_DEBUG_H__
 
     if ( cpp_flag && upp_flag ) {
-	cerr << argv[0] << " Error cannot use -E and -U++ flags together." << endl;
+	cerr << argv[0] << " error, cannot use -E and -U++ flags together." << endl;
 	exit( -1 );
     } // if
 
@@ -390,7 +389,7 @@ int main( int argc, char *argv[] ) {
 
 	int pargs = 0;
 	if ( profile ) {
-	    pargs += 11;				// N profiler arguments added at beginning
+	    pargs += 9;					// N profiler arguments added at beginning
 	    if ( ! debugging ) pargs += 1;		// no -g flag ? make room for one
 	} // if
 	shuffle( args, sargs, nargs, pargs );
@@ -414,10 +413,6 @@ int main( int argc, char *argv[] ) {
 	    sargs += 1;
 	    args[sargs] = "U_OTHERPROFILINGSW";		// force profiler start-up widgets to be loaded from archive
 	    sargs += 1;
-	    args[sargs] = "-u";
-	    sargs += 1;
-	    args[sargs] = "U_HARDWAREPROFILINGSW";	// force profiler start-up widgets to be loaded from archive
-	    sargs += 1;
 	    args[sargs] = ( *new string( mvdlibdir + "/uProfile"  + m + d + ".a" ) ).c_str();
 	    sargs += 1;
 	    if ( ! debugging ) {			// add -g if not specified
@@ -475,8 +470,11 @@ int main( int argc, char *argv[] ) {
 
 	// any machine specific libraries
 
-	libs[nlibs] = "-ldl";				// calls to dlsym/dlerror
-	nlibs += 1;
+	if ( tos != "irix" ) {
+	    // unnecessary on irix, and potentially not present in 64-bit
+	    libs[nlibs] = "-ldl";			// calls to dlsym/dlerror
+	    nlibs += 1;
+	} // if
 
 	if ( profile ) {
 	    args[nargs] = ( *new string( string("-L") + mvdlibdir ) ).c_str();
@@ -500,8 +498,8 @@ int main( int argc, char *argv[] ) {
 	    libs[nlibs] = "-lSM";
 	    nlibs += 1;
 	    libs[nlibs] = "-lICE";
-	    nlibs += 1;
-	    libs[nlibs] = "-lXpm";
+//	    nlibs += 1;
+//	    libs[nlibs] = "-lXpm";
 	    nlibs += 1;
 	    libs[nlibs] = "-lXext";
 	    nlibs += 1;
@@ -528,8 +526,10 @@ int main( int argc, char *argv[] ) {
                 libs[nlibs] = "-lperfctr";
                 nlibs += 1;
 	    } // if
-	    if ( tos == "linux" && tcpu == "ia64" ) {	// link in libunwind for backtraces
-                libs[nlibs] = "-lunwind";
+	    if ( tos == "linux" && tcpu == "ia64" ) {
+                libs[nlibs] = "-lunwind";		// link in libunwind for backtraces
+                nlibs += 1;
+                libs[nlibs] = "-lpfm3";			// link in performance counter
                 nlibs += 1;
 	    } // if
 	} // if
@@ -539,7 +539,20 @@ int main( int argc, char *argv[] ) {
 	    nlibs += 1;
 	    libs[nlibs] = "-lsocket";
 	    nlibs += 1;
+#if ! defined( TLS )
+	    libs[nlibs] = "-z";
+	    nlibs += 1;
+	    libs[nlibs] = "now";
+	    nlibs += 1;
+#endif // TLS
 	} // if
+
+#if defined( TLS )					// Thread Local Storage ?
+	if ( tos == "linux" && multi ) {
+	    libs[nlibs] = "-lpthread";
+	    nlibs += 1;
+	} // if
+#endif // TLS
     } // if
 
     // add the directory that contains the include files to the list of
@@ -620,10 +633,6 @@ int main( int argc, char *argv[] ) {
 	nargs += 1;
         args[nargs] = "-D__U_PROFILE__";
         nargs += 1;
-	if ( executable && link ) {
-	    args[nargs] = ( *new string( string("-D__U_EXECUTABLE_FILENAME__=\"") + argv[executable] + string("\"") ) ).c_str();
-	    nargs += 1;
-	} // if
     } else {
         heading += " (no profile)";
     } // if
@@ -633,6 +642,11 @@ int main( int argc, char *argv[] ) {
     nargs += 1;
 #endif // U_TLS
 
+#if defined( ONETIMER )					// Thread Local Storage ?
+    args[nargs] = "-D__U_ONETIMER__";
+    nargs += 1;
+#endif // U_ONETIMER
+
     if ( Bprefix.length() == 0 ) {
 	Bprefix = installlibdir;
 	args[nargs] = ( *new string( string("-D__U_GCC_BPREFIX__=") + Bprefix ) ).c_str();
@@ -650,16 +664,35 @@ int main( int argc, char *argv[] ) {
 	compiler_name = *new string( compiler_path.substr( p + 1 ) );
     } // if
 
-    if ( compiler_name.substr(0,3) == "g++" ) {		// allow suffix on g++ name
-        // TEMPORARY: gcc 3.2.3 code gen problem
-	args[nargs] = "-fno-optimize-sibling-calls"; 
-	nargs += 1;
+    if ( prefix( compiler_name, "g++" ) ) {		// allow suffix on g++ name
+	if ( tcpu == "ia64" ) {
+	    // TEMPORARY: gcc 3 code gen problem on ia64
+	    args[nargs] = "-fno-optimize-sibling-calls"; 
+	    nargs += 1;
+	} // if
 	args[nargs] = "-no-integrated-cpp"; 
 	nargs += 1;
 	args[nargs] = ( *new string( string("-B") + Bprefix + "/" ) ).c_str();
 	nargs += 1;
+    } else if ( prefix( compiler_name, "icpc" ) ) {
+	args[nargs] = ( *new string( string("-Qlocation,c,") + Bprefix ) ).c_str();
+	nargs += 1;
+	args[nargs] = ( *new string( string("-Qlocation,cpp,") + Bprefix ) ).c_str();
+	nargs += 1;
+	// 61, 68 integer operations -- necessary for gcc includes
+	// 161 unknown pragma -- necessary for gcc includes
+	// 177 label used but never referenced
+	// 239 floating-point underflow -- necessary for gcc includes
+	// 327 null reference
+	// 873 no placement delete operator
+	// 1125 virtual function override intended? -- useful, but prone to false positives
+	// 1292 attribute "__nonnull__" ignored -- necessary for gcc includes
+	// 1476 tail padding of base class
+	// 1572 floating-point equality -- necessary for gcc includes
+	args[nargs] = "-wd61,68,161,177,239,327,873,1125,1292,1476,1572";
+	nargs += 1;
     } else {
-	cerr << argv[0] << ": Error compiler " << compiler_name << " not supported." << endl;
+	cerr << argv[0] << " error, compiler " << compiler_name << " not supported." << endl;
 	exit( -1 );
     } // if
 
@@ -701,6 +734,11 @@ int main( int argc, char *argv[] ) {
 	cerr << endl;
     } // if
 
+    if ( ! nonoptarg ) {
+	cerr << argv[0] << " error, no input files" << endl;
+	exit( -1 );
+    } // if
+
     // execute the command and return the result
 
     execvp( args[0], (char *const *)args );		// should not return
